@@ -202,12 +202,6 @@ CENTERROR_CATALOG(CENTERROR_GP_DNS_HOSTENT_NAME_INVALID)
 CENTERROR_CATALOG(CENTERROR_GP_DNS_QUERY_FAILED)
 CENTERROR_CATALOG(CENTERROR_GP_EVENT_LOG_NOT_AVAILABLE)
 CENTERROR_CATALOG(CENTERROR_GP_NO_SUCH_PROVIDER)
-CENTERROR_CATALOG(CENTERROR_GP_STRING_CONVERSION_FAILED)
-CENTERROR_CATALOG(CENTERROR_GP_CREATE_FAILED)
-CENTERROR_CATALOG(CENTERROR_GP_WRITE_FAILED)
-CENTERROR_CATALOG(CENTERROR_GP_READ_FAILED)
-CENTERROR_CATALOG(CENTERROR_GP_QUERY_DIRECTORY)
-CENTERROR_CATALOG(CENTERROR_GP_PATH_NOT_FOUND)
 
 CENTERROR_CATALOG(CENTERROR_REGISTRY_OPEN_KEYDB_FAILED)
 CENTERROR_CATALOG(CENTERROR_REGISTRY_NO_SUCH_KEY)
@@ -482,9 +476,9 @@ CENTERROR_CATALOG_DESC(
     
     "Required PAM module not found",
     
-    "The pam_lsass module or a required system PAM module "
+    "The pam_lwidentity module or a required system PAM module "
     "could not be found.  Please ensure that all pam modules are "
-    "present in correct location and that Likewise is "
+    "present in correct location and that Likewise Enterprise is "
     "completely installed." )
 
 CENTERROR_CATALOG_DESC(
