@@ -676,7 +676,7 @@ CTCreateTempDirectory(
     if(tmpDir == NULL)
         tmpDir = "/tmp";
 
-    ceError = CTAllocateStringPrintf(&template, "%s/likewisetmpXXXXXX", tmpDir);
+    ceError = CTAllocateStringPrintf(&template, "%s/centeristmpXXXXXX", tmpDir);
     BAIL_ON_CENTERIS_ERROR(ceError);
 
     if (mkdtemp(template) == NULL) {
@@ -1641,7 +1641,6 @@ CTRunSedOnFile(
     mode_t mode;
     PSTR sedPath = NULL;
     BOOLEAN isSame;
-    PSTR pszFinalPath = NULL;
 
     BAIL_ON_CENTERIS_ERROR(ceError = CTFindSed(&sedPath));
     ppszArgs[argPos++] = sedPath;
@@ -1650,11 +1649,7 @@ CTRunSedOnFile(
         ppszArgs[argPos++] = "-n";
     ppszArgs[argPos++] = pszExpression;
 
-    ceError = CTGetFileTempPath(
-                        pszDstPath,
-                        &pszFinalPath,
-                        &tempPath);
-    BAIL_ON_CENTERIS_ERROR(ceError);
+    BAIL_ON_CENTERIS_ERROR(ceError = CTAllocateStringPrintf(&tempPath, "%s.lwidentity.temp", pszDstPath));
 
     dwFdIn = open(pszSrcPath, O_RDONLY);
     if (dwFdIn < 0)
@@ -1683,15 +1678,15 @@ CTRunSedOnFile(
         BAIL_ON_CENTERIS_ERROR(ceError = CENTERROR_COMMAND_FAILED);
     }
 
-    BAIL_ON_CENTERIS_ERROR(ceError = CTFileContentsSame(tempPath, pszFinalPath, &isSame));
+    BAIL_ON_CENTERIS_ERROR(ceError = CTFileContentsSame(tempPath, pszDstPath, &isSame));
     if (isSame)
     {
         BAIL_ON_CENTERIS_ERROR(ceError = CTRemoveFile(tempPath));
     }
     else
     {
-        ceError = CTSafeReplaceFile(pszFinalPath, tempPath);
-        BAIL_ON_CENTERIS_ERROR(ceError);
+        BAIL_ON_CENTERIS_ERROR(ceError = CTBackupFile(pszDstPath));
+        BAIL_ON_CENTERIS_ERROR(ceError = CTMoveFile(tempPath, pszDstPath));
     }
 
 error:
@@ -1708,7 +1703,6 @@ error:
     if (pProcInfo)
         CTFreeProcInfo(pProcInfo);
     CT_SAFE_FREE_STRING(tempPath);
-    CT_SAFE_FREE_STRING(pszFinalPath);
     CT_SAFE_FREE_STRING(sedPath);
 
     return ceError;
@@ -1836,91 +1830,6 @@ cleanup:
     return ceError;
 }
 
-CENTERROR
-CTGetFileTempPath(
-        PCSTR unresolvedSrcPath,
-        PSTR* resolvedSrcPath,
-        PSTR* tempPath)
-{
-    PSTR symTarget = NULL;
-    PSTR newPath = NULL;
-    PSTR currentPath = NULL;
-    CENTERROR ceError = CENTERROR_SUCCESS;
-    // do not free
-    PSTR separator = NULL;
-
-    if (resolvedSrcPath)
-    {
-        *resolvedSrcPath = NULL;
-    }
-    if (tempPath)
-    {
-        *tempPath = NULL;
-    }
-
-    ceError = CTAllocateString(unresolvedSrcPath, &currentPath);
-    GCE(ceError);
-
-    while (1)
-    {
-        ceError = CTGetSymLinkTarget(
-                        currentPath,
-                        &symTarget);
-        if (ceError == CTMapSystemError(EINVAL))
-        {
-            // The last symlink component was resolved
-            ceError = 0;
-            break;
-        }
-        else if (ceError == CTMapSystemError(ENOENT))
-        {
-            // The target does not exist yet. The caller should create this path
-            ceError = 0;
-            break;
-        }
-        GCE(ceError);
-
-        // Strip off the file component
-        separator = strrchr(currentPath, '/');
-        if (separator != NULL)
-        {
-            separator[1] = 0;
-        }
-
-        if (symTarget[0] == '/')
-        {
-            GCE(ceError = CTAllocateStringPrintf(&newPath, "%s", symTarget));
-        }
-        else
-        {
-            GCE(ceError = CTAllocateStringPrintf(&newPath, "%s%s", currentPath,
-                        symTarget));
-        }
-
-        CT_SAFE_FREE_STRING(currentPath);
-        CT_SAFE_FREE_STRING(symTarget);
-        currentPath = newPath;
-        newPath = NULL;
-    }
-
-    if (tempPath)
-    {
-        GCE(ceError = CTAllocateStringPrintf(tempPath, "%s.lwidentity.new", currentPath));
-    }
-
-    if (resolvedSrcPath)
-    {
-        *resolvedSrcPath = currentPath;
-        currentPath = NULL;
-    }
-
-cleanup:
-    CT_SAFE_FREE_STRING(currentPath);
-    CT_SAFE_FREE_STRING(newPath);
-    CT_SAFE_FREE_STRING(symTarget);
-    return ceError;
-}
-
 CENTERROR
 CTSafeReplaceFile(
         PCSTR finalName,
