@@ -184,7 +184,7 @@ CTStrToUpper(
 
     if (pszString != NULL) {
         while (*pszString != '\0') {
-            *pszString = toupper((int)*pszString);
+            *pszString = toupper(*pszString);
             pszString++;
         }
     }
@@ -199,7 +199,7 @@ CTStrToLower(
 
     if (pszString != NULL) {
         while (*pszString != '\0') {
-            *pszString = tolower((int)*pszString);
+            *pszString = tolower(*pszString);
             pszString++;
         }
     }
@@ -654,14 +654,12 @@ CENTERROR CTReadToken(const char **pos, CTParseToken *store, const char *include
         (*pos)++;
     }
     white_start = *pos;
-    while (**pos != '\0' && strchr(includeSeparators, **pos) != NULL)
+    while(strchr(includeSeparators, **pos) != NULL)
     {
         (*pos)++;
     }
     white_end = *pos;
-    while (white_start > token_start &&
-            white_start[-1] != '\0' &&
-            strchr(trimBack, white_start[-1]) != NULL)
+    while(white_start > token_start && strchr(trimBack, *white_start) != NULL)
     {
         white_start--;
     }
