@@ -142,6 +142,8 @@
                                                 RPC_C_CN_DBG_ROUTINE_TRACE,\
                                                 ("(" #s ")\n"))
 
+#include <npctypes.h>
+
 
 /***********************************************************************/
 /*
@@ -549,7 +551,7 @@ typedef struct rpc_cn_assoc_grp_s_t
     unsigned16                          grp_refcnt;
     rpc_addr_p_t                        grp_address;
     rpc_addr_p_t                        grp_secaddr;
-    rpc_transport_info_p_t              grp_transport_info;
+    NPC_TOKEN_ID			grp_imp_token;
     rpc_cn_local_id_t                   grp_id;
     unsigned16                          grp_max_assoc;
     unsigned16                          grp_cur_assoc;
@@ -568,17 +570,18 @@ typedef struct rpc_cn_assoc_grp_s_t
 
 typedef struct
 {
-    unsigned16 volatile                 cn_state;
-    unsigned16 volatile                 cn_rcvr_waiters;
+    unsigned16                          cn_state;
+    unsigned16                          cn_rcvr_waiters;
     rpc_mutex_t                         cn_rcvr_mutex; /* unused so far */
     rpc_cond_t                          cn_rcvr_cond;
     dcethread*                          cn_rcvr_thread_id;
     unsigned_char_t                     *cn_listening_endpoint;
-    rpc_socket_t volatile               cn_sock;
+    rpc_socket_t                        cn_sock;
     rpc_addr_p_t                        rpc_addr;
-    unsigned volatile                   exit_rcvr : 1;
-    unsigned volatile                   in_sendmsg : 1;
-    unsigned volatile                   waiting_for_sendmsg_complete : 1;
+    NPC_TOKEN_ID                        imp_token;
+    unsigned                            exit_rcvr : 1;
+    unsigned                            in_sendmsg : 1;
+    unsigned                            waiting_for_sendmsg_complete : 1;
 } rpc_cn_ctlblk_t, *rpc_cn_ctlblk_p_t;
 
 #define RPC_CN_ASSOC_LOCK(__assoc)	RPC_MUTEX_LOCK((__assoc)->cn_ctlblk.cn_rcvr_mutex)
@@ -594,7 +597,7 @@ typedef struct
 #define RPC_C_CN_ASSOC_SCANNED                  0x00000008
 #define RPC_C_CN_ASSOC_AUTH_EXPECTED            0x00000010
 
-struct rpc_cn_assoc_s_t
+typedef struct rpc_cn_assoc_s_t
 {
     rpc_list_t                          link;   /* MUST BE 1ST */
     rpc_cn_sm_ctlblk_t                  assoc_state;
@@ -620,12 +623,10 @@ struct rpc_cn_assoc_s_t
     rpc_list_t                          syntax_list;    /* rpc_cn_syntax_t */
     rpc_list_t                          msg_list;       /* rpc_cn_fragbuf_t */
     rpc_cn_assoc_sec_context_t          security;
-    rpc_transport_info_p_t              transport_info;
     rpc_cn_fragbuf_p_t                  raw_packet_p;
     rpc_cn_assoc_sm_work_p_t            assoc_sm_work;
     unsigned32                          bind_packets_sent;
-};
-// rpc_cn_assoc_t and rpc_cn_assoc_p_t are declared in comsoc.h
+} rpc_cn_assoc_t, *rpc_cn_assoc_p_t;
 
 /*
  * If KRB_CN is on, or it isn't explicitly off, turn on CN_AUTH.
@@ -813,7 +814,7 @@ EXTERNAL rpc_list_desc_t        rpc_g_cn_assoc_lookaside_list;
  * R P C _ G _ C N _ C A L L _ R E P _ L O O K A S I D E _ L I S T
  */
 
-#define RPC_C_CN_CALL_LOOKASIDE_MAX             0
+#define RPC_C_CN_CALL_LOOKASIDE_MAX             16
 EXTERNAL rpc_list_desc_t        rpc_g_cn_call_lookaside_list;
 
 /*
@@ -828,7 +829,7 @@ EXTERNAL rpc_list_desc_t          rpc_g_cn_binding_lookaside_list;
  * R P C _ G _ C N _ [ L G , S M ] _ F R A G B U F _ L I S T
  */
 
-#define RPC_C_CN_FRAGBUF_LOOKASIDE_MAX          0
+#define RPC_C_CN_FRAGBUF_LOOKASIDE_MAX          8
 EXTERNAL rpc_list_desc_t          rpc_g_cn_lg_fbuf_lookaside_list;
 EXTERNAL rpc_list_desc_t          rpc_g_cn_sm_fbuf_lookaside_list;
 
