@@ -2403,7 +2403,7 @@ unsigned32          *status;
     /*
      * Create a network descriptor for this RPC Protocol Sequence.
      */
-    serr = rpc__socket_open(pseq_id, NULL, &desc);
+    serr = rpc__socket_open(pseq_id, &desc);
 
     if (RPC_SOCKET_IS_ERR(serr))
     {
@@ -2490,7 +2490,7 @@ unsigned32          *status;
 CLEANUP:
 
     if (have_desc)
-        RPC_SOCKET_CLOSE(desc);
+        rpc__socket_close(desc);
 
     if (have_addr_vec)
         rpc__naf_addr_vector_free (&addr_vector, &temp_status);
