@@ -1,5 +1,5 @@
 /*
- *
+ * 
  * (c) Copyright 1991 OPEN SOFTWARE FOUNDATION, INC.
  * (c) Copyright 1991 HEWLETT-PACKARD COMPANY
  * (c) Copyright 1991 DIGITAL EQUIPMENT CORPORATION
@@ -16,7 +16,7 @@
  * Packard Company, nor Digital Equipment Corporation makes any
  * representations about the suitability of this software for any
  * purpose.
- *
+ * 
  */
 /*
  */
@@ -27,7 +27,7 @@
 **
 **  FACILITY:
 **
-**      Remote Procedure Call (RPC)
+**      Remote Procedure Call (RPC) 
 **
 **  ABSTRACT:
 **
@@ -185,7 +185,7 @@ GLOBAL rpc_cn_auth_epv_t rpc_g_schnauth_cn_epv =
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      Determine whether the authentication protocol requires a
 **      3-way authentication handshake. If true the client is expected to
 **      provide an rpc_auth3 PDU before the security context is fully
@@ -229,7 +229,7 @@ INTERNAL boolean32 rpc__schnauth_cn_three_way (void)
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      Determine whether the established security context will be
 **      valid (i. e. timely) for the next 300 seconds. If
 **      not this routine will try to renew the context.
@@ -244,7 +244,7 @@ INTERNAL boolean32 rpc__schnauth_cn_three_way (void)
 **
 **  INPUTS/OUTPUTS:     none
 **
-**  OUTPUTS:
+**  OUTPUTS:            
 **
 **      st              The return status of this routine.
 **
@@ -258,14 +258,14 @@ INTERNAL boolean32 rpc__schnauth_cn_three_way (void)
 **      information rep and RPC auth information rep will
 **      still be valid in 300 seconds, false if not.
 **
-**  SIDE EFFECTS:
+**  SIDE EFFECTS:       
 **
 **      The context may be renewed.
 **
 **--
 **/
 
-INTERNAL boolean32 rpc__schnauth_cn_context_valid
+INTERNAL boolean32 rpc__schnauth_cn_context_valid 
 #ifdef _DCE_PROTO_
 (
     rpc_cn_sec_context_p_t          sec,
@@ -314,7 +314,7 @@ unsigned32                      *st;
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      Create an auth information rep data structure with and
 **      add a reference to it. This is called on the server
 **      side. The fields will be initialized to NULL values.
@@ -329,7 +329,7 @@ unsigned32                      *st;
 **
 **  INPUTS/OUTPUTS:     none
 **
-**  OUTPUTS:
+**  OUTPUTS:            
 **
 **      info            A pointer to the auth information rep structure
 **                      containing RPC protocol indenpendent information.
@@ -341,14 +341,14 @@ unsigned32                      *st;
 **
 **  FUNCTION VALUE:     none
 **
-**  SIDE EFFECTS:
+**  SIDE EFFECTS:       
 **
 **      The newly create auth info will have a reference count of 1.
 **
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_create_info
+INTERNAL void rpc__schnauth_cn_create_info 
 #ifdef _DCE_PROTO_
 (
     rpc_authn_level_t                authn_level,
@@ -386,10 +386,10 @@ unsigned32                       *st;
     /*
      * Allocate storage for a noauth info structure from heap.
      */
-    RPC_MEM_ALLOC(schnauth_info,
-		  rpc_schnauth_info_p_t,
-		  sizeof (rpc_schnauth_info_t),
-		  RPC_C_MEM_SCHNAUTH_INFO,
+    RPC_MEM_ALLOC(schnauth_info, 
+		  rpc_schnauth_info_p_t, 
+		  sizeof (rpc_schnauth_info_t), 
+		  RPC_C_MEM_SCHNAUTH_INFO, 
 		  RPC_C_MEM_WAITOK);
 
     /*
@@ -422,7 +422,7 @@ unsigned32                       *st;
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      Determine whether the client's credentials stored in the
 **      security context are different from those in the auth info.
 **      If they are not the same return true, else false.
@@ -435,7 +435,7 @@ unsigned32                       *st;
 **
 **  INPUTS/OUTPUTS:     none
 **
-**  OUTPUTS:
+**  OUTPUTS:            
 **
 **      st              The return status of this routine.
 **
@@ -450,9 +450,9 @@ unsigned32                       *st;
 **      false if not.
 **
 **      The md5 checksum algorithm requires the use of the session key
-**      to encrypt the CRC(assoc_uuid).  Since the session key will
+**      to encrypt the CRC(assoc_uuid).  Since the session key will 
 **      change when the credential changes, this routine sets the flag
-**      indicating that a (potentially) valid encrypted crc is now
+**      indicating that a (potentially) valid encrypted crc is now 
 **      invalid, forcing a recomputation.
 **
 **  SIDE EFFECTS:       none
@@ -460,7 +460,7 @@ unsigned32                       *st;
 **--
 **/
 
-INTERNAL boolean32 rpc__schnauth_cn_cred_changed
+INTERNAL boolean32 rpc__schnauth_cn_cred_changed 
 #ifdef _DCE_PROTO_
 (
     rpc_cn_sec_context_p_t          sec,
@@ -472,9 +472,9 @@ rpc_cn_sec_context_p_t          sec;
 unsigned32                      *st;
 #endif
 {
-    rpc_schnauth_cn_info_t *schnauth_cn_info ATTRIBUTE_UNUSED;
-    rpc_schnauth_info_p_t   schnuth_info ATTRIBUTE_UNUSED;
-    boolean32               different_creds;
+  rpc_schnauth_cn_info_t          *schnauth_cn_info ATTRIBUTE_UNUSED;
+    rpc_schnauth_info_p_t         schnuth_info ATTRIBUTE_UNUSED;
+    boolean32                     different_creds;
 
     CODING_ERROR (st);
 
@@ -514,11 +514,11 @@ unsigned32                      *st;
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      Determine whether the client's credentials are still
 **      valid. If not this routine will try to renew the credentials.
 **      If they cannot be renewed an error is returned. This routine
-**      is called from the client side.
+**      is called from the client side. 
 **
 **  INPUTS:
 **
@@ -526,7 +526,7 @@ unsigned32                      *st;
 **
 **  INPUTS/OUTPUTS:     none
 **
-**  OUTPUTS:
+**  OUTPUTS:            
 **
 **      st              The return status of this routine.
 **
@@ -541,7 +541,7 @@ unsigned32                      *st;
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_cred_refresh
+INTERNAL void rpc__schnauth_cn_cred_refresh 
 #ifdef _DCE_PROTO_
 (
     rpc_auth_info_p_t               auth_info,
@@ -553,9 +553,8 @@ rpc_auth_info_p_t               auth_info;
 unsigned32                      *st;
 #endif
 {
-    rpc_schnauth_info_p_t schnauth_info;
-
-    schnauth_info = (rpc_schnauth_info_p_t)auth_info;
+    rpc_schnauth_cn_info_t        *schnauth_cn_info ATTRIBUTE_UNUSED;
+    rpc_schnauth_info_p_t         schnauth_info ATTRIBUTE_UNUSED;
 
     CODING_ERROR (st);
 
@@ -591,7 +590,7 @@ unsigned32                      *st;
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      This routine will format the auth_value field of
 **      either an rpc_bind or rpc_alter_context PDU. This is
 **      called from the client side association state machine.
@@ -606,14 +605,14 @@ unsigned32                      *st;
 **      auth_value      A pointer to the auth_value field in the rpc_bind or
 **                      rpc_alter_context PDU authentication trailer.
 **
-**  INPUTS/OUTPUTS:
+**  INPUTS/OUTPUTS:     
 **
 **      auth_value_len  On input, the lenght, in bytes of the available space
 **                      for the auth_value field. On output, the lenght in
 **                      bytes used in encoding the auth_value field. Zero if
 **                      an error status is returned.
 **
-**  OUTPUTS:
+**  OUTPUTS:            
 **
 **      st              The return status of this routine.
 **
@@ -628,7 +627,7 @@ unsigned32                      *st;
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_fmt_client_req
+INTERNAL void rpc__schnauth_cn_fmt_client_req 
 #ifdef _DCE_PROTO_
 (
    rpc_cn_assoc_sec_context_p_t      assoc_sec,
@@ -679,6 +678,17 @@ unsigned32                      * /* st */
         return;
     }
 #endif
+#if 0
+    if (*auth_value_len < RPC_CN_PKT_SIZEOF_BIND_AUTH_VAL)
+    {
+        *st = rpc_s_credentials_too_large;
+        return;
+    }
+    else
+    {
+        *auth_value_len = RPC_CN_PKT_SIZEOF_BIND_AUTH_VAL;
+    }
+#endif
 
     auth_info = sec->sec_cn_info;
     schnauth_info = (rpc_schnauth_cn_info_t*)auth_info;
@@ -702,7 +712,7 @@ unsigned32                      * /* st */
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      This routine will format the auth_value field of
 **      either an rpc_bind_ack or rpc_alter_context_response
 **      PDU. The authentication protocol encoding in the
@@ -732,7 +742,7 @@ unsigned32                      * /* st */
 **      auth_value      A pointer to the auth_value field in the rpc_bind or
 **                      rpc_alter_context PDU authentication trailer.
 **
-**  INPUTS/OUTPUTS:
+**  INPUTS/OUTPUTS:     
 **
 **      auth_value_len  On input, the length, in bytes of the available space
 **                      for the auth_value field. On output, the length in
@@ -752,7 +762,7 @@ unsigned32                      * /* st */
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_fmt_srvr_resp
+INTERNAL void rpc__schnauth_cn_fmt_srvr_resp 
 #ifdef _DCE_PROTO_
 (
     unsigned32                      verify_st,
@@ -817,20 +827,20 @@ unsigned32                      *auth_value_len;
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      This routine will free an NCA Connection RPC auth
 **      information rep.
 **
-**  INPUTS:
+**  INPUTS:             
 **
 **      info            A pointer to the auth information rep structure
 **                      containing RPC protocol indenpendent information.
 **
-**  INPUTS/OUTPUTS:
+**  INPUTS/OUTPUTS:     
 **
 **      cn_info         A pointer to the RPC auth information rep structure
 **                      containing NCA Connection specific
-**                      information. NULL on output.
+**                      information. NULL on output. 
 **
 **  OUTPUTS:            none
 **
@@ -845,15 +855,15 @@ unsigned32                      *auth_value_len;
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_free_prot_info
+INTERNAL void rpc__schnauth_cn_free_prot_info 
 #ifdef _DCE_PROTO_
 (
-    rpc_auth_info_p_t               info,
+    rpc_auth_info_p_t               info,    
     rpc_cn_auth_info_p_t            *cn_info
 )
 #else
 (info, cn_info)
-rpc_auth_info_p_t               info;
+rpc_auth_info_p_t               info;    
 rpc_cn_auth_info_p_t            *cn_info;
 #endif
 {
@@ -883,7 +893,7 @@ rpc_cn_auth_info_p_t            *cn_info;
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      This routine will create and return an NCA Connection
 **      RPC auth information rep.
 **
@@ -894,7 +904,7 @@ rpc_cn_auth_info_p_t            *cn_info;
 **
 **  INPUTS/OUTPUTS:     none
 **
-**  OUTPUTS:
+**  OUTPUTS:            
 **
 **      cn_info         A pointer to the RPC auth information rep structure
 **                      containing NCA Connection specific information.
@@ -911,7 +921,7 @@ rpc_cn_auth_info_p_t            *cn_info;
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_get_prot_info
+INTERNAL void rpc__schnauth_cn_get_prot_info 
 #ifdef _DCE_PROTO_
 (
     rpc_auth_info_p_t               info,
@@ -952,10 +962,10 @@ unsigned32                      *st;
     /*
      * Allocate storage for a schnauth cn info structure from heap.
      */
-    RPC_MEM_ALLOC (schnauth_cn_info,
-                   rpc_schnauth_cn_info_p_t,
-                   sizeof (rpc_schnauth_cn_info_t),
-                   RPC_C_MEM_SCHNAUTH_CN_INFO,
+    RPC_MEM_ALLOC (schnauth_cn_info, 
+                   rpc_schnauth_cn_info_p_t, 
+                   sizeof (rpc_schnauth_cn_info_t), 
+                   RPC_C_MEM_SCHNAUTH_CN_INFO, 
                    RPC_C_MEM_WAITOK);
 
     /*
@@ -984,7 +994,7 @@ unsigned32                      *st;
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      This routine will format the auth_value field of
 **      a call level PDU, namely an rpc_request, rpc_response
 **      rpc_fault, rpc_remote_alert or rpc_orphaned PDU. It will
@@ -1006,14 +1016,14 @@ unsigned32                      *st;
 **      auth_value      A pointer to the auth_value field in the rpc_bind or
 **                      rpc_alter_context PDU authentication trailer.
 **
-**  INPUTS/OUTPUTS:
+**  INPUTS/OUTPUTS:     
 **
 **      auth_value_len  On input, the lenght, in bytes of the available space
 **                      for the auth_value field. On output, the lenght in
 **                      bytes used in encoding the auth_value field. Zero if
 **                      an error status is returned.
 **
-**  OUTPUTS:
+**  OUTPUTS:            
 **
 **      st              The return status of this routine.
 **
@@ -1028,7 +1038,7 @@ unsigned32                      *st;
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_pre_call
+INTERNAL void rpc__schnauth_cn_pre_call 
 #ifdef _DCE_PROTO_
 (
     rpc_cn_assoc_sec_context_p_t    assoc_sec,
@@ -1073,6 +1083,36 @@ unsigned32                      *st;
         return;
     }
 #endif
+#if 0
+    if (sec->sec_info->authn_level >= rpc_c_authn_level_pkt)
+    {
+        if (*auth_value_len < RPC_CN_PKT_SIZEOF_AUTH_VAL_CKSM)
+        {
+            *st = rpc_s_credentials_too_large;
+            return;
+        }
+        else
+        {
+            *auth_value_len = RPC_CN_PKT_SIZEOF_AUTH_VAL_CKSM;
+        }
+    }
+    else
+    {
+        if (*auth_value_len < RPC_CN_PKT_SIZEOF_AUTH_VAL)
+        {
+            *st = rpc_s_credentials_too_large;
+            return;
+        }
+        else
+        {
+            *auth_value_len = RPC_CN_PKT_SIZEOF_AUTH_VAL;
+        }
+    }
+
+    priv_auth_value = (rpc_cn_auth_value_priv_t *)auth_value;
+    priv_auth_value->sub_type = RPC_C_CN_DCE_SUB_TYPE;
+    priv_auth_value->checksum_length = 0;
+#endif
 
     *auth_value_len = sizeof(rpc_cn_schnauth_tlr_t);
 
@@ -1084,15 +1124,15 @@ unsigned32                      *st;
  * Sign the packet prior to sending
  */
 
-INTERNAL void rpc__schnauth_cn_wrap_pdu
+INTERNAL void schn_sign_pdu
 #ifdef _DCE_PROTO_
 (
     rpc_cn_assoc_sec_context_p_t    assoc_sec ATTRIBUTE_UNUSED,
-    rpc_cn_sec_context_p_t          sec,
-    rpc_socket_iovec_p_t            iov,
-    unsigned32                      iovlen,
-    rpc_socket_iovec_p_t            out_iov,
-    unsigned32                      *st
+    rpc_cn_sec_context_p_t          sec ATTRIBUTE_UNUSED,
+    rpc_socket_iovec_p_t            iov ATTRIBUTE_UNUSED,
+    unsigned32                      iovlen ATTRIBUTE_UNUSED,
+    rpc_socket_iovec_p_t            out_iov ATTRIBUTE_UNUSED,
+    unsigned32                      *st ATTRIBUTE_UNUSED
 )
 #else
 (assoc_sec, sec, iov, iovlen, out_iov, st)
@@ -1105,13 +1145,16 @@ unsigned32                      *st;
 #endif
 {
     const unsigned32 hdr_idx = 0;
-    unsigned32 status = rpc_s_ok;
+#if 0
+    /* Testing blob */
+    const char *testing_blob = "RAFAL";
+    const unsigned32 testing_blob_len = 5;
+#endif
     rpc_schnauth_cn_info_p_t schn_auth;
     rpc_cn_common_hdr_p_t com_hdr;
     rpc_cn_auth_tlr_p_t com_tlr;
     rpc_cn_schnauth_tlr_p_t schn_tlr;
     unsigned32 tlr_idx;
-    unsigned32 part_idx;
     unsigned_char_p_t pdu_blob;
     unsigned32 pdu_blob_len;
     unsigned16 packet_len, stub_len, auth_pad_len;
@@ -1127,93 +1170,48 @@ unsigned32                      *st;
     tlr_idx = iovlen - 1;
     com_tlr = (rpc_cn_auth_tlr_p_t)(iov[tlr_idx].iov_base);
     schn_tlr = (rpc_cn_schnauth_tlr_p_t)(com_tlr->auth_value);
+
+    /* allocate the entire packet in one piece */
     com_hdr = (rpc_cn_common_hdr_p_t)(iov[hdr_idx].iov_base);
-
-
-    /*
-     * Calculate header + stub length (including initial padding)
-     */
-
-    part_idx = hdr_idx;
-    stub_len = 0;
-    while (part_idx < tlr_idx) {
-	stub_len += iov[part_idx++].iov_len;
-    }
-
-    stub_len -= RPC_CN_PKT_SIZEOF_RQST_HDR;
-
+    stub_len = com_hdr->frag_len - (RPC_CN_PKT_SIZEOF_RQST_HDR +
+				    RPC_CN_PKT_SIZEOF_COM_AUTH_TLR +
+				    sizeof(rpc_cn_schnauth_tlr_t));
     /* ensure auth trailer padding */
     auth_pad_len = stub_len % 0x0008;
-
-    /*
-     * Allocate the entire packet in one piece
-     */
-    packet_len = stub_len + (RPC_CN_PKT_SIZEOF_RQST_HDR +
-			     RPC_CN_PKT_SIZEOF_COM_AUTH_TLR +
-			     RPC_CN_PKT_SIZEOF_SCHNAUTH_TLR +
-			     auth_pad_len);
+    packet_len = com_hdr->frag_len + auth_pad_len;
 
     out_iov->iov_len = packet_len;
+
     RPC_MEM_ALLOC(out_iov->iov_base,
 		  pointer_t,
 		  out_iov->iov_len,
 		  RPC_C_MEM_SCHNAUTH_INFO,
 		  RPC_C_MEM_WAITOK);
-    if (out_iov->iov_base == NULL) {
-        *st = rpc_s_no_memory;
-	return;
-    }
-
     memset(out_iov->iov_base, 0, out_iov->iov_len);
 
-    /* Update packet and padding length after adding auth padding bytes */
-    com_hdr->frag_len        += auth_pad_len;
-    com_tlr->stub_pad_length += auth_pad_len;
-
-    /*
-     * Create the packet blob including auth trailer padding
-     */
+    com_hdr->frag_len = packet_len;
+    com_tlr->stub_pad_length = auth_pad_len;
 
+    /* create the packet blob including auth traile padding */
     base = out_iov->iov_base;
-
-    /* header [idx = 0] */
-    memcpy(base, (void*)com_hdr, RPC_CN_PKT_SIZEOF_COMMON_HDR);
-    base += RPC_CN_PKT_SIZEOF_COMMON_HDR;
-
-    /* stub [idx = 0] (the rest of it following header) */
-    memcpy(base, iov[hdr_idx].iov_base + RPC_CN_PKT_SIZEOF_COMMON_HDR,
-	   iov[hdr_idx].iov_len - RPC_CN_PKT_SIZEOF_COMMON_HDR);
-    base += iov[hdr_idx].iov_len - RPC_CN_PKT_SIZEOF_COMMON_HDR;
-
-    /* stub [idx = 1 .. (tlr_idx - 1)] (if there is any remaining part) */
-    part_idx = 1;
-    while (part_idx < tlr_idx) {
-	/* This packet is longer than 2 parts (header+stub and trailer)
-	   so make sure we copy all of them */
-	memcpy(base, iov[part_idx].iov_base, iov[part_idx].iov_len);
-	base += iov[part_idx].iov_len;
-	part_idx++;
-    }
-
-    /* auth padding */
-    base += auth_pad_len;
-
-    /* common trailer [idx = tlr_idx] */
+    memcpy(base, iov[hdr_idx].iov_base, iov[hdr_idx].iov_len);
+    base += iov[hdr_idx].iov_len + auth_pad_len;
     memcpy(base, (void*)com_tlr, RPC_CN_PKT_SIZEOF_COM_AUTH_TLR);
     base += RPC_CN_PKT_SIZEOF_COM_AUTH_TLR;
-
-    /* schannel trailer */
     memcpy(base, (void*)schn_tlr, RPC_CN_PKT_SIZEOF_SCHNAUTH_TLR);
-    base += RPC_CN_PKT_SIZEOF_SCHNAUTH_TLR;
 
-    /* set PDU blob pointer and length */
     pdu_blob = out_iov->iov_base + RPC_CN_PKT_SIZEOF_RQST_HDR;
     pdu_blob_len = stub_len + auth_pad_len;
 
-    /* set new location of common and schannel trailer */
     com_tlr = (rpc_cn_auth_tlr_p_t)(pdu_blob + pdu_blob_len);
     schn_tlr = (rpc_cn_schnauth_tlr_p_t)(com_tlr->auth_value);
 
+#if 0
+    /* HACK for testing */
+    memset(nonce, 0, sizeof(nonce));
+    nonce[0] = 1;
+#endif
+
     switch (com_tlr->auth_level) {
     case rpc_c_protect_level_pkt_integ:
         sec_level = SCHANNEL_SEC_LEVEL_INTEGRITY;
@@ -1224,14 +1222,15 @@ unsigned32                      *st;
 	break;
 
     default:
-	*st = rpc_s_unsupported_protect_level;
+	/* TODO: unsupported authz level ? */
+	*st = -1;
 	return;
     }
 
     input_token.base = (uint8*)pdu_blob;
     input_token.len  = pdu_blob_len;
 
-    status = schn_wrap(schn_ctx, sec_level, &input_token, &output_token, &tail);
+    schn_wrap(schn_ctx, sec_level, &input_token, &output_token, &tail);
 
     memcpy(pdu_blob, output_token.base, output_token.len);
 
@@ -1240,9 +1239,7 @@ unsigned32                      *st;
     memcpy(schn_tlr->seq_number, tail.seq_number, 8);
     memcpy(schn_tlr->nonce, tail.nonce, 8);
 
-    schn_free_blob(&output_token);
-
-    *st = status;
+    *st = rpc_s_ok;
 }
 
 
@@ -1255,15 +1252,15 @@ unsigned32                      *st;
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      This routine will perform per-packet security
 **      processing on a packet before it is sent. This
 **      includes checksumming and encryption.
 **
 **      Note that in some cases, the data is copied to
-**      a contiguous buffer for checksumming and
+**      a contiguous buffer for checksumming and 
 **      encryption.  In these cases, the contiguous
-**      iov element should be used instead of the original
+**      iov element should be used instead of the original 
 **      iovector.
 **
 **  INPUTS:
@@ -1275,7 +1272,7 @@ unsigned32                      *st;
 **                      information rep.
 **      iov             A pointer to the iovector containing the PDU
 **                      about to be sent. The appropriate per-packet security
-**                      services will be applied to it.
+**                      services will be applied to it. 
 **      iovlen          The length, in bytes, of the PDU.
 **      out_iov         An iovector element.  This iovector element
 **                      will describe packet if the original iov
@@ -1284,7 +1281,7 @@ unsigned32                      *st;
 **
 **  INPUTS/OUTPUTS:     none
 **
-**  OUTPUTS:
+**  OUTPUTS:            
 **
 **      st              The return status of this routine.
 **
@@ -1299,14 +1296,14 @@ unsigned32                      *st;
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_pre_send
+INTERNAL void rpc__schnauth_cn_pre_send 
 #ifdef _DCE_PROTO_
 (
     rpc_cn_assoc_sec_context_p_t    assoc_sec,
     rpc_cn_sec_context_p_t          sec,
     rpc_socket_iovec_p_t            iov,
-    unsigned32                      iovlen,
-    rpc_socket_iovec_p_t            out_iov,
+    unsigned32                      iovlen ATTRIBUTE_UNUSED,
+    rpc_socket_iovec_p_t            out_iov ATTRIBUTE_UNUSED,
     unsigned32                      *st
 )
 #else
@@ -1355,8 +1352,8 @@ unsigned32                      *st;
         case RPC_C_CN_PKT_REQUEST:
         case RPC_C_CN_PKT_RESPONSE:
         {
-            rpc__schnauth_cn_wrap_pdu(assoc_sec, sec, iov, iovlen, out_iov, st);
-            return;
+            schn_sign_pdu(assoc_sec, sec, iov, iovlen, out_iov, st);
+            break;
         }
 
         case RPC_C_CN_PKT_FAULT:
@@ -1379,17 +1376,17 @@ unsigned32                      *st;
 }
 
 
-INTERNAL void rpc__schnauth_cn_unwrap_pdu
+INTERNAL void schn_check_signature
 #ifdef _DCE_PROTO_
 (
     rpc_cn_assoc_sec_context_p_t    assoc_sec ATTRIBUTE_UNUSED,
-    rpc_cn_sec_context_p_t          sec,
-    rpc_cn_common_hdr_p_t           pdu,
-    unsigned32                      pdu_len,
-    unsigned32                      cred_len,
-    rpc_cn_auth_tlr_p_t             auth_tlr,
+    rpc_cn_sec_context_p_t          sec ATTRIBUTE_UNUSED,
+    rpc_cn_common_hdr_p_t           pdu ATTRIBUTE_UNUSED,
+    unsigned32                      pdu_len ATTRIBUTE_UNUSED,
+    unsigned32                      cred_len ATTRIBUTE_UNUSED,
+    rpc_cn_auth_tlr_p_t             auth_tlr ATTRIBUTE_UNUSED,
     boolean32                       unpack_ints ATTRIBUTE_UNUSED,
-    unsigned32                      *st
+    unsigned32                      *st ATTRIBUTE_UNUSED
 )
 #else
 (assoc_sec, sec, pdu, pdu_len, cred_len, auth_tlr, unpack_ints, st)
@@ -1403,7 +1400,7 @@ boolean32                       unpack_ints;
 unsigned32                      *st;
 #endif
 {
-    unsigned32 status = rpc_s_ok;
+    unsigned32 status = 0;
     rpc_schnauth_cn_info_p_t schn_auth;
     rpc_cn_schnauth_tlr_p_t schn_tlr;
     unsigned32 sec_level;
@@ -1424,7 +1421,8 @@ unsigned32                      *st;
 	break;
 
     default:
-	*st = rpc_s_unsupported_protect_level;
+	/* TODO: unsupported authz level ? */
+	*st = -1;
 	return;
     }
 
@@ -1433,7 +1431,7 @@ unsigned32                      *st;
     input_token.base = (uint8*)(pdu) + RPC_CN_PKT_SIZEOF_RESP_HDR;
     input_token.len  = pdu_len - (RPC_CN_PKT_SIZEOF_RESP_HDR +
 				  RPC_CN_PKT_SIZEOF_COM_AUTH_TLR +
-				  RPC_CN_PKT_AUTH_LEN((rpc_cn_packet_p_t) pdu));
+				  RPC_CN_PKT_SIZEOF_SCHNAUTH_TLR);
 
     output_token.base = NULL;
     output_token.len  = 0;
@@ -1447,7 +1445,6 @@ unsigned32                      *st;
 			 &tail);
 
     memcpy(input_token.base, output_token.base, output_token.len);
-    schn_free_blob(&output_token);
 
     *st = status;
 }
@@ -1462,7 +1459,7 @@ unsigned32                      *st;
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      This routine will perform per-packet security
 **      processing on a packet after it is received. This
 **      includes decryption and verification of checksums.
@@ -1485,7 +1482,7 @@ unsigned32                      *st;
 **
 **  INPUTS/OUTPUTS:     none
 **
-**  OUTPUTS:
+**  OUTPUTS:            
 **
 **      st              The return status of this routine.
 **
@@ -1500,7 +1497,7 @@ unsigned32                      *st;
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_recv_check
+INTERNAL void rpc__schnauth_cn_recv_check 
 #ifdef _DCE_PROTO_
 (
     rpc_cn_assoc_sec_context_p_t    assoc_sec,
@@ -1573,8 +1570,8 @@ unsigned32                      *st;
         case RPC_C_CN_PKT_REQUEST:
         case RPC_C_CN_PKT_RESPONSE:
 	{
-	    rpc__schnauth_cn_unwrap_pdu(assoc_sec, sec, pdu, pdu_len, cred_len,
-					auth_tlr, unpack_ints, st);
+	    schn_check_signature(assoc_sec, sec, pdu, pdu_len, cred_len,
+				 auth_tlr, unpack_ints, st);
         }
         case RPC_C_CN_PKT_FAULT:
         case RPC_C_CN_PKT_BIND:
@@ -1604,7 +1601,7 @@ unsigned32                      *st;
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      This routine will locate and return the association
 **      UUID CRC contained in the auth_value field of an
 **      authentication trailer of an rpc_bind, rpc_bind_ack,
@@ -1618,7 +1615,7 @@ unsigned32                      *st;
 **
 **  INPUTS/OUTPUTS:     none
 **
-**  OUTPUTS:
+**  OUTPUTS:            
 **
 **      assoc_uuid_crc  The association UUID CRC contained in the auth_value
 **                      field.
@@ -1634,7 +1631,7 @@ unsigned32                      *st;
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_tlr_uuid_crc
+INTERNAL void rpc__schnauth_cn_tlr_uuid_crc 
 #ifdef _DCE_PROTO_
 (
     pointer_t               auth_value,
@@ -1670,7 +1667,7 @@ unsigned32              *uuid_crc;
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      This routine will byte swap all the appropriate fields
 **      of the the auth_value field of an authentication
 **      trailer. It will also convert any characters from
@@ -1684,7 +1681,7 @@ unsigned32              *uuid_crc;
 **                      RunTime Extensions Specification Version OSF TX1.0.9
 **                      pre 1003 for details), of the remote machine.
 **
-**  INPUTS/OUTPUTS:
+**  INPUTS/OUTPUTS:     
 **
 **      pkt_p           A pointer to the entire packet.
 **
@@ -1701,7 +1698,7 @@ unsigned32              *uuid_crc;
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_tlr_unpack
+INTERNAL void rpc__schnauth_cn_tlr_unpack 
 #ifdef _DCE_PROTO_
 (
     rpc_cn_packet_p_t       pkt_p ATTRIBUTE_UNUSED,
@@ -1709,7 +1706,7 @@ INTERNAL void rpc__schnauth_cn_tlr_unpack
     unsigned8               *packed_drep ATTRIBUTE_UNUSED
 )
 #else
-(pkt_p, auth_value_len, packed_drep)
+(pkt_p, auth_value_len, packed_drep) 
 rpc_cn_packet_p_t       pkt_p;
 unsigned32              auth_value_len;
 unsigned8               *packed_drep;
@@ -1728,7 +1725,7 @@ unsigned8               *packed_drep;
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      This routine will decode the auth_value field of
 **      either an rpc_bind or rpc_alter_context PDU. Any
 **      error encountered while authenticating the client
@@ -1752,7 +1749,7 @@ unsigned8               *packed_drep;
 **
 **  INPUTS/OUTPUTS:     none
 **
-**  OUTPUTS:
+**  OUTPUTS:            
 **
 **      st              The return status of this routine.
 **
@@ -1767,7 +1764,7 @@ unsigned8               *packed_drep;
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_vfy_client_req
+INTERNAL void rpc__schnauth_cn_vfy_client_req 
 #ifdef _DCE_PROTO_
 (
     rpc_cn_assoc_sec_context_p_t    assoc_sec,
@@ -1795,7 +1792,7 @@ unsigned32                      * /* st */
                     ("(rpc__schnauth_cn_vfy_client_req)\n"));
 
     priv_auth_value = (rpc_cn_bind_auth_value_priv_t *)auth_value;
-
+    
     RPC_DBG_PRINTF (rpc_e_dbg_auth, RPC_C_CN_DBG_AUTH_PKT,
                     ("(rpc__schnauth_cn_vfy_client_req) prot->%x level->%x key_id->%x assoc_uuid_crc->%x xmit_seq->%x recv_seq->%x\n",
                     rpc_c_authn_dce_dummy,
@@ -1826,7 +1823,7 @@ unsigned32                      * /* st */
 **  SCOPE:              INTERNAL - declared locally
 **
 **  DESCRIPTION:
-**
+**      
 **      This routine will decode auth_value field either an
 **      rpc_bind_ack or rpc_alter_context_response PDU. If the
 **      credentials field of the auth_value field contains an
@@ -1850,7 +1847,7 @@ unsigned32                      * /* st */
 **
 **  INPUTS/OUTPUTS:     none
 **
-**  OUTPUTS:
+**  OUTPUTS:            
 **
 **      st              The return status of this routine.
 **
@@ -1865,7 +1862,7 @@ unsigned32                      * /* st */
 **--
 **/
 
-INTERNAL void rpc__schnauth_cn_vfy_srvr_resp
+INTERNAL void rpc__schnauth_cn_vfy_srvr_resp 
 #ifdef _DCE_PROTO_
 (
     rpc_cn_assoc_sec_context_p_t    assoc_sec,
@@ -1875,7 +1872,7 @@ INTERNAL void rpc__schnauth_cn_vfy_srvr_resp
     unsigned32                      *st
 )
 #else
-(assoc_sec, sec, auth_value, auth_value_len, st)
+(assoc_sec, sec, auth_value, auth_value_len, st) 
 rpc_cn_assoc_sec_context_p_t    assoc_sec;
 rpc_cn_sec_context_p_t          sec;
 pointer_t                       auth_value;
@@ -1911,7 +1908,7 @@ unsigned32                      *st;
 }
 
 
-PRIVATE rpc_protocol_id_t       rpc__schnauth_cn_init
+PRIVATE rpc_protocol_id_t       rpc__schnauth_cn_init 
 #ifdef _DCE_PROTO_
 (
     rpc_auth_rpc_prot_epv_p_t       *epv,
