@@ -35,7 +35,6 @@
 #include "djtimemgmt.h"
 #include "djcli.h"
 #include "djfirewall.h"
-#include "djauditing.h"
 #include "ctprocutils.h"
 #include "lwexc.h"
 
@@ -66,11 +65,7 @@ ShowUsage()
     fprintf(stdout, "    --log {.|path}                             Log to a file (or \".\" to log\n"
                     "                                               to console).\n");
     fprintf(stdout, "    --loglevel {error|warning|info|verbose}    Adjusts how much logging is\n"
-                    "                                               produced by domainjoin.\n");
-    fprintf(stdout, "    --nodcerpcd                                prevents dcerpcd from being\n"
-                    "                                               started, along with any daemons\n"
-                    "                                               that depend on it.\n");
-    fprintf(stdout, "\n");
+                    "                                               produced by domainjoin.\n\n");
     fprintf(stdout, "  and commands are:\n\n");
     fprintf(stdout, "    query\n");
     fprintf(stdout, "    setname <computer name>\n");
@@ -93,13 +88,11 @@ ShowUsageInternal()
 
     fprintf(stdout, "  Internal debug commands:\n");
     fprintf(stdout, "    fixfqdn\n");
-    fprintf(stdout, "    configure { --enable | --disable } pam [--testprefix <dir>]\n");
-    fprintf(stdout, "    configure { --enable | --disable } nsswitch [--testprefix <dir>]\n");
-    fprintf(stdout, "    configure { --enable | --disable } ssh [--testprefix <dir>]\n");
-    fprintf(stdout, "    configure { --enable | --disable } [--testprefix <dir>] [--long <longdomain>] [--short <shortdomain>] krb5\n");
-    fprintf(stdout, "    configure { --enable | --disable } firewall [--testprefix <dir>]\n");
-    fprintf(stdout, "    configure { --enable | --disable } eventfwdd\n");
-    fprintf(stdout, "    configure { --enable | --disable } reapsysld\n");
+    fprintf(stdout, "    configure pam [--testprefix <dir>] { --enable | --disable }\n");
+    fprintf(stdout, "    configure nsswitch [--testprefix <dir>] { --enable | --disable }\n");
+    fprintf(stdout, "    configure ssh [--testprefix <dir>] { --enable | --disable }\n");
+    fprintf(stdout, "    configure krb5 [--testprefix <dir>] [--long <longdomain>] [--short <shortdomain>] { --enable | --disable }\n");
+    fprintf(stdout, "    configure firewall [--testprefix <dir>] { --enable | --disable }\n");
     fprintf(stdout, "    get_os_type\n");
     fprintf(stdout, "    get_arch\n");
     fprintf(stdout, "    get_distro\n");
@@ -118,23 +111,12 @@ FillMissingPassword(
 {
     CENTERROR ceError = CENTERROR_SUCCESS;
     PSTR pszPassword = NULL;
-    PCSTR pszEnvPassword = NULL;
 
-    pszEnvPassword = getenv("PASSWORD");
-    if (pszEnvPassword == NULL)
-    {
-        fprintf(stdout, "%s's password: ",username);
-        fflush(stdout);
-        ceError = GetPassword(&pszPassword);
-        BAIL_ON_CENTERIS_ERROR(ceError);
-        fprintf(stdout, "\n");
-    }
-    else
-    {
-        DJ_LOG_WARNING("Retrieved password from envionmental variable");
-        ceError = CTStrdup(pszEnvPassword, &pszPassword);
-        BAIL_ON_CENTERIS_ERROR(ceError);
-    }
+    fprintf(stdout, "%s's password: ",username);
+    fflush(stdout);
+    ceError = GetPassword(&pszPassword);
+    BAIL_ON_CENTERIS_ERROR(ceError);
+    fprintf(stdout, "\n");
 
     if (!IsNullOrEmptyString(pszPassword)) {
         *ppszPassword = pszPassword;
@@ -301,7 +283,6 @@ void DoJoin(int argc, char **argv, int columns, LWException **exc)
     DynamicArray enableModules, disableModules;
     DynamicArray detailModules;
     size_t i;
-    int passwordIndex = -1;
     PSTR moduleDetails = NULL;
     PSTR wrapped = NULL;
 
@@ -317,9 +298,7 @@ void DoJoin(int argc, char **argv, int columns, LWException **exc)
         else if(!strcmp(argv[0], "--preview"))
             preview = TRUE;
         else if(!strcmp(argv[0], "--ignore-firewall-ntp"))
-        {
-            printf("Warning: --ignore-firewall-ntp is deprecated. This behavior is now default.\n");
-        }
+            options.ignoreFirewallNtp = TRUE;
         else if(!strcmp(argv[0], "--ignore-pam"))
             options.ignorePam = TRUE;
         else if(!strcmp(argv[0], "--notimesync"))
@@ -369,10 +348,7 @@ void DoJoin(int argc, char **argv, int columns, LWException **exc)
     }
 
     if(argc == 3)
-    {
         LW_CLEANUP_CTERR(exc, CTStrdup(argv[2], &options.password));
-        passwordIndex = 2;
-    }
     // The join username is not required in preview or details mode.
     else if(argc == 1 && (preview || detailModules.size != 0) )
         ;
@@ -383,12 +359,6 @@ void DoJoin(int argc, char **argv, int columns, LWException **exc)
     }
     options.joiningDomain = TRUE;
 
-    DJ_LOG_INFO("Domainjoin invoked with %d arg(s) to the join command:", argc);
-    for(i = 0; i < argc; i++)
-    {
-        DJ_LOG_INFO("    [%s]", i == passwordIndex ? "<password>" : argv[i]);
-    }
-
     LW_CLEANUP_CTERR(exc, CTStrdup(
         argv[0], &options.domainName));
     if(argc > 1)
@@ -498,7 +468,6 @@ void DoLeaveNew(int argc, char **argv, int columns, LWException **exc)
     size_t i;
     PSTR moduleDetails = NULL;
     PSTR wrapped = NULL;
-    int passwordIndex = -1;
 
     DJZeroJoinProcessOptions(&options);
     memset(&enableModules, 0, sizeof(enableModules));
@@ -544,10 +513,7 @@ void DoLeaveNew(int argc, char **argv, int columns, LWException **exc)
     }
 
     if(argc == 2)
-    {
         LW_CLEANUP_CTERR(exc, CTStrdup(argv[1], &options.password));
-        passwordIndex = 1;
-    }
     else if(argc > 2)
     {
         LW_RAISE(exc, CENTERROR_DOMAINJOIN_SHOW_USAGE);
@@ -555,12 +521,6 @@ void DoLeaveNew(int argc, char **argv, int columns, LWException **exc)
     }
     options.joiningDomain = FALSE;
 
-    DJ_LOG_INFO("Domainjoin invoked with %d arg(s) to the leave command:", argc);
-    for(i = 0; i < argc; i++)
-    {
-        DJ_LOG_INFO("    [%s]", i == passwordIndex ? "<password>" : argv[i]);
-    }
-
     if(argc > 0)
     {
         LW_CLEANUP_CTERR(exc, CTStrdup(argv[0], &options.username));
@@ -658,7 +618,6 @@ cleanup:
     CT_SAFE_FREE_STRING(wrapped);
 }
 
-#ifndef ENABLE_MINIMAL
 void DoConfigure(int argc, char **argv, LWException **exc)
 {
     EnableType dwEnable = ENABLE_TYPE_AUTO;
@@ -721,10 +680,8 @@ void DoConfigure(int argc, char **argv, LWException **exc)
     else if(!strcmp(argv[0], "krb5"))
         LW_CLEANUP_CTERR(exc, DJModifyKrb5Conf(testPrefix,
             GetEnableBoolean(dwEnable), longDomain, shortDomain, NULL));
-    else if(!strcmp(argv[0], "eventfwdd"))
-        LW_CLEANUP_CTERR(exc, DJConfigureEventFwd(testPrefix, GetEnableBoolean(dwEnable)));
-    else if(!strcmp(argv[0], "reapsysld"))
-        LW_CLEANUP_CTERR(exc, DJConfigureReapSyslog(testPrefix, GetEnableBoolean(dwEnable)));
+    else if(!strcmp(argv[0], "firewall"))
+        LW_CLEANUP_CTERR(exc, DJConfigureFirewallForAuth(testPrefix, GetEnableBoolean(dwEnable)));
     else
     {
         LW_RAISE(exc, CENTERROR_DOMAINJOIN_SHOW_USAGE);
@@ -734,14 +691,13 @@ void DoConfigure(int argc, char **argv, LWException **exc)
 cleanup:
     ;
 }
-#endif
 
 void DoGetDistroInfo(int argc, char **argv, LWException **exc)
 {
     PSTR str = NULL;
     PCSTR requestType = argv[0];
     PCSTR testPrefix = NULL;
-    DistroInfo distro = {0};
+    DistroInfo distro;
 
     argc--;
     argv++;
@@ -800,7 +756,6 @@ int main(
     DWORD dwLogLevel;
     BOOLEAN showHelp = FALSE;
     BOOLEAN showInternalHelp = FALSE;
-    BOOLEAN bEnableDcerpcd = TRUE;
     int remainingArgs = argc;
     char **argPos = argv;
     int i;
@@ -835,8 +790,6 @@ int main(
             logLevel = (++argPos)[0];
             remainingArgs--;
         }
-        else if (!strcmp(argPos[0], "--nodcerpcd"))
-            bEnableDcerpcd = FALSE;
         else
             break;
         remainingArgs--;
@@ -885,22 +838,10 @@ int main(
         LW_CLEANUP_CTERR(&exc, ceError);
     }
 
-    if (!strcmp(argPos[0], "join") || !strcmp(argPos[0], "leave"))
+    DJ_LOG_INFO("Domainjoin invoked with %d arg(s):", argc);
+    for(i = 0; i < argc; i++)
     {
-        DJ_LOG_INFO("Domainjoin invoked with the %s command (remaining arguments will be printed later):", argPos[0]);
-        // Only print up to the 'join' part
-        for (i = 0; i <= argPos - argv; i++)
-        {
-            DJ_LOG_INFO("    [%s]", argv[i]);
-        }
-    }
-    else
-    {
-        DJ_LOG_INFO("Domainjoin invoked with %d arg(s):", argc);
-        for (i = 0; i < argc; i++)
-        {
-            DJ_LOG_INFO("    [%s]", argv[i]);
-        }
+        DJ_LOG_INFO("    [%s]", argv[i]);
     }
 
     if(!strcmp(argPos[0], "setname"))
@@ -912,10 +853,9 @@ int main(
             goto cleanup;
         }
         //Needed so that DJGetMachineSid does not call winbind
-        LW_TRY(&exc, DJNetInitialize(bEnableDcerpcd, &LW_EXC));
+        LW_TRY(&exc, DJNetInitialize(&LW_EXC));
         LW_TRY(&exc, DJSetComputerName(argPos[0], NULL, &LW_EXC));
     }
-#ifndef ENABLE_MINIMAL
     else if(!strcmp(argPos[0], "sync_time"))
     {
         unsigned int allowedDrift;
@@ -928,36 +868,33 @@ int main(
         LW_CLEANUP_CTERR(&exc, ParseUInt(argPos[1], &allowedDrift));
         LW_CLEANUP_CTERR(&exc, DJSyncTimeToDC(argPos[0], allowedDrift));
     }
-#endif
     else if(!strcmp(argPos[0], "join"))
     {
         argPos++;
         remainingArgs--;
-        LW_TRY(&exc, DJNetInitialize(bEnableDcerpcd, &LW_EXC));
+        LW_TRY(&exc, DJNetInitialize(&LW_EXC));
         LW_TRY(&exc, DoJoin(remainingArgs, argPos, columns, &LW_EXC));
     }
     else if(!strcmp(argPos[0], "leave"))
     {
         argPos++;
         remainingArgs--;
-        LW_TRY(&exc, DJNetInitialize(bEnableDcerpcd, &LW_EXC));
+        LW_TRY(&exc, DJNetInitialize(&LW_EXC));
         LW_TRY(&exc, DoLeaveNew(remainingArgs, argPos, columns, &LW_EXC));
     }
     else if(!strcmp(argPos[0], "query"))
     {
-        LW_TRY(&exc, DJNetInitialize(bEnableDcerpcd, &LW_EXC));
+        LW_TRY(&exc, DJNetInitialize(&LW_EXC));
         LW_TRY(&exc, DoQuery(&LW_EXC));
     }
     else if(!strcmp(argPos[0], "fixfqdn"))
         LW_TRY(&exc, DoFixFqdn(&LW_EXC));
-#ifndef ENABLE_MINIMAL
     else if(!strcmp(argPos[0], "configure"))
     {
         argPos++;
         remainingArgs--;
         LW_TRY(&exc, DoConfigure(remainingArgs, argPos, &LW_EXC));
     }
-#endif
     else if(!strcmp(argPos[0], "get_os_type") ||
         !strcmp(argPos[0], "get_arch") ||
         !strcmp(argPos[0], "get_distro") ||
