@@ -41,7 +41,6 @@ typedef enum _QueryResult
     SufficientlyConfigured,
     FullyConfigured,
     NotApplicable,
-    ApplePluginInUse
 } QueryResult;
 
 struct _JoinModule;
@@ -77,6 +76,7 @@ struct _JoinProcessOptions
     BOOLEAN joiningDomain;
     BOOLEAN showTraces;
     BOOLEAN disableTimeSync;
+    BOOLEAN ignoreFirewallNtp;
     BOOLEAN ignorePam;
     WarningFunction warningCallback;
     /* Contains modules that are enabled and disabled by the user, but does
