@@ -199,7 +199,6 @@ cleanup:
     CT_SAFE_FREE_STRING(initDir);
     CT_SAFE_FREE_STRING(daemonPath);
     CT_SAFE_FREE_STRING(altDaemonName);
-    CT_SAFE_FREE_STRING(statusBuffer);
 }
 
 static void FindDaemonScript(PCSTR name, PSTR *path, LWException **exc)
@@ -568,8 +567,6 @@ DJConfigureForDaemonRestart(
     DistroInfo distro;
     PSTR symlinkTarget = NULL;
     PSTR symlinkName = NULL;
-    long status = 0;
-    PSTR statusBuffer = NULL;
 
     memset(&distro, 0, sizeof(distro));
 
@@ -700,142 +697,11 @@ DJConfigureForDaemonRestart(
                         directories, pszDaemonName, &LW_EXC));
         }
     }
-    else if(distro.os == OS_SUNOS)
-    {
-        BOOLEAN bUsesSVCS = FALSE;
-
-        LW_CLEANUP_CTERR(exc, CTCheckFileExists("/usr/sbin/svcadm", &bUsesSVCS));
-        if (bUsesSVCS)
-        {
-            /* On newer Solaris system, in order for a daemon to start in multi-user mode,
-             * we need to register our daemons with the service manager (svcs).
-             *
-             * To add:
-             * svccfg import /etc/likewise/svcs-solaris/<daemon name>.xml
-             * svcadm enable <daemon name>
-             *
-             * To remove:
-             * svcadm disable <daemon name>
-             * svccfg delete  <daemon name>
-             */
-            if(bStatus)
-            {
-                LW_CLEANUP_CTERR(exc, CTShell("/usr/sbin/svccfg import /etc/likewise/svcs-solaris/%daemonName.xml >/dev/null 2>&1; echo $? >%statusBuffer",
-                            CTSHELL_STRING(daemonName, pszDaemonName),
-                            CTSHELL_BUFFER(statusBuffer, &statusBuffer)));
-
-                status = atol(statusBuffer);
-
-                CT_SAFE_FREE_STRING(statusBuffer);
-                statusBuffer = NULL;
-
-                DJ_LOG_INFO("Daemon [%s]: svccfg import /etc/likewise/svcs-solaris/%s.xml status [%d]", pszDaemonName, pszDaemonName, status);
-
-                if (status) {
-                    LW_RAISE_EX(exc, CENTERROR_DOMAINJOIN_INCORRECT_STATUS, "svccfg import failed", "An error occurred while using svccfg to process the '%s' daemon. This daemon was being added to the list of processes to start on reboot.", pszDaemonName);
-                    goto cleanup;
-                }
-
-                LW_CLEANUP_CTERR(exc, CTShell("/usr/sbin/svcadm enable %daemonName >/dev/null 2>&1; echo $? >%statusBuffer",
-                            CTSHELL_STRING(daemonName, pszDaemonName),
-                            CTSHELL_BUFFER(statusBuffer, &statusBuffer)));
-
-                status = atol(statusBuffer);
-
-                DJ_LOG_INFO("Daemon [%s]: svcadm enable %s status [%d]", pszDaemonName, pszDaemonName, status);
-
-                if (status) {
-                    LW_RAISE_EX(exc, CENTERROR_DOMAINJOIN_INCORRECT_STATUS, "svcadm enable failed", "An error occurred while using svcadm to process the '%s' daemon. This daemon was being added to the list of processes to start on reboot.", pszDaemonName);
-                    goto cleanup;
-                }
-            }
-            else
-            {
-                LW_CLEANUP_CTERR(exc, CTShell("/usr/sbin/svcadm disable %daemonName >/dev/null 2>&1; echo $? >%statusBuffer",
-                            CTSHELL_STRING(daemonName, pszDaemonName),
-                            CTSHELL_BUFFER(statusBuffer, &statusBuffer)));
-
-                status = atol(statusBuffer);
-
-                CT_SAFE_FREE_STRING(statusBuffer);
-                statusBuffer = NULL;
-
-                DJ_LOG_INFO("Daemon [%s]: svcadm disable %s status [%d]", pszDaemonName, pszDaemonName, status);
-
-                LW_CLEANUP_CTERR(exc, CTShell("/usr/sbin/svccfg delete %daemonName >/dev/null 2>&1; echo $? >%statusBuffer",
-                            CTSHELL_STRING(daemonName, pszDaemonName),
-                            CTSHELL_BUFFER(statusBuffer, &statusBuffer)));
-
-                status = atol(statusBuffer);
-
-                DJ_LOG_INFO("Daemon [%s]: svccfg delete %s status [%d]", pszDaemonName, pszDaemonName, status);
-            }
-        }
-        else
-        {
-            /* On older Solaris system, in order for a daemon to start in multi-user mode,
-             * a start symlink must be put in /etc/rc2.d, and a stop symlink
-             * must be put in /etc/rc0.d, /etc/rc1.d, /etc/rcS.d.
-             */
-            if(bStatus)
-            {
-                PCSTR relativeName = strrchr(pszDaemonName, '/');
-
-                if (relativeName == NULL)
-                {
-                    relativeName = pszDaemonName;
-                }
-                else
-                {
-                    relativeName++;
-                }
-
-                LW_TRY(exc, FindDaemonScript(pszDaemonName,
-                            &symlinkTarget, &LW_EXC));
-                LW_CLEANUP_CTERR(exc, CTAllocateStringPrintf(&symlinkName,
-                        "/etc/rc0.d/K%02d%s", stopPriority, relativeName));
-                LW_TRY(exc,
-                        DJOverwriteSymlink(symlinkTarget, symlinkName, &LW_EXC));
-                CT_SAFE_FREE_STRING(symlinkName);
-
-                LW_CLEANUP_CTERR(exc, CTAllocateStringPrintf(&symlinkName,
-                        "/etc/rc1.d/K%02d%s", stopPriority, relativeName));
-                LW_TRY(exc,
-                        DJOverwriteSymlink(symlinkTarget, symlinkName, &LW_EXC));
-                CT_SAFE_FREE_STRING(symlinkName);
-
-                LW_CLEANUP_CTERR(exc, CTAllocateStringPrintf(&symlinkName,
-                        "/etc/rcS.d/K%02d%s", stopPriority, relativeName));
-                LW_TRY(exc,
-                        DJOverwriteSymlink(symlinkTarget, symlinkName, &LW_EXC));
-                CT_SAFE_FREE_STRING(symlinkName);
-
-                LW_CLEANUP_CTERR(exc, CTAllocateStringPrintf(&symlinkName,
-                        "/etc/rc2.d/S%02d%s", startPriority, relativeName));
-                LW_TRY(exc,
-                        DJOverwriteSymlink(symlinkTarget, symlinkName, &LW_EXC));
-            }
-            else
-            {
-                /* Remove any symlinks to the daemon if they exist */
-                PCSTR directories[] = {
-                    "/etc/rc0.d",
-                    "/etc/rc1.d",
-                    "/etc/rc2.d",
-                    "/etc/rc3.d",
-                    "/etc/rcS.d",
-                    NULL };
-                LW_TRY(exc, DJRemoveDaemonLinksInDirectories(
-                            directories, pszDaemonName, &LW_EXC));
-            }
-        }
-    }
 
 done:
 cleanup:
     CT_SAFE_FREE_STRING(symlinkTarget);
     CT_SAFE_FREE_STRING(symlinkName);
-    CT_SAFE_FREE_STRING(statusBuffer);
 }
 
 void
@@ -894,35 +760,31 @@ DJManageDaemon(
 {
     BOOLEAN bStarted = FALSE;
 
-    // Check for the existence of the daemon prior to doing anything.
-    // notice that we are using the private version so that if we fail,
-    // our inner exception will be the one that was tossed due to the failure.
+    // check our current state prior to doing anything.  notice that
+    // we are using the private version so that if we fail, our inner
+    // exception will be the one that was tossed due to the failure.
     LW_TRY(exc, DJGetDaemonStatus(pszName, &bStarted, &LW_EXC));
 
-    // Verify that daemon is configured as needed for running after restart,
-    // this also sets up any service control manager settings. On newer
-    // Solaris systems, the service control manager will start/stop the
-    // daemon as a result of the service configuration. It is okay to have
-    // this function called more than once for a given daemon, if it is already
-    // running or stopped it will remain the same with the same service pid.
-    LW_TRY(exc, DJConfigureForDaemonRestart(pszName, bStatus, startPriority, stopPriority, &LW_EXC));
+    // if we got this far, we have validated the existence of the
+    // daemon and we have figured out if its started or stopped
 
-    // Reverify the daemon status now, it may be started or stopped as needed by the step above.
-    LW_TRY(exc, DJGetDaemonStatus(pszName, &bStarted, &LW_EXC));
-
-    // If we are already in the desired state, do nothing.
+    // if we are already in the desired state, do nothing.
     if (bStarted != bStatus) {
+
         LW_TRY(exc, DJStartStopDaemon(pszName, bStatus, &LW_EXC));
+
     }
 
+    LW_TRY(exc, DJConfigureForDaemonRestart(pszName, bStatus, startPriority, stopPriority, &LW_EXC));
+
 cleanup:
     ;
 }
 
 struct _DaemonList daemonList[] = {    
-    //{ "reapsysld", {NULL}, FALSE, 12, 9 },
-    { "gpagentd", {NULL}, FALSE, 22, 9 },
-    //{ "eventfwdd", {NULL}, FALSE, 21, 9 },
+    { "lsassd", {"likewise-open", NULL}, TRUE, 93, 10 },
+    { "gpagentd", {NULL}, FALSE, 94, 9 },
+    { "lwmgmtd", {NULL}, FALSE, 95, 8 },
     { NULL, {NULL}, FALSE, 0, 0 },
 };
 
