@@ -1,25 +1,31 @@
 /* Editor Settings: expandtabs and use 4 spaces for indentation
-* ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
-* -*- mode: c, c-basic-offset: 4 -*- */
+ * ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
+ * -*- mode: c, c-basic-offset: 4 -*- */
 
 /*
- * Copyright (C) Centeris Corporation 2004-2007
- * Copyright (C) Likewise Software    2007-2008
+ * Copyright Likewise Software    2004-2008
  * All rights reserved.
- * 
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as 
- * published by the Free Software Foundation; either version 2.1 of 
- * the License, or (at your option) any later version.
+ *
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the license, or (at
+ * your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser
+ * General Public License for more details.  You should have received a copy
+ * of the GNU Lesser General Public License along with this program.  If
+ * not, see <http://www.gnu.org/licenses/>.
  *
- * You should have received a copy of the GNU Lesser General Public 
- * License along with this program.  If not, see 
- * <http://www.gnu.org/licenses/>.
+ * LIKEWISE SOFTWARE MAKES THIS SOFTWARE AVAILABLE UNDER OTHER LICENSING
+ * TERMS AS WELL.  IF YOU HAVE ENTERED INTO A SEPARATE LICENSE AGREEMENT
+ * WITH LIKEWISE SOFTWARE, THEN YOU MAY ELECT TO USE THE SOFTWARE UNDER THE
+ * TERMS OF THAT SOFTWARE LICENSE AGREEMENT INSTEAD OF THE TERMS OF THE GNU
+ * LESSER GENERAL PUBLIC LICENSE, NOTWITHSTANDING THE ABOVE NOTICE.  IF YOU
+ * HAVE QUESTIONS, OR WISH TO REQUEST A COPY OF THE ALTERNATE LICENSING
+ * TERMS OFFERED BY LIKEWISE SOFTWARE, PLEASE CONTACT LIKEWISE SOFTWARE AT
+ * license@likewisesoftware.com
  */
 
 #include "domainjoin.h"
@@ -33,6 +39,8 @@
 #include <sys/socket.h>
 #endif
 
+#include <netinet/in.h>
+
 #define GCE(x) GOTO_CLEANUP_ON_CENTERROR((x))
 
 /* TODO: Add to centutils */
@@ -100,7 +108,10 @@ static CENTERROR ConnectSocket(int sock, struct sockaddr_in *to)
 {
     if(connect(sock, (struct sockaddr *)to, sizeof(*to)) < 0)
     {
-        return CTMapSystemError(errno);
+        if (errno != EINPROGRESS)
+        {
+            return CTMapSystemError(errno);
+        }
     }
     return CENTERROR_SUCCESS;
 }
@@ -138,8 +149,8 @@ static CENTERROR CheckPorts(PortCheck *checks, int checkNum, int tcptimeout)
         if(checks[i].udp)
         {
             GCE(ceError = CreateSocket(checks[i].udp, &checks[i].sock));
-            GCE(ceError = SetNonblocking(checks[i].sock));
             GCE(ceError = ConnectSocket(checks[i].sock, &checks[i].to));
+            GCE(ceError = SetNonblocking(checks[i].sock));
         }
         else
             checks[i].sock = -1;
@@ -641,13 +652,8 @@ static void CachePortCheck(PCSTR domainName, ModuleState *state, DCPortCheckOpti
     }
 
     DJ_LOG_INFO("Getting DC");
-    LW_CLEANUP_CTERR(exc, DJGetDomainDC(domainName, &check->dc));
-    if(IsNullOrEmptyString(check->dc))
-    {
-        //Maybe cldap is blocked? We'll default to the domain name
-        CT_SAFE_FREE_STRING(check->dc);
-        LW_CLEANUP_CTERR(exc, CTStrdup(domainName, &check->dc));
-    }
+    LW_TRY(exc, DJGetDomainDC(domainName, &check->dc, &LW_EXC));
+
     DJ_LOG_INFO("Starting port check");
     LW_TRY(exc, CheckDCPorts(check, options, &LW_EXC));
     if(state != NULL)
