@@ -268,7 +268,7 @@ WriteHostnameToSunFiles(
     DWORD nPaths = 0;
     DWORD iPath = 0;
     PSTR contents = NULL;
-    LONG fileLen;
+    long fileLen;
 
     DJ_LOG_INFO("Setting hostname to [%s]", pszComputerName);
 
@@ -399,6 +399,36 @@ error:
     return ceError;
 }
 
+static
+CENTERROR
+GetTmpPath(
+    PCSTR pszOriginalPath,
+    PSTR* ppszTmpPath
+    )
+{
+    CENTERROR ceError = CENTERROR_SUCCESS;
+    PCSTR pszSuffix = ".domainjoin";
+    PSTR pszTmpPath = NULL;
+
+    ceError = CTAllocateMemory(strlen(pszOriginalPath)+strlen(pszSuffix)+1,
+                               PPCAST(&pszTmpPath));
+    BAIL_ON_CENTERIS_ERROR(ceError);
+
+    strcpy(pszTmpPath, pszOriginalPath);
+    strcat(pszTmpPath, pszSuffix);
+
+    *ppszTmpPath = pszTmpPath;
+
+    return ceError;
+
+error:
+
+    if (pszTmpPath)
+        CTFreeString(pszTmpPath);
+
+    return ceError;
+}
+
 static
 BOOLEAN
 IsComment(
@@ -426,7 +456,6 @@ DJReplaceNameValuePair(
 {
     CENTERROR ceError = CENTERROR_SUCCESS;
     PSTR pszTmpPath = NULL;
-    PSTR pszFinalPath = NULL;
     FILE* fpSrc = NULL;
     FILE* fpDst = NULL;
     regex_t rx;
@@ -436,10 +465,7 @@ DJReplaceNameValuePair(
 
     memset(&rx, 0, sizeof(rx));
 
-    ceError = CTGetFileTempPath(
-                        pszFilePath,
-                        &pszFinalPath,
-                        &pszTmpPath);
+    ceError = GetTmpPath(pszFilePath, &pszTmpPath);
     BAIL_ON_CENTERIS_ERROR(ceError);
 
     sprintf(szRegExp, "^[[:space:]]*%s[[:space:]]*=.*$", pszName);
@@ -449,7 +475,7 @@ DJReplaceNameValuePair(
         BAIL_ON_CENTERIS_ERROR(ceError);
     }
 
-    if ((fpSrc = fopen(pszFinalPath, "r")) == NULL) {
+    if ((fpSrc = fopen(pszFilePath, "r")) == NULL) {
         ceError = CTMapSystemError(errno);
         BAIL_ON_CENTERIS_ERROR(ceError);
     }
@@ -494,7 +520,10 @@ DJReplaceNameValuePair(
     fclose(fpSrc); fpSrc = NULL;
     fclose(fpDst); fpDst = NULL;
 
-    ceError = CTSafeReplaceFile(pszFinalPath, pszTmpPath);
+    ceError = CTBackupFile(pszFilePath);
+    BAIL_ON_CENTERIS_ERROR(ceError);
+
+    ceError = CTMoveFile(pszTmpPath, pszFilePath);
     BAIL_ON_CENTERIS_ERROR(ceError);
 
     bRemoveFile = FALSE;
@@ -512,8 +541,8 @@ error:
     if (bRemoveFile)
         CTRemoveFile(pszTmpPath);
 
-    CT_SAFE_FREE_STRING(pszTmpPath);
-    CT_SAFE_FREE_STRING(pszFinalPath);
+    if (pszTmpPath)
+        CTFreeString(pszTmpPath);
 
     return ceError;
 }
@@ -584,7 +613,6 @@ error:
     return ceError;
 }
 
-#if !defined(HAVE_SETHOSTNAME) || ! HAVE_DECL_SETHOSTNAME
 static
 CENTERROR
 DJFixNetworkManagerOnlineTimeout(
@@ -649,11 +677,10 @@ cleanup:
 
     return ceError;
 }
-#endif
 
 static
 CENTERROR
-DJConfigureDHCPService(
+DJRestartDHCPService(
     PSTR pszComputerName
     )
 {
@@ -661,13 +688,13 @@ DJConfigureDHCPService(
     int EE = 0;
     BOOLEAN bFileExists = FALSE;
     PSTR dhcpFilePath = "/etc/sysconfig/network/dhcp";
+    PSTR dhcpFilePathNew = "/etc/sysconfig/network/dhcp.new";
     PSTR  ppszArgs[] =
         { "/bin/sed",
           "s/^.*\\(DHCLIENT_SET_HOSTNAME\\).*=.*$/\\1=\\\"no\\\"/",
           dhcpFilePath,
           NULL
         };
-#if !defined(HAVE_SETHOSTNAME) || !HAVE_DECL_SETHOSTNAME
     PSTR  ppszNetArgs[] =
         {
 #if defined(_AIX)
@@ -678,25 +705,18 @@ DJConfigureDHCPService(
             "restart",
             NULL
         };
-#endif
     PPROCINFO pProcInfo = NULL;
     LONG status = 0;
-    PSTR pszFinalPath = NULL;
-    PSTR pszTmpPath = NULL;
 
     ceError = CTCheckFileExists(dhcpFilePath, &bFileExists);
     CLEANUP_ON_CENTERROR_EE(ceError, EE);
 
-    if (bFileExists)
-    {
-        ceError = CTGetFileTempPath(
-                            dhcpFilePath,
-                            &pszFinalPath,
-                            &pszTmpPath);
+    if (bFileExists) {
+
+        ceError = CTBackupFile(dhcpFilePath);
         CLEANUP_ON_CENTERROR_EE(ceError, EE);
 
-        ppszArgs[2] = pszFinalPath;
-        ceError = DJSpawnProcessOutputToFile(ppszArgs[0], ppszArgs, pszTmpPath, &pProcInfo);
+        ceError = DJSpawnProcessOutputToFile(ppszArgs[0], ppszArgs, dhcpFilePathNew, &pProcInfo);
         CLEANUP_ON_CENTERROR_EE(ceError, EE);
 
         ceError = DJGetProcessStatus(pProcInfo, &status);
@@ -707,7 +727,8 @@ DJConfigureDHCPService(
             CLEANUP_ON_CENTERROR_EE(ceError, EE);
         }
 
-        ceError = CTSafeReplaceFile(pszFinalPath, pszTmpPath);
+        // Now move temp file into place
+        ceError = CTMoveFile(dhcpFilePathNew, dhcpFilePath);
         CLEANUP_ON_CENTERROR_EE(ceError, EE);
     }
 
@@ -716,13 +737,6 @@ DJConfigureDHCPService(
         pProcInfo = NULL;
     }
 
-#if defined(HAVE_SETHOSTNAME) && HAVE_DECL_SETHOSTNAME
-    if (sethostname(pszComputerName, strlen(pszComputerName)) < 0)
-    {
-        ceError = CTMapSystemError(errno);
-        CLEANUP_ON_CENTERROR_EE(ceError, EE);
-    }
-#else
     ceError = DJFixNetworkManagerOnlineTimeout();
     CLEANUP_ON_CENTERROR_EE(ceError, EE);
 
@@ -738,7 +752,6 @@ DJConfigureDHCPService(
         ceError = CENTERROR_DOMAINJOIN_DHCPRESTART_FAIL;
         CLEANUP_ON_CENTERROR_EE(ceError, EE);
     }
-#endif
 
 cleanup:
 
@@ -747,9 +760,6 @@ cleanup:
 
     DJ_LOG_VERBOSE("DJRestartDHCPService LEAVE -> 0x%08x (EE = %d)", ceError, EE);
 
-    CT_SAFE_FREE_STRING(pszFinalPath);
-    CT_SAFE_FREE_STRING(pszTmpPath);
-
     return ceError;
 }
 
@@ -800,11 +810,8 @@ FixNetworkInterfaces(
             {"/etc/sysconfig/network", "ifcfg-eth-id-[^.]*$"},
             {"/etc/sysconfig/network", "ifcfg-eth0[^.]*$"},
             {"/etc/sysconfig/network", "ifcfg-eth-bus[^.]*$"},
-            //SLES 10.1 on zSeries uses one of:
-            //  /etc/sysconfig/network/ifcfg-qeth-bus-ccw-0.0.0500
-            //  /etc/sysconfig/network/ifcfg-ctc-bus-ccw-0.0.0004
-            {"/etc/sysconfig/network", "ifcfg-qeth-bus.*\\.[0-9]\\+$"},
-            {"/etc/sysconfig/network", "ifcfg-ctc-bus.*\\.[0-9]\\+$"},
+            //SLES 10.1 on zSeries uses /etc/sysconfig/network/ifcfg-qeth-bus-ccw-0.0.0500
+            {"/etc/sysconfig/network", "ifcfg-qeth-bus[^.]*$"},
             // Redhat uses /etc/sysconfig/network-scripts/ifcfg-eth<number>
             {"/etc/sysconfig/network-scripts", "ifcfg-eth[^.]*$"},
             {NULL, NULL}
@@ -861,7 +868,7 @@ FixNetworkInterfaces(
 
     // Only DHCP boxes need to restart their networks
     if (bDHCPHost) {
-        LW_CLEANUP_CTERR(exc, DJConfigureDHCPService(pszComputerName));
+        LW_CLEANUP_CTERR(exc, DJRestartDHCPService(pszComputerName));
     }
 
 cleanup:
@@ -1091,7 +1098,6 @@ static void DoSetHostname(JoinProcessOptions *options, LWException **exc)
         DJSetComputerName(options->computerName,
             options->domainName, &LW_EXC));
 
-#ifndef ENABLE_MINIMAL
     ceError = DJConfigureHostsEntry(NULL);
     if(ceError == CENTERROR_INVALID_FILENAME)
     {
@@ -1101,14 +1107,11 @@ static void DoSetHostname(JoinProcessOptions *options, LWException **exc)
 #endif
     }
     LW_CLEANUP_CTERR(exc, ceError);
-#endif
 
-#ifndef ENABLE_MINIMAL
     DJRestartIfRunning("nscd", &inner);
     if(!LW_IS_OK(inner) && inner->code == CENTERROR_FILE_NOT_FOUND)
         LW_HANDLE(&inner);
     LW_CLEANUP(exc, inner);
-#endif
 
 cleanup:
     LW_HANDLE(&inner);
@@ -1325,9 +1328,9 @@ void DJCheckValidComputerName(
     dwLen = strlen(pszComputerName);
 
     //Zero length hostnames are already handled above
-    if (dwLen > 63)
+    if (dwLen > 15)
     {
-        LW_RAISE_EX(exc, CENTERROR_INVALID_COMPUTERNAME, "Invalid hostname", "The name '%s' is %d characters long. Hostnames may only be up to 63 characters long.", pszComputerName, dwLen);
+        LW_RAISE_EX(exc, CENTERROR_INVALID_COMPUTERNAME, "Invalid hostname", "The name '%s' is %d characters long. Hostnames may only be up to 15 characters long.", pszComputerName, dwLen);
         goto cleanup;
     }
 
