@@ -234,19 +234,12 @@ static CENTERROR WriteNsswitchConfiguration(const char *rootPrefix, NsswitchConf
     int i;
     char *tempName = NULL;
     char *finalName = NULL;
-    char *prefixedPath = NULL;
     FILE *file = NULL;
     memset(&printedLine, 0, sizeof(printedLine));
 
-    GCE(ceError = CTAllocateStringPrintf(&prefixedPath, "%s%s", rootPrefix, conf->filename));
-
-    GCE(ceError = CTGetFileTempPath(
-                        prefixedPath,
-                        &finalName,
-                        &tempName));
-
-    DJ_LOG_INFO("Writing nsswitch configuration for %s", finalName);
+    DJ_LOG_INFO("Writing nsswitch configuration for %s", conf->filename);
 
+    GCE(ceError = CTAllocateStringPrintf(&tempName, "%s%s.new", rootPrefix, conf->filename));
     ceError = CTOpenFile(tempName, "w", &file);
     if(!CENTERROR_IS_OK(ceError))
     {
@@ -263,9 +256,13 @@ static CENTERROR WriteNsswitchConfiguration(const char *rootPrefix, NsswitchConf
     GCE(ceError = CTCloseFile(file));
     file = NULL;
 
-    GCE(ceError = CTSafeReplaceFile(
-            finalName,
-            tempName));
+    /* Make sure to set perms */
+
+    GCE(ceError = CTChangePermissions(tempName, S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH));
+
+    GCE(ceError = CTAllocateStringPrintf(&finalName, "%s%s", rootPrefix, conf->filename));
+    GCE(ceError = CTBackupFile(finalName));
+    GCE(ceError = CTMoveFile(tempName, finalName));
     DJ_LOG_INFO("File moved into place");
 
 cleanup:
@@ -274,7 +271,6 @@ cleanup:
     CTArrayFree(&printedLine);
     CT_SAFE_FREE_STRING(tempName);
     CT_SAFE_FREE_STRING(finalName);
-    CT_SAFE_FREE_STRING(prefixedPath);
     return ceError;
 }
 
@@ -1033,8 +1029,6 @@ static void ConfigureApparmor(BOOLEAN enable, LWException **exc)
     PCSTR addString;
     PSTR restartPath = NULL;
     PSTR restartCommand = NULL;
-    char *tempName = NULL;
-    char *finalName = NULL;
 
     LW_CLEANUP_CTERR(exc, IsApparmorConfigured(&configured));
     if(configured == enable)
@@ -1045,12 +1039,7 @@ static void ConfigureApparmor(BOOLEAN enable, LWException **exc)
     if(!hasApparmor)
         goto cleanup;
 
-    GCE(ceError = CTGetFileTempPath(
-                        APPARMOR_NSSWITCH,
-                        &finalName,
-                        &tempName));
-
-    LW_CLEANUP_CTERR(exc, CTCheckFileHoldsPattern(finalName,
+    LW_CLEANUP_CTERR(exc, CTCheckFileHoldsPattern(APPARMOR_NSSWITCH,
                 "mr,", &usingMr));
 
     if(usingMr)
@@ -1058,32 +1047,32 @@ static void ConfigureApparmor(BOOLEAN enable, LWException **exc)
 PREFIXDIR "/lib/*.so*            mr,\n"
 PREFIXDIR "/lib64/*.so*          mr,\n"
 "/tmp/.lwidentity/pipe              rw,\n"
-LOCALSTATEDIR "/lib/likewise/.lsassd  rw,\n"
+LOCALSTATEDIR "/lib/likewise/.lsasd  rw,\n"
 LOCALSTATEDIR "/tmp/.lsaclient_*              rw,\n";
     else
         addString =
 PREFIXDIR "/lib/*.so*            r,\n"
 PREFIXDIR "/lib64/*.so*          r,\n"
 "/tmp/.lwidentity/pipe              rw,\n"
-LOCALSTATEDIR "/lib/likewise/.lsassd  rw,\n"
+LOCALSTATEDIR "/lib/likewise/.lsasd  rw,\n"
 LOCALSTATEDIR "/tmp/.lsaclient_*              rw,\n";
 
 
     if(enable)
     {
-        LW_CLEANUP_CTERR(exc, CTCopyFileWithOriginalPerms(finalName, tempName));
-        LW_CLEANUP_CTERR(exc, CTOpenFile(tempName, "a", &file));
+        LW_CLEANUP_CTERR(exc, CTCopyFileWithOriginalPerms(APPARMOR_NSSWITCH, APPARMOR_NSSWITCH ".new"));
+        LW_CLEANUP_CTERR(exc, CTOpenFile(APPARMOR_NSSWITCH ".new", "a", &file));
         LW_CLEANUP_CTERR(exc, CTFilePrintf(file, "# likewise\n%s# end likewise\n",
                     addString));
 
         CTSafeCloseFile(&file);
 
-        LW_CLEANUP_CTERR(exc, CTSafeReplaceFile(finalName, tempName));
+        LW_CLEANUP_CTERR(exc, CTSafeReplaceFile(APPARMOR_NSSWITCH, APPARMOR_NSSWITCH ".new"));
     }
     else
     {
-        LW_CLEANUP_CTERR(exc, CTRunSedOnFile(finalName, finalName, FALSE, "/^[ \t]*#[ \t]*likewise[ \t]*$/,/^[ \t]*#[ \t]*end likewise[ \t]*$/d"));
-        LW_CLEANUP_CTERR(exc, CTRunSedOnFile(finalName, finalName, FALSE, "/^[ \t]*#[ \t]*centeris[ \t]*$/,/^[ \t]*#[ \t]*end centeris[ \t]*$/d"));
+        LW_CLEANUP_CTERR(exc, CTRunSedOnFile(APPARMOR_NSSWITCH, APPARMOR_NSSWITCH, FALSE, "/^[ \t]*#[ \t]*likewise[ \t]*$/,/^[ \t]*#[ \t]*end likewise[ \t]*$/d"));
+        LW_CLEANUP_CTERR(exc, CTRunSedOnFile(APPARMOR_NSSWITCH, APPARMOR_NSSWITCH, FALSE, "/^[ \t]*#[ \t]*centeris[ \t]*$/,/^[ \t]*#[ \t]*end centeris[ \t]*$/d"));
     }
 
 
@@ -1109,12 +1098,10 @@ cleanup:
     if(file != NULL)
     {
         CTCloseFile(file);
-        CTRemoveFile(tempName);
+        CTRemoveFile(APPARMOR_NSSWITCH ".new");
     }
     CT_SAFE_FREE_STRING(restartPath);
     CT_SAFE_FREE_STRING(restartCommand);
-    CT_SAFE_FREE_STRING(tempName);
-    CT_SAFE_FREE_STRING(finalName);
 }
 
 static CENTERROR UnsuportedSeLinuxEnabled(BOOLEAN *hasBadSeLinux)
@@ -1192,66 +1179,72 @@ static QueryResult QueryNsswitch(const JoinProcessOptions *options, LWException
     QueryResult result = FullyConfigured;
     BOOLEAN configured;
     BOOLEAN exists;
+    BOOLEAN hasApparmor;
     BOOLEAN hasBadSeLinux;
     NsswitchConf conf;
     CENTERROR ceError = CENTERROR_SUCCESS;
 
     memset(&conf, 0, sizeof(conf));
 
-    if (options->joiningDomain)
+    ceError = ReadNsswitchConf(&conf, NULL, FALSE);
+    if(ceError == CENTERROR_INVALID_FILENAME)
     {
-        ceError = ReadNsswitchConf(&conf, NULL, FALSE);
-        if(ceError == CENTERROR_INVALID_FILENAME)
-        {
-            ceError = CENTERROR_SUCCESS;
-            DJ_LOG_WARNING("Warning: Could not find nsswitch file");
-            goto cleanup;
-        }
-        LW_CLEANUP_CTERR(exc, ceError);
+        ceError = CENTERROR_SUCCESS;
+        DJ_LOG_WARNING("Warning: Could not find nsswitch file");
+        goto cleanup;
+    }
+    LW_CLEANUP_CTERR(exc, ceError);
 
+    if(options->joiningDomain)
+    {
         LW_TRY(exc, result = RemoveCompat(&conf, NULL, &LW_EXC));
         if(result == CannotConfigure || result == NotConfigured)
-        {
             goto cleanup;
-        }
+    }
 
-        LW_CLEANUP_CTERR(exc, UpdateNsswitchConf(&conf, TRUE));
-        if(conf.modified)
-        {
-            LW_CLEANUP_CTERR(exc, UnsuportedSeLinuxEnabled(&hasBadSeLinux));
-            if(hasBadSeLinux)
-                result = CannotConfigure;
-            else
-                result = NotConfigured;
-            goto cleanup;
-        }
+    LW_CLEANUP_CTERR(exc, UpdateNsswitchConf(&conf, options->joiningDomain));
+    if(conf.modified)
+    {
+        LW_CLEANUP_CTERR(exc, UnsuportedSeLinuxEnabled(&hasBadSeLinux));
+        if(hasBadSeLinux)
+            result = CannotConfigure;
+        else
+            result = NotConfigured;
+        goto cleanup;
+    }
 
-        LW_CLEANUP_CTERR(exc, DJHasMethodsCfg(&exists));
-
-        if(exists)
-        {
-            LW_CLEANUP_CTERR(exc, DJIsMethodsCfgConfigured(&configured));
-
-            if(!configured)
-            {
-                result = NotConfigured;
-                goto cleanup;
-            }
-        }
-
-        LW_CLEANUP_CTERR(exc, IsApparmorConfigured(&configured));
-
-        if(!configured)
+    LW_CLEANUP_CTERR(exc, DJHasMethodsCfg(&exists));
+    if(exists)
+    {
+        LW_CLEANUP_CTERR(exc, DJIsMethodsCfgConfigured(&configured));
+        if((configured != FALSE) != (options->joiningDomain != FALSE))
         {
             result = NotConfigured;
             goto cleanup;
         }
     }
 
+    LW_CLEANUP_CTERR(exc, IsApparmorConfigured(&configured));
+    LW_CLEANUP_CTERR(exc, HasApparmor(&hasApparmor));
+    if(options->joiningDomain)
+    {
+        if(!configured)
+        {
+            result = NotConfigured;
+            goto cleanup;
+        }
+    }
+    else
+    {
+        if(hasApparmor && configured)
+        {
+            result = SufficientlyConfigured;
+            goto cleanup;
+        }
+    }
+
 cleanup:
-
     FreeNsswitchConfContents(&conf);
-
     return result;
 }
 
@@ -1365,22 +1358,14 @@ static void DoNsswitch(JoinProcessOptions *options, LWException **exc)
             &restartException);
     if(restartException != NULL && restartException->code == CENTERROR_COMMAND_FAILED)
     {
-        options->warningCallback(options, "Some services require manual restart", restartException->longMsg);
+        options->warningCallback(options, "Unable to restart services after nsswitch modification", restartException->longMsg);
         LW_HANDLE(&restartException);
     }
     LW_CLEANUP(exc, restartException);
 
     LW_TRY(exc, RestartDtloginIfRunning(options, &LW_EXC));
 
-    options->warningCallback(options,
-                             "System restart required",
-                             "Your system has been configured to authenticate to "
-                             "Active Directory for the first time.  It is recommended "
-                             "that you restart your system to ensure that all applications "
-                             "recognize the new settings.");
-
 cleanup:
-
     FreeNsswitchConfContents(&conf);
 }
 
