@@ -42,21 +42,14 @@
 #include "includes.h"
 
 
-VOID
+
+void
 LWIFreeEventRecord(
     PEVENT_LOG_RECORD pEventRecord
     )
 {
-    LWIFreeEventRecordList(1, pEventRecord);
-}
+    EVT_LOG_VERBOSE("client::eventlog.c FreeEventRecord(pEventRecord=%.16X)\n", pEventRecord);
 
-static
-VOID
-LWIFreeEventRecordContents(
-    PEVENT_LOG_RECORD pEventRecord
-)
-{
-    EVT_SAFE_FREE_STRING(pEventRecord->pszEventTableCategoryId);
     EVT_SAFE_FREE_STRING(pEventRecord->pszEventType);
     EVT_SAFE_FREE_STRING(pEventRecord->pszEventSource);
     EVT_SAFE_FREE_STRING(pEventRecord->pszEventCategory);
@@ -64,22 +57,11 @@ LWIFreeEventRecordContents(
     EVT_SAFE_FREE_STRING(pEventRecord->pszComputer);
     EVT_SAFE_FREE_STRING(pEventRecord->pszDescription);
     EVT_SAFE_FREE_MEMORY(pEventRecord->pszData);
-}
 
-VOID
-LWIFreeEventRecordList(
-    DWORD dwRecords,
-    PEVENT_LOG_RECORD pEventRecordList
-    )
-{
-    DWORD dwIndex = 0;
+    EVTFreeMemory(pEventRecord);
 
-    for (dwIndex = 0; dwIndex < dwRecords; dwIndex++)
-    {
-        LWIFreeEventRecordContents(&pEventRecordList[dwIndex]);
-    }
+    EVT_LOG_VERBOSE("client::eventlog.c FreeEventRecord() Finished\n", pEventRecord);
 
-    EVTFreeMemory(pEventRecordList);
 }
 
 void
@@ -91,8 +73,13 @@ LWIFreeEventLogHandle(
     PEVENT_LOG_HANDLE pEventLogHandle = (PEVENT_LOG_HANDLE) hEventLog;
     PEVENT_LOG_RECORD pEventRecord = &(pEventLogHandle->defaultEventLogRecord);
 
-    LWIFreeEventLogRpcBinding(pEventLogHandle->bindingHandle);
-    LWIFreeEventRecordContents(pEventRecord);
+    EVT_SAFE_FREE_MEMORY(pEventRecord->pszEventType);
+    EVT_SAFE_FREE_MEMORY(pEventRecord->pszEventSource);
+    EVT_SAFE_FREE_MEMORY(pEventRecord->pszEventCategory);
+    EVT_SAFE_FREE_MEMORY(pEventRecord->pszUser);
+    EVT_SAFE_FREE_MEMORY(pEventRecord->pszComputer);
+    EVT_SAFE_FREE_MEMORY(pEventRecord->pszDescription);
+    EVT_SAFE_FREE_MEMORY(pEventRecord->pszData);
     EVT_SAFE_FREE_MEMORY(pEventLogHandle);
 }
 
@@ -175,7 +162,7 @@ LWIOpenEventLog(
 
     BAIL_ON_EVT_ERROR(dwError);
 
-    pEventLogHandle->bindingHandle = eventBindingLocal;
+    pEventLogHandle->bindingHandle = (ULONG) eventBindingLocal;
     *phEventLog = (HANDLE)pEventLogHandle;
 
 
@@ -198,11 +185,6 @@ error:
         LWIFreeEventLogHandle((HANDLE)pEventLogHandle);
     }
 
-    if (eventBindingLocal)
-    {
-        LWIFreeEventLogRpcBinding(eventBindingLocal);
-    }
-
     *phEventLog = (HANDLE) NULL;
 
     goto cleanup;
@@ -291,7 +273,7 @@ LWICloseEventLog(
     TRY
     {
         dwError = RpcLWICloseEventLog(
-            (handle_t) pEventLogHandle->bindingHandle
+            (handle_t)(ULONG) pEventLogHandle->bindingHandle
             );
     }
     CATCH_ALL
@@ -347,7 +329,7 @@ LWIReadEventLog(
     TRY
     {
         dwError = RpcLWIReadEventLog(
-                    (handle_t) pEventLogHandle->bindingHandle,
+                    (handle_t)(ULONG) pEventLogHandle->bindingHandle,
                     dwLastRecordId, 
                     nRecordsPerPage,
                     (idl_char*)sqlFilterChar, 
@@ -364,7 +346,6 @@ LWIReadEventLog(
 
 
 cleanup:
-    EVT_SAFE_FREE_STRING(sqlFilterChar);
     return dwError;
 
 error:
@@ -398,7 +379,7 @@ LWICountEventLog(
     TRY
     {
         dwError = RpcLWIEventLogCount(
-                    (handle_t) pEventLogHandle->bindingHandle,
+                    (handle_t)(ULONG) pEventLogHandle->bindingHandle,
                     (idl_char*)sqlFilterChar,
                     (unsigned32*)pdwNumMatched);
     }
@@ -411,7 +392,6 @@ LWICountEventLog(
     BAIL_ON_EVT_ERROR(dwError);
 
 cleanup:
-    EVT_SAFE_FREE_STRING(sqlFilterChar);
     return dwError;
 
 error:
@@ -574,40 +554,6 @@ error:
 }
 
 
-DWORD
-LWIWriteEventLogRecords(
-    HANDLE hEventLog,
-    DWORD cRecords,
-    PEVENT_LOG_RECORD pEventRecords
-    )
-{
-    volatile DWORD dwError = 0;
-    PEVENT_LOG_HANDLE pEventLogHandle = (PEVENT_LOG_HANDLE) hEventLog;
-
-    TRY
-    {
-        dwError = RpcLWIWriteEventLogRecords(
-                        (handle_t) pEventLogHandle->bindingHandle,
-                        cRecords,
-                        pEventRecords);
-    }
-    CATCH_ALL
-    {
-        dwError = EVTGetRpcError(THIS_CATCH, EVT_ERROR_RPC_EXCEPTION_UPON_WRITE);
-    }
-    ENDTRY;
-
-    BAIL_ON_EVT_ERROR(dwError);
-
-cleanup:
-
-    return dwError;
-
-error:
-    EVT_LOG_ERROR("Failed to write event log. Error code [%d]\n", dwError);
-    goto cleanup;
-}
-
 DWORD
 LWIWriteEventLogBase(
     HANDLE hEventLog,
@@ -692,10 +638,8 @@ LWIWriteEventLogBase(
 
     TRY
     {
-        dwError = RpcLWIWriteEventLogRecords(
-                        (handle_t) pEventLogHandle->bindingHandle,
-                        1,
-                        &eventRecordLocal);
+        dwError = RpcLWIWriteEventLog( (handle_t)(ULONG) pEventLogHandle->bindingHandle,
+						   eventRecordLocal);
     }
     CATCH_ALL
     {
@@ -714,6 +658,8 @@ error:
     goto cleanup;
 }
 
+
+
 DWORD
 LWIWriteEventLog(
     HANDLE hEventLog,
@@ -763,7 +709,7 @@ LWIDeleteFromEventLog(
 
     TRY
     {
-        dwError = RpcLWIDeleteFromEventLog( (handle_t) pEventLogHandle->bindingHandle,
+        dwError = RpcLWIDeleteFromEventLog( (handle_t)(ULONG) pEventLogHandle->bindingHandle,
                                             (idl_char*)sqlFilterChar);
     }
     CATCH_ALL
@@ -793,7 +739,7 @@ LWIClearEventLog(
 
     TRY
     {
-        dwError = RpcLWIClearEventLog( (handle_t) pEventLogHandle->bindingHandle);
+        dwError = RpcLWIClearEventLog( (handle_t)(ULONG) pEventLogHandle->bindingHandle);
     }
     CATCH_ALL
     {
