@@ -51,11 +51,11 @@
   #include <sys/stat.h>
   #include <dirent.h>
   #include <pwd.h>
-  #include <lwrpcrt.h>
-  #include <lw/winerror.h>
+  #include <compat/dcerpc.h>
+  #include <dce/dcethread.h>
+  #include <compat/rpcstatus.h>
   #include <dlfcn.h>
   #include <dce/rpcexc.h>
-  #include <dce/lrpc.h>
 
 #if HAVE_WC16STR_H
   #include <wc16str.h>
