@@ -1,15 +1,12 @@
-#include <config.h>
-
-#include <eventsys.h>
-
-#include <reg/lwreg.h>
-
-#include <eventdefs.h>
-#include <eventlog.h>
+#include "config.h"
 
+#include "eventsys.h"
+#include "eventlog.h"
+#include "eventdefs.h"
 
 #include "eventutils.h"
 
+#include "evtcfg_p.h"
 #include "sysfuncs_p.h"
 #include "evtlogger_p.h"
 #include "evtcfgutils.h"
