@@ -55,8 +55,7 @@ typedef struct __AD_CELL_COOKIE_DATA
     // Initially, this is set to NULL to indicate that the primary cell
     // should be searched.
     const DLINKEDLIST* pCurrentCell;
-    PLSA_DM_LDAP_CONNECTION pLdapConn;
-    LW_SEARCH_COOKIE LdapCookie;
+    LSA_SEARCH_COOKIE LdapCookie;
 
     // This hash table is used to ensure that the same user/group is not
     // returned twice through linked cells. It is only allocated if linked
@@ -74,11 +73,10 @@ LsaAdBatchFreeCellCookie(
 
     if (pData != NULL)
     {
-        LwFreeCookieContents(&pData->LdapCookie);
-        LsaDmLdapClose(pData->pLdapConn);
+        LsaFreeCookieContents(&pData->LdapCookie);
         LsaHashSafeFree(&pData->pEnumeratedSids);
 
-        LW_SAFE_FREE_MEMORY(pData);
+        LSA_SAFE_FREE_MEMORY(pData);
     }
 }
 
@@ -93,14 +91,14 @@ LsaAdBatchEnumGetNoMoreError(
     switch (ObjectType)
     {
         case LSA_AD_BATCH_OBJECT_TYPE_USER:
-            dwError = LW_ERROR_NO_MORE_USERS;
+            dwError = LSA_ERROR_NO_MORE_USERS;
             break;
         case LSA_AD_BATCH_OBJECT_TYPE_GROUP:
-            dwError = LW_ERROR_NO_MORE_GROUPS;
+            dwError = LSA_ERROR_NO_MORE_GROUPS;
             break;
         default:
             LSA_ASSERT(FALSE);
-            dwError = LW_ERROR_INTERNAL;
+            dwError = LSA_ERROR_INTERNAL;
     }
 
     return dwError;
@@ -121,7 +119,7 @@ LsaAdBatchEnumGetScopeRoot(
 
     if (bIsByRealObject)
     {
-        dwError = LwLdapConvertDomainToDN(pszDnsDomainName, &pszScopeRoot);
+        dwError = LsaLdapConvertDomainToDN(pszDnsDomainName, &pszScopeRoot);
         BAIL_ON_LSA_ERROR(dwError);
     }
     else
@@ -137,11 +135,11 @@ LsaAdBatchEnumGetScopeRoot(
                 break;
             default:
                 LSA_ASSERT(FALSE);
-                dwError = LW_ERROR_INTERNAL;
+                dwError = LSA_ERROR_INTERNAL;
                 BAIL_ON_LSA_ERROR(dwError);
         }
 
-        dwError = LwAllocateStringPrintf(
+        dwError = LsaAllocateStringPrintf(
                         &pszScopeRoot,
                         "CN=%s,%s",
                         pszContainer,
@@ -154,7 +152,7 @@ cleanup:
     return dwError;
 
 error:
-    LW_SAFE_FREE_STRING(pszScopeRoot);
+    LSA_SAFE_FREE_STRING(pszScopeRoot);
     goto cleanup;
 }
 
@@ -260,8 +258,6 @@ DWORD
 LsaAdBatchEnumProcessRealMessages(
     IN PCSTR pszDnsDomainName,
     IN PCSTR pszNetbiosDomainName,
-    IN DWORD dwDirectoryMode,
-    IN ADConfigurationMode adMode,
     IN LSA_AD_BATCH_OBJECT_TYPE ObjectType,
     IN HANDLE hDirectory,
     IN LDAPMessage* pMessages,
@@ -272,12 +268,11 @@ LsaAdBatchEnumProcessRealMessages(
 {
     DWORD dwError = 0;
     LDAPMessage* pCurrentMessage = NULL;
-    LDAP* pLd = LwLdapGetSession(hDirectory);
+    LDAP* pLd = LsaLdapGetSession(hDirectory);
     PLSA_SECURITY_OBJECT* ppObjects = NULL;
     DWORD dwObjectsCount = 0;
-    LSA_AD_BATCH_ITEM batchItem = { { 0 }, 0 };
 
-    dwError = LwAllocateMemory(
+    dwError = LsaAllocateMemory(
                     dwCount * sizeof(*ppObjects),
                     (PVOID*)&ppObjects);
     BAIL_ON_LSA_ERROR(dwError);
@@ -285,40 +280,29 @@ LsaAdBatchEnumProcessRealMessages(
     pCurrentMessage = ldap_first_entry(pLd, pMessages);
     while (pCurrentMessage)
     {
-        dwError = LsaAdBatchGatherRealObjectInternal(
+        LSA_AD_BATCH_ITEM batchItem = { { 0 }, 0 };
+
+        dwError = LsaAdBatchGatherRealObject(
                         &batchItem,
-                        &dwDirectoryMode,
-                        &adMode,
                         ObjectType,
                         NULL,
                         hDirectory,
                         pCurrentMessage);
         BAIL_ON_LSA_ERROR(dwError);
 
-        //
-        // Need to discard special groups (such as BUILTIN)
-        // that can show up in domain group enumeration.
-        //
-        if (!AdIsSpecialDomainSidPrefix(batchItem.pszSid))
-        {
-            dwError = LsaAdBatchMarshal(
-                            pszDnsDomainName,
-                            pszNetbiosDomainName,
-                            &batchItem,
-                            &ppObjects[dwObjectsCount]);
-            BAIL_ON_LSA_ERROR(dwError);
+        dwError = LsaAdBatchMarshal(
+                        pszDnsDomainName,
+                        pszNetbiosDomainName,
+                        &batchItem,
+                        &ppObjects[dwObjectsCount]);
+        BAIL_ON_LSA_ERROR(dwError);
 
-            dwObjectsCount++;
-        }
-
-        LsaAdBatchDestroyBatchItemContents(&batchItem);
+        dwObjectsCount++;
 
         pCurrentMessage = ldap_next_entry(pLd, pCurrentMessage);
     }
 
 cleanup:
-    LsaAdBatchDestroyBatchItemContents(&batchItem);
-
     *pdwObjectsCount = dwObjectsCount;
     *pppObjects = ppObjects;
 
@@ -326,7 +310,7 @@ cleanup:
 
 error:
     // set OUT params out cleanup.
-    ADCacheSafeFreeObjectList(dwObjectsCount, &ppObjects);
+    LsaDbSafeFreeObjectList(dwObjectsCount, &ppObjects);
     dwObjectsCount = 0;
 
     goto cleanup;
@@ -347,7 +331,7 @@ LsaAdBatchEnumProcessPseudoMessages(
 {
     DWORD dwError = 0;
     LDAPMessage* pCurrentMessage = NULL;
-    LDAP* pLd = LwLdapGetSession(hDirectory);
+    LDAP* pLd = LsaLdapGetSession(hDirectory);
     PSTR* ppszSids = NULL;
     DWORD dwSidsCount = 0;
     PLSA_SECURITY_OBJECT* ppObjects = NULL;
@@ -355,7 +339,7 @@ LsaAdBatchEnumProcessPseudoMessages(
     PSTR* ppszKeywordValues = NULL;
     DWORD dwKeywordValuesCount = 0;
 
-    dwError = LwAllocateMemory(
+    dwError = LsaAllocateMemory(
                     dwCount * sizeof(*ppszSids),
                     (PVOID*)&ppszSids);
     BAIL_ON_LSA_ERROR(dwError);
@@ -365,7 +349,7 @@ LsaAdBatchEnumProcessPseudoMessages(
     {
         PCSTR pszSidFromKeywords = NULL;
 
-        dwError = LwLdapGetStrings(
+        dwError = LsaLdapGetStrings(
                         hDirectory,
                         pCurrentMessage,
                         AD_LDAP_KEYWORDS_TAG,
@@ -377,30 +361,19 @@ LsaAdBatchEnumProcessPseudoMessages(
                                     dwKeywordValuesCount,
                                     ppszKeywordValues,
                                     AD_LDAP_BACKLINK_PSEUDO_TAG);
-        if (LW_IS_NULL_OR_EMPTY_STR(pszSidFromKeywords))
+        if (IsNullOrEmptyString(pszSidFromKeywords))
         {
-            dwError = LW_ERROR_INVALID_SID;
+            dwError = LSA_ERROR_INVALID_SID;
             BAIL_ON_LSA_ERROR(dwError);
         }
 
-        //
-        // There should never be any special groups (such as BUILTIN)
-        // that were provisioned in the domain.
-        //
-        if (!AdIsSpecialDomainSidPrefix(pszSidFromKeywords))
-        {
-            dwError = LwAllocateString(pszSidFromKeywords,
-                                        &ppszSids[dwSidsCount]);
-            BAIL_ON_LSA_ERROR(dwError);
+        dwError = LsaAllocateString(pszSidFromKeywords,
+                                    &ppszSids[dwSidsCount]);
+        BAIL_ON_LSA_ERROR(dwError);
 
-            dwSidsCount++;
-        }
-        else
-        {
-            LSA_LOG_WARNING("Got unexpected special domain SID in enumeration of pseudo-objects: '%s'", pszSidFromKeywords);
-        }
+        dwSidsCount++;
 
-        LwFreeStringArray(ppszKeywordValues, dwKeywordValuesCount);
+        LsaFreeStringArray(ppszKeywordValues, dwKeywordValuesCount);
         ppszKeywordValues = NULL;
         dwKeywordValuesCount = 0;
 
@@ -422,8 +395,8 @@ LsaAdBatchEnumProcessPseudoMessages(
     XXX;
 
 cleanup:
-    LwFreeStringArray(ppszKeywordValues, dwKeywordValuesCount);
-    LwFreeStringArray(ppszSids, dwSidsCount);
+    LsaFreeStringArray(ppszKeywordValues, dwKeywordValuesCount);
+    LsaFreeStringArray(ppszSids, dwSidsCount);
 
     *pdwObjectsCount = dwObjectsCount;
     *pppObjects = ppObjects;
@@ -432,7 +405,7 @@ cleanup:
 
 error:
     // set OUT params out cleanup.
-    ADCacheSafeFreeObjectList(dwObjectsCount, &ppObjects);
+    LsaDbSafeFreeObjectList(dwObjectsCount, &ppObjects);
     dwObjectsCount = 0;
 
     goto cleanup;
@@ -444,8 +417,7 @@ LsaAdBatchEnumProcessMessages(
     IN PCSTR pszDnsDomainName,
     IN PCSTR pszNetbiosDomainName,
     IN LSA_AD_BATCH_OBJECT_TYPE ObjectType,
-    IN DWORD dwDirectoryMode,
-    IN ADConfigurationMode adMode,
+    IN BOOLEAN bIsByRealObject,
     IN HANDLE hDirectory,
     IN LDAPMessage* pMessages,
     IN DWORD dwMaxCount,
@@ -455,14 +427,14 @@ LsaAdBatchEnumProcessMessages(
 {
     DWORD dwError = 0;
     DWORD dwCount = 0;
-    LDAP* pLd = LwLdapGetSession(hDirectory);
+    LDAP* pLd = LsaLdapGetSession(hDirectory);
     PLSA_SECURITY_OBJECT* ppObjects = NULL;
     DWORD dwObjectsCount = 0;
 
     dwCount = ldap_count_entries(pLd, pMessages);
     if ((int)dwCount < 0)
     {
-       dwError = LW_ERROR_LDAP_ERROR;
+       dwError = LSA_ERROR_LDAP_ERROR;
        BAIL_ON_LSA_ERROR(dwError);
     }
     else if (dwCount == 0)
@@ -472,18 +444,15 @@ LsaAdBatchEnumProcessMessages(
     }
     else if (dwCount > dwMaxCount)
     {
-       dwError = LW_ERROR_LDAP_ERROR;
+       dwError = LSA_ERROR_LDAP_ERROR;
        BAIL_ON_LSA_ERROR(dwError);
     }
 
-    if ((DEFAULT_MODE == dwDirectoryMode && SchemaMode == adMode) ||
-        (UNPROVISIONED_MODE == dwDirectoryMode))
+    if (bIsByRealObject)
     {
         dwError = LsaAdBatchEnumProcessRealMessages(
                         pszDnsDomainName,
                         pszNetbiosDomainName,
-                        dwDirectoryMode,
-                        adMode,
                         ObjectType,
                         hDirectory,
                         pMessages,
@@ -514,7 +483,7 @@ cleanup:
 
 error:
     // set OUT params out cleanup.
-    ADCacheSafeFreeObjectList(dwObjectsCount, &ppObjects);
+    LsaDbSafeFreeObjectList(dwObjectsCount, &ppObjects);
     dwObjectsCount = 0;
 
     goto cleanup;
@@ -527,11 +496,11 @@ error:
 static
 DWORD
 LsaAdBatchEnumObjectsInCell(
-    IN PLSA_DM_LDAP_CONNECTION pConn,
-    IN OUT PLW_SEARCH_COOKIE pCookie,
+    IN HANDLE hDirectory,
+    IN OUT PLSA_SEARCH_COOKIE pCookie,
     IN LSA_AD_BATCH_OBJECT_TYPE ObjectType,
-    IN DWORD dwDirectoryMode,
-    IN ADConfigurationMode adMode,
+    IN BOOLEAN bIsByRealObject,
+    IN BOOLEAN bIsSchemaMode,
     IN OPTIONAL PCSTR pszDnsDomainName,
     IN OPTIONAL PCSTR pszCellDn,
     IN DWORD dwMaxObjectsCount,
@@ -573,7 +542,7 @@ LsaAdBatchEnumObjectsInCell(
         AD_LDAP_SHELL_TAG,
         NULL
     };
-    PSTR* pszAttributeList = NULL;
+    PSTR* pszAttributeList = bIsByRealObject ? szRealAttributeList : szBacklinkAttributeList;
     PSTR pszScopeRoot = NULL;
     PCSTR pszQuery = NULL;
     PSTR pszNetbiosDomainName = NULL;
@@ -582,28 +551,8 @@ LsaAdBatchEnumObjectsInCell(
     DWORD dwObjectsCount = 0;
     PLSA_SECURITY_OBJECT* ppTotalObjects = NULL;
     DWORD dwTotalObjectsCount = 0;
-    HANDLE hDirectory = NULL;
-    BOOLEAN bIsByRealObject = FALSE;
-    BOOLEAN bIsSchemaMode = SchemaMode == adMode;
 
-    if (pCookie->bSearchFinished)
-    {
-        // Client programs cannot directly call this function, so typically
-        // this function will not get called after the search is finished.
-        // However, if this function failed in a previous invocation, the
-        // bSearchFinished would be set to true, but the caller would bail out
-        // before moving to the next cell.
-        dwError = LsaAdBatchEnumGetNoMoreError(ObjectType);
-        BAIL_ON_LSA_ERROR(dwError);
-    }
-
-    if ((DEFAULT_MODE == dwDirectoryMode && SchemaMode == adMode) ||
-        (UNPROVISIONED_MODE == dwDirectoryMode))
-    {
-        bIsByRealObject = TRUE;
-    }
-
-    pszAttributeList = bIsByRealObject ? szRealAttributeList : szBacklinkAttributeList;
+    LSA_ASSERT(!pCookie->bSearchFinished);
 
     dwError = LsaAdBatchEnumGetScopeRoot(
                     ObjectType,
@@ -622,15 +571,14 @@ LsaAdBatchEnumObjectsInCell(
 
     while (!pCookie->bSearchFinished && dwRemainingObjectsWanted)
     {
-        dwError = LsaDmLdapDirectoryOnePagedSearch(
-                        pConn,
+        dwError = LsaLdapDirectoryOnePagedSearch(
+                        hDirectory,
                         pszScopeRoot,
                         pszQuery,
                         pszAttributeList,
                         dwRemainingObjectsWanted,
                         pCookie,
                         bIsByRealObject ? LDAP_SCOPE_SUBTREE : LDAP_SCOPE_ONELEVEL,
-                        &hDirectory,
                         &pMessage);
         BAIL_ON_LSA_ERROR(dwError);
 
@@ -638,17 +586,12 @@ LsaAdBatchEnumObjectsInCell(
                         pszDnsDomainName,
                         pszNetbiosDomainName,
                         ObjectType,
-                        dwDirectoryMode,
-                        adMode,
+                        bIsByRealObject,
                         hDirectory,
                         pMessage,
                         dwRemainingObjectsWanted,
                         &dwObjectsCount,
                         &ppObjects);
-        if (dwError == LW_ERROR_NO_MORE_USERS || dwError == LW_ERROR_NO_MORE_GROUPS)
-        {
-            dwError = 0;
-        }
         BAIL_ON_LSA_ERROR(dwError);
 
         ldap_msgfree(pMessage);
@@ -665,13 +608,13 @@ LsaAdBatchEnumObjectsInCell(
     }
 
 cleanup:
-    LW_SAFE_FREE_STRING(pszScopeRoot);
-    LW_SAFE_FREE_STRING(pszNetbiosDomainName);
+    LSA_SAFE_FREE_STRING(pszScopeRoot);
+    LSA_SAFE_FREE_STRING(pszNetbiosDomainName);
     if (pMessage)
     {
         ldap_msgfree(pMessage);
     }
-    ADCacheSafeFreeObjectList(dwObjectsCount, &ppObjects);
+    LsaDbSafeFreeObjectList(dwObjectsCount, &ppObjects);
 
     *pdwObjectsCount = dwTotalObjectsCount;
     *pppObjects = ppTotalObjects;
@@ -680,7 +623,7 @@ cleanup:
 
 error:
     // set OUT params in cleanup.
-    ADCacheSafeFreeObjectList(dwTotalObjectsCount, &ppTotalObjects);
+    LsaDbSafeFreeObjectList(dwTotalObjectsCount, &ppTotalObjects);
     dwTotalObjectsCount = 0;
 
     goto cleanup;
@@ -693,8 +636,11 @@ error:
 static
 DWORD
 LsaAdBatchEnumObjectsInLinkedCells(
-    IN OUT PLW_SEARCH_COOKIE pCookie,
+    IN HANDLE hDirectory,
+    IN OUT PLSA_SEARCH_COOKIE pCookie,
     IN LSA_AD_BATCH_OBJECT_TYPE ObjectType,
+    IN BOOLEAN bIsByRealObject,
+    IN BOOLEAN bIsSchemaMode,
     IN DWORD dwMaxObjectsCount,
     OUT PDWORD pdwObjectsCount,
     OUT PLSA_SECURITY_OBJECT** pppObjects
@@ -706,8 +652,6 @@ LsaAdBatchEnumObjectsInLinkedCells(
     PLSA_SECURITY_OBJECT* ppObjects = *pppObjects;
     DWORD dwObjectsCount = *pdwObjectsCount;
     PAD_CELL_COOKIE_DATA pCookieData = NULL;
-    ADConfigurationMode adMode = gpADProviderData->adConfigurationMode;
-    BOOLEAN bIsDefaultCell = gpADProviderData->dwDirectoryMode == DEFAULT_MODE;
 
     LSA_ASSERT(pCookie->pfnFree == LsaAdBatchFreeCellCookie);
     pCookieData = (PAD_CELL_COOKIE_DATA)pCookie->pvData;
@@ -717,31 +661,12 @@ LsaAdBatchEnumObjectsInLinkedCells(
         PAD_LINKED_CELL_INFO pCellInfo = (PAD_LINKED_CELL_INFO)
             pCookieData->pCurrentCell->pItem;
 
-        if (pCookieData->pLdapConn == NULL)
-        {
-            dwError = LsaDmLdapOpenDc(
-                            pCellInfo->pszDomain,
-                            &pCookieData->pLdapConn);
-            BAIL_ON_LSA_ERROR(dwError);
-        }
-
-        // determine schema/non-schema mode in the current cell
-        dwError = LsaAdBatchQueryCellConfigurationMode(
-                       gpADProviderData->szDomain,
-                       pCellInfo->pszCellDN,
-                       &adMode);
-        BAIL_ON_LSA_ERROR(dwError);
-
-        dwError = LsaAdBatchIsDefaultCell(pCellInfo->pszCellDN,
-                                          &bIsDefaultCell);
-        BAIL_ON_LSA_ERROR(dwError);
-
         dwError = LsaAdBatchEnumObjectsInCell(
-                        pCookieData->pLdapConn,
+                        hDirectory,
                         &pCookieData->LdapCookie,
                         ObjectType,
-                        bIsDefaultCell ? DEFAULT_MODE : CELL_MODE,
-                        adMode,
+                        bIsByRealObject,
+                        bIsSchemaMode,
                         pCellInfo->pszDomain,
                         pCellInfo->pszCellDN,
                         dwMaxObjectsCount - dwObjectsCount,
@@ -759,9 +684,7 @@ LsaAdBatchEnumObjectsInLinkedCells(
         if (pCookieData->LdapCookie.bSearchFinished)
         {
             pCookieData->pCurrentCell = pCookieData->pCurrentCell->pNext;
-            LwFreeCookieContents(&pCookieData->LdapCookie);
-            LsaDmLdapClose(pCookieData->pLdapConn);
-            pCookieData->pLdapConn = NULL;
+            LsaFreeCookieContents(&pCookieData->LdapCookie);
         }
     }
 
@@ -774,13 +697,13 @@ cleanup:
     *pdwObjectsCount = dwObjectsCount;
     *pppObjects = ppObjects;
 
-    ADCacheSafeFreeObjectList(dwObjectsCountInOneCell, &ppObjectsInOneCell);
+    LsaDbSafeFreeObjectList(dwObjectsCountInOneCell, &ppObjectsInOneCell);
 
     return dwError;
 
 error:
    // set OUT params in cleanup...
-   ADCacheSafeFreeObjectList(dwObjectsCount, &ppObjects);
+   LsaDbSafeFreeObjectList(dwObjectsCount, &ppObjects);
    dwObjectsCount = 0;
 
    goto cleanup;
@@ -792,17 +715,20 @@ error:
 // error.
 DWORD
 LsaAdBatchEnumObjects(
-    IN OUT PLW_SEARCH_COOKIE pCookie,
-    IN LSA_OBJECT_TYPE AccountType,
+    IN HANDLE hDirectory,
+    IN OUT PLSA_SEARCH_COOKIE pCookie,
+    IN ADAccountType AccountType,
     IN DWORD dwMaxObjectsCount,
     OUT PDWORD pdwObjectsCount,
     OUT PLSA_SECURITY_OBJECT** pppObjects
     )
 {
     DWORD dwError = 0;
+    BOOLEAN bIsByRealObject = FALSE;
     LSA_AD_BATCH_OBJECT_TYPE objectType = 0;
     DWORD dwObjectsCount = 0;
     PLSA_SECURITY_OBJECT* ppObjects = NULL;
+    BOOLEAN bIsSchemaMode = (gpADProviderData->adConfigurationMode == SchemaMode) ? TRUE : FALSE;
     PAD_CELL_COOKIE_DATA pCookieData = NULL;
     DWORD dwTotalObjectsCount = 0;
     PLSA_SECURITY_OBJECT* ppTotalObjects = NULL;
@@ -810,6 +736,11 @@ LsaAdBatchEnumObjects(
     DWORD dwOutput = 0;
     PSTR pszCopiedSid = NULL;
 
+    if (LsaAdBatchIsDefaultSchemaMode() || LsaAdBatchIsUnprovisionedMode())
+    {
+        bIsByRealObject = TRUE;
+    }
+
     dwError = LsaAdBatchAccountTypeToObjectType(AccountType, &objectType);
     BAIL_ON_LSA_ERROR(dwError);
 
@@ -821,7 +752,7 @@ LsaAdBatchEnumObjects(
 
     if (pCookie->pfnFree == NULL)
     {
-        dwError = LwAllocateMemory(
+        dwError = LsaAllocateMemory(
                         sizeof(AD_CELL_COOKIE_DATA),
                         &pCookie->pvData);
         BAIL_ON_LSA_ERROR(dwError);
@@ -834,7 +765,7 @@ LsaAdBatchEnumObjects(
             dwError = LsaHashCreate(
                             10 * 1024,
                             LsaHashCaselessStringCompare,
-                            LsaHashCaselessStringHash,
+                            LsaHashCaselessString,
                             LsaHashFreeStringKey,
                             NULL,
                             &pCookieData->pEnumeratedSids);
@@ -854,21 +785,13 @@ LsaAdBatchEnumObjects(
     {
         if (pCookieData->pCurrentCell == NULL)
         {
-            if (pCookieData->pLdapConn == NULL)
-            {
-                dwError = LsaDmLdapOpenDc(
-                                gpADProviderData->szDomain,
-                                &pCookieData->pLdapConn);
-                BAIL_ON_LSA_ERROR(dwError);
-            }
-
             // First get the objects from the primary cell
             dwError = LsaAdBatchEnumObjectsInCell(
-                            pCookieData->pLdapConn,
+                            hDirectory,
                             &pCookieData->LdapCookie,
                             objectType,
-                            gpADProviderData->dwDirectoryMode,
-                            gpADProviderData->adConfigurationMode,
+                            bIsByRealObject,
+                            bIsSchemaMode,
                             gpADProviderData->szDomain,
                             gpADProviderData->cell.szCellDN,
                             dwMaxObjectsCount - dwTotalObjectsCount,
@@ -885,9 +808,7 @@ LsaAdBatchEnumObjects(
 
             if (pCookieData->LdapCookie.bSearchFinished)
             {
-                LwFreeCookieContents(&pCookieData->LdapCookie);
-                LsaDmLdapClose(pCookieData->pLdapConn);
-                pCookieData->pLdapConn = NULL;
+                LsaFreeCookieContents(&pCookieData->LdapCookie);
                 pCookieData->pCurrentCell = gpADProviderData->pCellList;
                 if (pCookieData->pCurrentCell == NULL)
                 {
@@ -898,8 +819,11 @@ LsaAdBatchEnumObjects(
         else
         {
             dwError = LsaAdBatchEnumObjectsInLinkedCells(
+                         hDirectory,
                          pCookie,
                          objectType,
+                         bIsByRealObject,
+                         bIsSchemaMode,
                          dwMaxObjectsCount - dwTotalObjectsCount,
                          &dwObjectsCount,
                          &ppObjects);
@@ -922,10 +846,10 @@ LsaAdBatchEnumObjects(
                             pCookieData->pEnumeratedSids,
                             ppTotalObjects[dwInput]->pszObjectSid,
                             NULL);
-                if (dwError == LW_ERROR_SUCCESS)
+                if (dwError == LSA_ERROR_SUCCESS)
                 {
                     // The object is already in the hash
-                    ADCacheSafeFreeObject(&ppTotalObjects[dwInput]);
+                    LsaDbSafeFreeObject(&ppTotalObjects[dwInput]);
                 }
                 else if (dwError == ENOENT)
                 {
@@ -941,7 +865,7 @@ LsaAdBatchEnumObjects(
                         BAIL_ON_LSA_ERROR(dwError);
                     }
 
-                    dwError = LwAllocateString(
+                    dwError = LsaAllocateString(
                                     ppTotalObjects[dwInput]->pszObjectSid,
                                     &pszCopiedSid);
                     BAIL_ON_LSA_ERROR(dwError);
@@ -971,15 +895,15 @@ LsaAdBatchEnumObjects(
 cleanup:
     *pdwObjectsCount = dwTotalObjectsCount;
     *pppObjects = ppTotalObjects;
-    LW_SAFE_FREE_STRING(pszCopiedSid);
+    LSA_SAFE_FREE_STRING(pszCopiedSid);
 
     return dwError;
 
 error:
     // set OUT params in cleanup...
-    ADCacheSafeFreeObjectList(dwObjectsCount, &ppObjects);
+    LsaDbSafeFreeObjectList(dwObjectsCount, &ppObjects);
     dwObjectsCount = 0;
-    ADCacheSafeFreeObjectList(dwTotalObjectsCount, &ppTotalObjects);
+    LsaDbSafeFreeObjectList(dwTotalObjectsCount, &ppTotalObjects);
     dwTotalObjectsCount = 0;
     goto cleanup;
 }
