@@ -62,7 +62,7 @@ LsaAdBatchGatherObjectType(
     if ((ObjectType != LSA_AD_BATCH_OBJECT_TYPE_USER) &&
         (ObjectType != LSA_AD_BATCH_OBJECT_TYPE_GROUP))
     {
-        dwError = LW_ERROR_DATA_ERROR;
+        dwError = LSA_ERROR_DATA_ERROR;
         BAIL_ON_LSA_ERROR(dwError);
     }
     else if (!pItem->ObjectType)
@@ -71,7 +71,7 @@ LsaAdBatchGatherObjectType(
     }
     else if (pItem->ObjectType != ObjectType)
     {
-        dwError = LW_ERROR_DATA_ERROR;
+        dwError = LSA_ERROR_DATA_ERROR;
         BAIL_ON_LSA_ERROR(dwError);
     }
 
@@ -125,15 +125,15 @@ LsaAdBatchGatherSchemaModeUser(
     DWORD dwError = 0;
     DWORD dwValue = 0;
 
-    dwError = LwLdapGetUInt32(
+    dwError = LsaLdapGetUInt32(
                     hDirectory,
                     pMessage,
                     AD_LDAP_UID_TAG,
                     &dwValue);
-    if (LW_ERROR_INVALID_LDAP_ATTR_VALUE == dwError)
+    if (LSA_ERROR_INVALID_LDAP_ATTR_VALUE == dwError)
     {
         SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_DISABLED);
-        dwError = LW_ERROR_SUCCESS;
+        dwError = LSA_ERROR_SUCCESS;
     }
     BAIL_ON_LSA_ERROR(dwError);
 
@@ -146,13 +146,13 @@ LsaAdBatchGatherSchemaModeUser(
     {
         LSA_LOG_DEBUG("uid must be non-zero for SID '%s'", pItem->pszSid);
         // SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_SKIP);
-        dwError = LW_ERROR_DATA_ERROR;
+        dwError = LSA_ERROR_DATA_ERROR;
         BAIL_ON_LSA_ERROR(dwError);
     }
 
     pItem->UserInfo.uid = (uid_t)dwValue;
 
-    dwError = LwLdapGetUInt32(
+    dwError = LsaLdapGetUInt32(
                     hDirectory,
                     pMessage,
                     AD_LDAP_GID_TAG,
@@ -163,41 +163,41 @@ LsaAdBatchGatherSchemaModeUser(
     {
         LSA_LOG_DEBUG("gid must be non-zero for SID '%s'", pItem->pszSid);
         // SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_SKIP);
-        dwError = LW_ERROR_DATA_ERROR;
+        dwError = LSA_ERROR_DATA_ERROR;
         BAIL_ON_LSA_ERROR(dwError);
     }
 
     pItem->UserInfo.gid = (gid_t)dwValue;
 
-    dwError = LwLdapGetString(
+    dwError = LsaLdapGetString(
                     hDirectory,
                     pMessage,
                     AD_LDAP_ALIAS_TAG,
                     &pItem->UserInfo.pszAlias);
     BAIL_ON_LSA_ERROR(dwError);
 
-    dwError = LwLdapGetString(
+    dwError = LsaLdapGetString(
                     hDirectory,
                     pMessage,
                     AD_LDAP_PASSWD_TAG,
                     &pItem->UserInfo.pszPasswd);
     BAIL_ON_LSA_ERROR(dwError);
 
-    dwError = LwLdapGetString(
+    dwError = LsaLdapGetString(
                     hDirectory,
                     pMessage,
                     AD_LDAP_GECOS_TAG,
                     &pItem->UserInfo.pszGecos);
     BAIL_ON_LSA_ERROR(dwError);
 
-    dwError = LwLdapGetString(
+    dwError = LsaLdapGetString(
                     hDirectory,
                     pMessage,
                     AD_LDAP_HOMEDIR_TAG,
                     &pItem->UserInfo.pszHomeDirectory);
     BAIL_ON_LSA_ERROR(dwError);
 
-    dwError = LwLdapGetString(
+    dwError = LsaLdapGetString(
                     hDirectory,
                     pMessage,
                     AD_LDAP_SHELL_TAG,
@@ -222,15 +222,15 @@ LsaAdBatchGatherSchemaModeGroup(
     DWORD dwError = 0;
     DWORD dwValue = 0;
 
-    dwError = LwLdapGetUInt32(
+    dwError = LsaLdapGetUInt32(
                     hDirectory,
                     pMessage,
                     AD_LDAP_GID_TAG,
                     &dwValue);
-    if (LW_ERROR_INVALID_LDAP_ATTR_VALUE == dwError)
+    if (LSA_ERROR_INVALID_LDAP_ATTR_VALUE == dwError)
     {
         SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_DISABLED);
-        dwError = LW_ERROR_SUCCESS;
+        dwError = LSA_ERROR_SUCCESS;
     }
     BAIL_ON_LSA_ERROR(dwError);
 
@@ -243,20 +243,20 @@ LsaAdBatchGatherSchemaModeGroup(
     {
         LSA_LOG_DEBUG("gid must be non-zero for SID '%s'", pItem->pszSid);
         // SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_SKIP);
-        dwError = LW_ERROR_DATA_ERROR;
+        dwError = LSA_ERROR_DATA_ERROR;
         BAIL_ON_LSA_ERROR(dwError);
     }
 
     pItem->GroupInfo.gid = (gid_t)dwValue;
 
-    dwError = LwLdapGetString(
+    dwError = LsaLdapGetString(
                     hDirectory,
                     pMessage,
                     AD_LDAP_DISPLAY_NAME_TAG,
                     &pItem->GroupInfo.pszAlias);
     BAIL_ON_LSA_ERROR(dwError);
 
-    dwError = LwLdapGetString(
+    dwError = LsaLdapGetString(
                     hDirectory,
                     pMessage,
                     AD_LDAP_PASSWD_TAG,
@@ -270,7 +270,6 @@ error:
     goto cleanup;
 }
 
-static
 DWORD
 LsaAdBatchGatherSchemaMode(
     IN OUT PLSA_AD_BATCH_ITEM pItem,
@@ -298,7 +297,7 @@ LsaAdBatchGatherSchemaMode(
             break;
         default:
             LSA_ASSERT(FALSE);
-            dwError = LW_ERROR_INTERNAL;
+            dwError = LSA_ERROR_INTERNAL;
             BAIL_ON_LSA_ERROR(dwError);
     }
 
@@ -325,10 +324,10 @@ LsaAdBatchGatherNonSchemaModeUser(
                     dwKeywordValuesCount,
                     AD_LDAP_UID_TAG,
                     &dwValue);
-    if (LW_ERROR_INVALID_LDAP_ATTR_VALUE == dwError)
+    if (LSA_ERROR_INVALID_LDAP_ATTR_VALUE == dwError)
     {
         SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_DISABLED);
-        dwError = LW_ERROR_SUCCESS;
+        dwError = LSA_ERROR_SUCCESS;
     }
     BAIL_ON_LSA_ERROR(dwError);
 
@@ -341,7 +340,7 @@ LsaAdBatchGatherNonSchemaModeUser(
     {
         LSA_LOG_DEBUG("uid must be non-zero for SID '%s'", pItem->pszSid);
         // SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_SKIP);
-        dwError = LW_ERROR_DATA_ERROR;
+        dwError = LSA_ERROR_DATA_ERROR;
         BAIL_ON_LSA_ERROR(dwError);
     }
 
@@ -358,7 +357,7 @@ LsaAdBatchGatherNonSchemaModeUser(
     {
         LSA_LOG_DEBUG("gid must be non-zero for SID '%s'", pItem->pszSid);
         // SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_SKIP);
-        dwError = LW_ERROR_DATA_ERROR;
+        dwError = LSA_ERROR_DATA_ERROR;
         BAIL_ON_LSA_ERROR(dwError);
     }
 
@@ -422,10 +421,10 @@ LsaAdBatchGatherNonSchemaModeGroup(
                     dwKeywordValuesCount,
                     AD_LDAP_GID_TAG,
                     &dwValue);
-    if (LW_ERROR_INVALID_LDAP_ATTR_VALUE == dwError)
+    if (LSA_ERROR_INVALID_LDAP_ATTR_VALUE == dwError)
     {
         SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_DISABLED);
-        dwError = LW_ERROR_SUCCESS;
+        dwError = LSA_ERROR_SUCCESS;
     }
     BAIL_ON_LSA_ERROR(dwError);
 
@@ -438,7 +437,7 @@ LsaAdBatchGatherNonSchemaModeGroup(
     {
         LSA_LOG_DEBUG("gid must be non-zero for SID '%s'", pItem->pszSid);
         // SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_SKIP);
-        dwError = LW_ERROR_DATA_ERROR;
+        dwError = LSA_ERROR_DATA_ERROR;
         BAIL_ON_LSA_ERROR(dwError);
     }
 
@@ -465,7 +464,6 @@ error:
     goto cleanup;
 }
 
-static
 DWORD
 LsaAdBatchGatherNonSchemaMode(
     IN OUT PLSA_AD_BATCH_ITEM pItem,
@@ -493,7 +491,7 @@ LsaAdBatchGatherNonSchemaMode(
             break;
         default:
             LSA_ASSERT(FALSE);
-            dwError = LW_ERROR_INTERNAL;
+            dwError = LSA_ERROR_INTERNAL;
             BAIL_ON_LSA_ERROR(dwError);
     }
 
@@ -514,6 +512,13 @@ LsaAdBatchGatherUnprovisionedModeUser(
 {
     DWORD dwError = 0;
 
+    // Need the primary group RID to marshal gid later.
+    dwError = LsaLdapGetUInt32(
+                hDirectory,
+                pMessage,
+                AD_LDAP_PRIMEGID_TAG,
+                &pItem->UserInfo.dwPrimaryGroupRid);
+    BAIL_ON_LSA_ERROR(dwError);
 #if 0
     if (dwError != 0)
     {
@@ -525,7 +530,7 @@ LsaAdBatchGatherUnprovisionedModeUser(
 #endif
 
     // Use display name for user gecos.
-    dwError = LwLdapGetString(
+    dwError = LsaLdapGetString(
                     hDirectory,
                     pMessage,
                     AD_LDAP_DISPLAY_NAME_TAG,
@@ -563,7 +568,7 @@ LsaAdBatchGatherUnprovisionedMode(
             break;
         default:
             LSA_ASSERT(FALSE);
-            dwError = LW_ERROR_INTERNAL;
+            dwError = LSA_ERROR_INTERNAL;
             BAIL_ON_LSA_ERROR(dwError);
     }
 
@@ -584,17 +589,9 @@ LsaAdBatchGatherRealUser(
 {
     DWORD dwError = 0;
 
-    dwError = LwLdapGetUInt32(
-                hDirectory,
-                pMessage,
-                AD_LDAP_PRIMEGID_TAG,
-                &pItem->UserInfo.dwPrimaryGroupRid);
-    BAIL_ON_LSA_ERROR(dwError);
-
-
     LSA_ASSERT(!pItem->UserInfo.pszUserPrincipalName);
 
-    dwError = LwLdapGetString(
+    dwError = LsaLdapGetString(
                     hDirectory,
                     pMessage,
                     AD_LDAP_UPN_TAG,
@@ -608,58 +605,35 @@ LsaAdBatchGatherRealUser(
         LsaPrincipalRealmToUpper(pItem->UserInfo.pszUserPrincipalName);
     }
 
-    dwError = LwLdapGetUInt32(
+    dwError = LsaLdapGetUInt32(
                     hDirectory,
                     pMessage,
                     AD_LDAP_USER_CTRL_TAG,
                     &pItem->UserInfo.UserAccountControl);
-    if (dwError == LW_ERROR_INVALID_LDAP_ATTR_VALUE)
+    if (dwError == LSA_ERROR_INVALID_LDAP_ATTR_VALUE)
     {
-        LSA_LOG_VERBOSE(
+        LSA_LOG_ERROR(
                 "User %s has an invalid value for the userAccountControl"
                 " attribute. Please check that it is set and that the "
-                "machine account has permission to read it. Assuming 0x%x",
-                pItem->pszSid, LSA_AD_UF_DEFAULT);
-        pItem->UserInfo.UserAccountControl = LSA_AD_UF_DEFAULT;
-        dwError = 0;
+                "machine account has permission to read it.",
+                pItem->pszSid);
     }
     BAIL_ON_LSA_ERROR(dwError);
 
-    dwError = LwLdapGetUInt64(
+    dwError = LsaLdapGetUInt64(
                     hDirectory,
                     pMessage,
                     AD_LDAP_ACCOUT_EXP_TAG,
                     &pItem->UserInfo.AccountExpires);
-    if (dwError == LW_ERROR_INVALID_LDAP_ATTR_VALUE)
-    {
-        LSA_LOG_VERBOSE(
-                "User %s has an invalid value for the accountExpires"
-                " attribute. Please check that it is set and that the "
-                "machine account has permission to read it.",
-                pItem->pszSid);
-        pItem->UserInfo.AccountExpires = 0;
-        dwError = 0;
-    }
     BAIL_ON_LSA_ERROR(dwError);
 
-    dwError = LwLdapGetUInt64(
+    dwError = LsaLdapGetUInt64(
                     hDirectory,
                     pMessage,
                     AD_LDAP_PWD_LASTSET_TAG,
                     &pItem->UserInfo.PasswordLastSet);
-    if (dwError == LW_ERROR_INVALID_LDAP_ATTR_VALUE)
-    {
-        LSA_LOG_VERBOSE(
-                "User %s has an invalid value for the passwordLastSet"
-                " attribute. Please check that it is set and that the "
-                "machine account has permission to read it.",
-                pItem->pszSid);
-        dwError = ADGetCurrentNtTime(&pItem->UserInfo.PasswordLastSet);
-    }
     BAIL_ON_LSA_ERROR(dwError);
 
-    SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_ACCOUNT_INFO_KNOWN);
-
 cleanup:
     return dwError;
 
@@ -675,31 +649,8 @@ LsaAdBatchGatherRealObject(
     IN HANDLE hDirectory,
     IN LDAPMessage* pMessage
     )
-{
-    return LsaAdBatchGatherRealObjectInternal(
-                pItem,
-                NULL,
-                NULL,
-                ObjectType,
-                ppszSid,
-                hDirectory,
-                pMessage);
-}
-
-DWORD
-LsaAdBatchGatherRealObjectInternal(
-    IN OUT PLSA_AD_BATCH_ITEM pItem,
-    IN OPTIONAL PDWORD pdwDirectoryMode,
-    IN OPTIONAL ADConfigurationMode* pAdMode,
-    IN LSA_AD_BATCH_OBJECT_TYPE ObjectType,
-    IN OUT OPTIONAL PSTR* ppszSid,
-    IN HANDLE hDirectory,
-    IN LDAPMessage* pMessage
-    )
 {
     DWORD dwError = 0;
-    DWORD dwDirectoryMode = pdwDirectoryMode == NULL ? gpADProviderData->dwDirectoryMode : *pdwDirectoryMode;
-    ADConfigurationMode adMode = pAdMode == NULL ? gpADProviderData->adConfigurationMode : *pAdMode;
 
     SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_HAVE_REAL);
 
@@ -719,42 +670,42 @@ LsaAdBatchGatherRealObjectInternal(
         }
     }
 
-    if (LW_IS_NULL_OR_EMPTY_STR(pItem->pszSid))
+    if (IsNullOrEmptyString(pItem->pszSid))
     {
-        dwError = LW_ERROR_DATA_ERROR;
+        dwError = LSA_ERROR_DATA_ERROR;
         BAIL_ON_LSA_ERROR(dwError);
     }
 
     LSA_ASSERT(!pItem->pszSamAccountName);
 
-    dwError = LwLdapGetString(
+    dwError = LsaLdapGetString(
                     hDirectory,
                     pMessage,
                     AD_LDAP_SAM_NAME_TAG,
                     &pItem->pszSamAccountName);
     BAIL_ON_LSA_ERROR(dwError);
-    if (LW_IS_NULL_OR_EMPTY_STR(pItem->pszSamAccountName))
+    if (IsNullOrEmptyString(pItem->pszSamAccountName))
     {
-        dwError = LW_ERROR_DATA_ERROR;
+        dwError = LSA_ERROR_DATA_ERROR;
         BAIL_ON_LSA_ERROR(dwError);
     }
 
     LSA_ASSERT(!pItem->pszDn);
 
-    dwError = LwLdapGetString(
+    dwError = LsaLdapGetString(
                     hDirectory,
                     pMessage,
                     AD_LDAP_DN_TAG,
                     &pItem->pszDn);
     BAIL_ON_LSA_ERROR(dwError);
-    if (LW_IS_NULL_OR_EMPTY_STR(pItem->pszDn))
+    if (IsNullOrEmptyString(pItem->pszDn))
     {
-        dwError = LW_ERROR_DATA_ERROR;
+        dwError = LSA_ERROR_DATA_ERROR;
         BAIL_ON_LSA_ERROR(dwError);
     }
 
     // Handle cases where real contains pseudo.
-    if (DEFAULT_MODE == dwDirectoryMode && SchemaMode == adMode)
+    if (LsaAdBatchIsDefaultSchemaMode())
     {
         // But only if we are not being called by a pseudo
         // lookup for default schema mode.
@@ -768,7 +719,7 @@ LsaAdBatchGatherRealObjectInternal(
             BAIL_ON_LSA_ERROR(dwError);
         }
     }
-    else if (UNPROVISIONED_MODE == dwDirectoryMode)
+    else if (LsaAdBatchIsUnprovisionedMode())
     {
         dwError = LsaAdBatchGatherUnprovisionedMode(
                         pItem,
@@ -795,57 +746,6 @@ error:
     goto cleanup;
 }
 
-DWORD
-LsaAdBatchGatherPseudoObjectDefaultSchema(
-    IN OUT PLSA_AD_BATCH_ITEM pItem,
-    IN LSA_AD_BATCH_OBJECT_TYPE ObjectType,
-    IN OUT OPTIONAL PSTR* ppszSid,
-    IN HANDLE hDirectory,
-    IN LDAPMessage* pMessage
-    )
-{
-    DWORD dwError = 0;
-
-    dwError = LsaAdBatchGatherObjectType(pItem, ObjectType);
-    BAIL_ON_LSA_ERROR(dwError);
-
-    if (!pItem->pszSid)
-    {
-        if (ppszSid)
-        {
-            LSA_XFER_STRING(*ppszSid, pItem->pszSid);
-        }
-        else
-        {
-            dwError = ADLdap_GetObjectSid(hDirectory, pMessage, &pItem->pszSid);
-            BAIL_ON_LSA_ERROR(dwError);
-        }
-    }
-
-    if (LW_IS_NULL_OR_EMPTY_STR(pItem->pszSid))
-    {
-        dwError = LW_ERROR_DATA_ERROR;
-        BAIL_ON_LSA_ERROR(dwError);
-    }
-
-    if (!IsSetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_HAVE_PSEUDO))
-    {
-        SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_HAVE_PSEUDO);
-        dwError = LsaAdBatchGatherSchemaMode(
-                        pItem,
-                        hDirectory,
-                        pMessage);
-        BAIL_ON_LSA_ERROR(dwError);
-    }
-
-cleanup:
-    return dwError;
-
-error:
-    SetFlag(pItem->Flags, LSA_AD_BATCH_ITEM_FLAG_ERROR);
-    goto cleanup;
-}
-
 static
 DWORD
 LsaAdBatchGatherPseudoSid(
@@ -874,13 +774,13 @@ LsaAdBatchGatherPseudoSid(
                                     dwKeywordValuesCount,
                                     ppszKeywordValues,
                                     AD_LDAP_BACKLINK_PSEUDO_TAG);
-        if (LW_IS_NULL_OR_EMPTY_STR(pszSidFromKeywords))
+        if (IsNullOrEmptyString(pszSidFromKeywords))
         {
-            dwError = LW_ERROR_INVALID_SID;
+            dwError = LSA_ERROR_INVALID_SID;
             BAIL_ON_LSA_ERROR(dwError);
         }
 
-        dwError = LwAllocateString(pszSidFromKeywords, &pszSid);
+        dwError = LsaAllocateString(pszSidFromKeywords, &pszSid);
         BAIL_ON_LSA_ERROR(dwError);
     }
 
@@ -889,7 +789,7 @@ cleanup:
     return dwError;
 
 error:
-    LW_SAFE_FREE_STRING(pszSid);
+    LSA_SAFE_FREE_STRING(pszSid);
     goto cleanup;
 }
 
