@@ -50,10 +50,6 @@
 
 #include "adprovider.h"
 
-typedef struct _LSA_DM_WRAP_ENUM_ONE_DOMAIN_INFO_CALLBACK_CONTEXT {
-    IN PCSTR pszDnsDomainName;
-} LSA_DM_WRAP_ENUM_ONE_DOMAIN_INFO_CALLBACK_CONTEXT, *PLSA_DM_WRAP_ENUM_ONE_DOMAIN_INFO_CALLBACK_CONTEXT;
-
 static
 BOOLEAN
 LsaDmWrappFilterExtraForestDomainsCallback(
@@ -160,61 +156,28 @@ LsaDmWrapEnumInMyForestTrustDomains(
                                 pdwCount);
 }
 
-static
-BOOLEAN
-LsaDmWrappFilterFindDomainCallback(
-    IN OPTIONAL PVOID pContext,
-    IN PLSA_DM_CONST_ENUM_DOMAIN_INFO pDomainInfo
-    )
-{
-    BOOLEAN bWantThis = FALSE;
-    PLSA_DM_WRAP_ENUM_ONE_DOMAIN_INFO_CALLBACK_CONTEXT pCtx = (PLSA_DM_WRAP_ENUM_ONE_DOMAIN_INFO_CALLBACK_CONTEXT) pContext;
-
-    // Find a domain info given a specified domain name
-    if (!strcasecmp(pDomainInfo->pszDnsDomainName, pCtx->pszDnsDomainName))
-    {
-        bWantThis = TRUE;
-    }
-
-    return bWantThis;
-}
-
 DWORD
-LsaDmWrapGetDomainEnumInfo(
-    IN PCSTR pszDnsDomainName,
-    OUT PLSA_DM_ENUM_DOMAIN_INFO* ppDomainInfo
+LsaDmWrapGetForestName(
+    IN PCSTR pszDomainName,
+    OUT PSTR* ppszDnsForestName
     )
 {
-    DWORD dwError = 0;
-    LSA_DM_WRAP_ENUM_ONE_DOMAIN_INFO_CALLBACK_CONTEXT context = { 0 };
-    PLSA_DM_ENUM_DOMAIN_INFO* ppDomainInfoList = NULL;
-
-    context.pszDnsDomainName = pszDnsDomainName;
-
-    dwError = LsaDmEnumDomainInfo(LsaDmWrappFilterFindDomainCallback,
-                               &context,
-                               &ppDomainInfoList,
-                               NULL);
-    BAIL_ON_LSA_ERROR(dwError);
-
-    // In case of NOT found, the above function bails out
-    // Double check here again
-    if (!ppDomainInfoList || !ppDomainInfoList[0])
-    {
-        dwError = LW_ERROR_NO_SUCH_DOMAIN;
-        BAIL_ON_LSA_ERROR(dwError);
-    }
-
-    *ppDomainInfo = ppDomainInfoList[0];
-    ppDomainInfoList[0] = NULL;
-
-cleanup:
-    LsaDmFreeEnumDomainInfoArray(ppDomainInfoList);
-
-    return dwError;
-
-error:
-    goto cleanup;
+    return LsaDmQueryDomainInfo(pszDomainName,
+                                NULL,
+                                NULL,
+                                NULL,
+                                NULL,
+                                NULL,
+                                NULL,
+                                NULL,
+                                NULL,
+                                NULL,
+                                NULL,
+                                ppszDnsForestName,
+                                NULL,
+                                NULL,
+                                NULL,
+                                NULL);
 }
 
 DWORD
@@ -257,7 +220,7 @@ LsaDmWrapGetDomainNameAndSidByObjectSid(
     PSID pDomainSid = NULL;
     PSTR pszDomainSid = NULL;
 
-    dwError = LsaAllocateSidFromCString(&pObjectSid, pszObjectSid);
+    dwError = ParseSidString(&pObjectSid, pszObjectSid);
     BAIL_ON_LSA_ERROR(dwError);
 
     dwError = LsaDmQueryDomainInfoByObjectSid(
@@ -281,13 +244,16 @@ LsaDmWrapGetDomainNameAndSidByObjectSid(
 
     if (ppszDomainSid)
     {
-        dwError = LsaAllocateCStringFromSid(&pszDomainSid, pDomainSid);
+        dwError = AD_SidToString(pDomainSid, &pszDomainSid);
         BAIL_ON_LSA_ERROR(dwError);
     }
 
 cleanup:
-    LW_SAFE_FREE_MEMORY(pObjectSid);
-    LW_SAFE_FREE_MEMORY(pDomainSid);
+    if (pObjectSid)
+    {
+        SidFree(pObjectSid);
+    }
+    LSA_SAFE_FREE_MEMORY(pDomainSid);
 
     if (ppszDnsDomainName)
     {
@@ -306,9 +272,214 @@ cleanup:
 
 error:
     // set output in cleanup.
-    LW_SAFE_FREE_STRING(pszDnsDomainName);
-    LW_SAFE_FREE_STRING(pszNetbiosDomainName);
-    LW_SAFE_FREE_STRING(pszDomainSid);
+    LSA_SAFE_FREE_STRING(pszDnsDomainName);
+    LSA_SAFE_FREE_STRING(pszNetbiosDomainName);
+    LSA_SAFE_FREE_STRING(pszDomainSid);
+    goto cleanup;
+}
+
+static
+DWORD
+LsaDmWrappQueryForestNameFromNetlogon(
+    IN PCSTR pszDnsDomainName,
+    OUT PSTR* ppszDnsForestName
+    )
+{
+    DWORD dwError = 0;
+    PLWNET_DC_INFO pDcInfo = NULL;
+    PSTR pszDnsForestName = NULL;
+
+    // Try background first, then not.
+    dwError = LWNetGetDCName(NULL,
+                             pszDnsDomainName,
+                             NULL,
+                             DS_BACKGROUND_ONLY,
+                             &pDcInfo);
+    if (dwError)
+    {
+        dwError = LWNetGetDCName(NULL,
+                                 pszDnsDomainName,
+                                 NULL,
+                                 0,
+                                 &pDcInfo);
+    }
+    BAIL_ON_LSA_ERROR(dwError);
+
+    dwError = LsaAllocateString(pDcInfo->pszDnsForestName, &pszDnsForestName);
+    BAIL_ON_LSA_ERROR(dwError);
+
+    *ppszDnsForestName = pszDnsForestName;
+
+cleanup:
+    LWNET_SAFE_FREE_DC_INFO(pDcInfo);
+    return dwError;
+
+error:
+    *ppszDnsForestName = NULL;
+    LSA_SAFE_FREE_STRING(pszDnsForestName);
+    goto cleanup;
+}
+
+
+#define IsSetFlag(Variable, Flags) (((Variable) & (Flags)) != 0)
+
+typedef DWORD LSA_DM_WRAP_CONNECT_DOMAIN_FLAGS;
+
+#define LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_GC           0x00000001
+#define LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_DC_INFO      0x00000002
+#define LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_AUTH         0x00000004
+
+typedef DWORD (*PFLSA_DM_WRAP_CONNECT_CALLBACK)(
+    IN PCSTR pszDnsDomainOrForestName,
+    IN OPTIONAL PLWNET_DC_INFO pDcInfo,
+    IN OPTIONAL PVOID pContext,
+    OUT PBOOLEAN pbIsNetworkError
+    );
+
+BOOLEAN
+LsaDmWrappIsNetworkError(
+    IN DWORD dwError
+    )
+{
+    BOOLEAN bIsNetworkError = FALSE;
+
+    switch (dwError)
+    {
+        case LSA_ERROR_DOMAIN_IS_OFFLINE:
+        case LWNET_ERROR_INVALID_DNS_RESPONSE:
+        case LWNET_ERROR_FAILED_FIND_DC:
+            bIsNetworkError = TRUE;
+            break;
+        default:
+            bIsNetworkError = FALSE;
+            break;
+    }
+
+    return bIsNetworkError;
+}
+
+static
+DWORD
+LsaDmWrappConnectDomain(
+    IN PCSTR pszDnsDomainName,
+    IN LSA_DM_WRAP_CONNECT_DOMAIN_FLAGS dwConnectFlags,
+    IN PLWNET_DC_INFO pDcInfo,
+    IN PFLSA_DM_WRAP_CONNECT_CALLBACK pfConnectCallback,
+    IN OPTIONAL PVOID pContext
+    )
+{
+    DWORD dwError = 0;
+    PSTR pszDnsForestName = NULL;
+    PCSTR pszDnsDomainOrForestName = pszDnsDomainName;
+    PLWNET_DC_INFO pLocalDcInfo = NULL;
+    PLWNET_DC_INFO pActualDcInfo = pDcInfo;
+    DWORD dwGetDcNameFlags = 0;
+    BOOLEAN bIsNetworkError = FALSE;
+    BOOLEAN bUseGc = IsSetFlag(dwConnectFlags, LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_GC);
+    BOOLEAN bUseDcInfo = IsSetFlag(dwConnectFlags, LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_DC_INFO);
+
+    if (bUseGc)
+    {
+        dwError = LsaDmWrapGetForestName(pszDnsDomainName,
+                                         &pszDnsForestName);
+        BAIL_ON_LSA_ERROR(dwError);
+        if (!pszDnsForestName)
+        {
+            // This is the case where there is an external trust such
+            // that we do not have forest root information.
+            // So let's do what we can.
+
+            // ISSUE-2008/09/22-dalmeida -- It is likely never correct to
+            // access the GC for an external trust.  We should check the
+            // trust attributes here and ASSERT some invariants.
+            // For now, however, we will log and try our best to comply
+            // with the caller.  This should help identify whether
+            // there are any mis-uses.
+            LSA_LOG_WARNING("Trying to access forest root for probable external trust (%s).",
+                            pszDnsDomainName);
+            dwError = LsaDmWrappQueryForestNameFromNetlogon(
+                        pszDnsDomainName,
+                        &pszDnsForestName);
+            BAIL_ON_LSA_ERROR(dwError);
+        }
+        pszDnsDomainOrForestName = pszDnsForestName;
+        dwGetDcNameFlags |= DS_GC_SERVER_REQUIRED;
+    }
+
+    if (LsaDmIsDomainOffline(pszDnsDomainOrForestName))
+    {
+        dwError = LSA_ERROR_DOMAIN_IS_OFFLINE;
+        BAIL_ON_LSA_ERROR(dwError);
+    }
+
+    if (IsSetFlag(dwConnectFlags, LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_AUTH))
+    {
+        dwError = AD_MachineCredentialsCacheInitialize();
+        BAIL_ON_LSA_ERROR(dwError);
+    }
+
+    if (bUseDcInfo && !pActualDcInfo)
+    {
+        dwError = LWNetGetDCName(NULL,
+                                 pszDnsDomainOrForestName,
+                                 NULL,
+                                 dwGetDcNameFlags,
+                                 &pLocalDcInfo);
+        bIsNetworkError = LsaDmWrappIsNetworkError(dwError);
+        BAIL_ON_LSA_ERROR(dwError);
+        pActualDcInfo = pLocalDcInfo;
+    }
+
+    dwError = pfConnectCallback(pszDnsDomainOrForestName,
+                                pActualDcInfo,
+                                pContext,
+                                &bIsNetworkError);
+    if (!dwError)
+    {
+        goto cleanup;
+    }
+    if (!bIsNetworkError)
+    {
+        BAIL_ON_LSA_ERROR(dwError);
+    }
+    if (!bUseDcInfo)
+    {
+        BAIL_ON_LSA_ERROR(dwError);
+    }
+
+    LWNET_SAFE_FREE_DC_INFO(pLocalDcInfo);
+    pActualDcInfo = NULL;
+    dwError = LWNetGetDCName(NULL,
+                             pszDnsDomainOrForestName,
+                             NULL,
+                             dwGetDcNameFlags | DS_FORCE_REDISCOVERY,
+                             &pLocalDcInfo);
+    bIsNetworkError = LsaDmWrappIsNetworkError(dwError);
+    BAIL_ON_LSA_ERROR(dwError);
+    pActualDcInfo = pLocalDcInfo;
+
+    dwError = pfConnectCallback(pszDnsDomainOrForestName,
+                                pActualDcInfo,
+                                pContext,
+                                &bIsNetworkError);
+    BAIL_ON_LSA_ERROR(dwError);
+
+cleanup:
+    LWNET_SAFE_FREE_DC_INFO(pLocalDcInfo);
+    LSA_SAFE_FREE_STRING(pszDnsForestName);
+    return dwError;
+
+error:
+    if (bIsNetworkError)
+    {
+        DWORD dwLocalError = LsaDmTransitionOffline(pszDnsDomainOrForestName);
+        if (dwLocalError)
+        {
+            LSA_LOG_DEBUG("Error %d transitioning %s offline",
+                          dwLocalError, pszDnsDomainOrForestName);
+        }
+        dwError = LSA_ERROR_DOMAIN_IS_OFFLINE;
+    }
     goto cleanup;
 }
 
@@ -324,13 +495,11 @@ typedef struct _LSA_DM_WRAP_LDAP_OPEN_DIRECORY_CALLBACK_CONTEXT {
 typedef struct _LSA_DM_WRAP_LOOKUP_SID_BY_NAME_CALLBACK_CONTEXT {
     IN PCSTR pszName;
     OUT PSTR pszSid;
-    OUT LSA_OBJECT_TYPE ObjectType;
 } LSA_DM_WRAP_LOOKUP_SID_BY_NAME_CALLBACK_CONTEXT, *PLSA_DM_WRAP_LOOKUP_SID_BY_NAME_CALLBACK_CONTEXT;
 
 typedef struct _LSA_DM_WRAP_LOOKUP_NAME_BY_SID_CALLBACK_CONTEXT {
     IN PCSTR pszSid;
     OUT PSTR pszNT4Name;
-    OUT LSA_OBJECT_TYPE ObjectType;
 } LSA_DM_WRAP_LOOKUP_NAME_BY_SID_CALLBACK_CONTEXT, *PLSA_DM_WRAP_LOOKUP_NAME_BY_SID_CALLBACK_CONTEXT;
 
 typedef struct _LSA_DM_WRAP_LOOKUP_NAMES_BY_SIDS_CALLBACK_CONTEXT {
@@ -353,18 +522,6 @@ typedef struct _LSA_DM_WRAP_ENUM_DOMAIN_TRUSTS_CALLBACK_CONTEXT {
     OUT DWORD dwCount;
 } LSA_DM_WRAP_ENUM_DOMAIN_TRUSTS_CALLBACK_CONTEXT, *PLSA_DM_WRAP_ENUM_DOMAIN_TRUSTS_CALLBACK_CONTEXT;
 
-typedef struct _LSA_DM_WRAP_GET_DC_NAME_CALLBACK_CONTEXT {
-    IN PCSTR pszDomainName;
-    IN BOOLEAN bReturnDnsName;
-    OUT PSTR pszDomainDnsOrFlatName;
-    OUT PSTR pszDomainForestDnsName;
-} LSA_DM_WRAP_GET_DC_NAME_CALLBACK_CONTEXT, *PLSA_DM_WRAP_GET_DC_NAME_CALLBACK_CONTEXT;
-
-typedef struct _LSA_DM_WRAP_AUTH_USER_EX_CALLBACK_CONTEXT {
-    IN PLSA_AUTH_USER_PARAMS pUserParams;
-    OUT PLSA_AUTH_USER_INFO  *ppUserInfo;
-} LSA_DM_WRAP_AUTH_USER_EX_CALLBACK_CONTEXT, *PLSA_DM_WRAP_AUTH_USER_EX_CALLBACK_CONTEXT;
-
 ///
 /// Callback functions
 ///
@@ -380,7 +537,45 @@ LsaDmWrappLdapPingTcpCallback(
 {
     DWORD dwError = 0;
 
-    dwError = LwLdapPingTcp(pDcInfo->pszDomainControllerAddress, 5);
+    dwError = LsaLdapPingTcp(pDcInfo->pszDomainControllerAddress, 5);
+    *pbIsNetworkError = dwError ? TRUE : FALSE;
+    return dwError;
+}
+
+static
+DWORD
+LsaDmWrappLdapOpenDirectoryDomainCallback(
+    IN PCSTR pszDnsDomainOrForestName,
+    IN OPTIONAL PLWNET_DC_INFO pDcInfo,
+    IN OPTIONAL PVOID pContext,
+    OUT PBOOLEAN pbIsNetworkError
+    )
+{
+    DWORD dwError = 0;
+    PLSA_DM_WRAP_LDAP_OPEN_DIRECORY_CALLBACK_CONTEXT pCtx = (PLSA_DM_WRAP_LDAP_OPEN_DIRECORY_CALLBACK_CONTEXT) pContext;
+
+    dwError = LsaLdapOpenDirectoryDomain(pszDnsDomainOrForestName,
+                                         pCtx->dwFlags,
+                                         &pCtx->hDirectory);
+    *pbIsNetworkError = dwError ? TRUE : FALSE;
+    return dwError;
+}
+
+static
+DWORD
+LsaDmWrappLdapOpenDirectoryGcCallback(
+    IN PCSTR pszDnsDomainOrForestName,
+    IN OPTIONAL PLWNET_DC_INFO pDcInfo,
+    IN OPTIONAL PVOID pContext,
+    OUT PBOOLEAN pbIsNetworkError
+    )
+{
+    DWORD dwError = 0;
+    PLSA_DM_WRAP_LDAP_OPEN_DIRECORY_CALLBACK_CONTEXT pCtx = (PLSA_DM_WRAP_LDAP_OPEN_DIRECORY_CALLBACK_CONTEXT) pContext;
+
+    dwError = LsaLdapOpenDirectoryGc(pszDnsDomainOrForestName,
+                                     pCtx->dwFlags,
+                                     &pCtx->hDirectory);
     *pbIsNetworkError = dwError ? TRUE : FALSE;
     return dwError;
 }
@@ -400,7 +595,6 @@ LsaDmWrappLookupSidByNameCallback(
     dwError = AD_NetLookupObjectSidByName(pDcInfo->pszDomainControllerName,
                                           pCtx->pszName,
                                           &pCtx->pszSid,
-                                          &pCtx->ObjectType,
                                           pbIsNetworkError);
     return dwError;
 }
@@ -420,7 +614,6 @@ LsaDmWrappLookupNameBySidCallback(
                     pDcInfo->pszDomainControllerName,
                     pCtx->pszSid,
                     &pCtx->pszNT4Name,
-                    &pCtx->ObjectType,
                     pbIsNetworkError);
 }
 
@@ -484,27 +677,6 @@ LsaDmWrappDsEnumerateDomainTrustsCallback(
     return dwError;
 }
 
-static
-DWORD
-LsaDmWrappDsGetDcNameCallback(
-    IN PCSTR pszDnsDomainOrForestName,
-    IN OPTIONAL PLWNET_DC_INFO pDcInfo,
-    IN OPTIONAL PVOID pContext,
-    OUT PBOOLEAN pbIsNetworkError
-    )
-{
-    DWORD dwError = 0;
-    PLSA_DM_WRAP_GET_DC_NAME_CALLBACK_CONTEXT pCtx = (PLSA_DM_WRAP_GET_DC_NAME_CALLBACK_CONTEXT) pContext;
-
-    dwError = AD_DsGetDcName(pDcInfo->pszDomainControllerName,
-                             pCtx->pszDomainName,
-                             pCtx->bReturnDnsName,
-                             &pCtx->pszDomainDnsOrFlatName,
-                             &pCtx->pszDomainForestDnsName,
-                             pbIsNetworkError);
-    return dwError;
-}
-
 ///
 /// Connect wrap functions
 ///
@@ -516,20 +688,70 @@ LsaDmWrapLdapPingTcp(
 {
     DWORD dwError = 0;
 
-    dwError = LsaDmConnectDomain(pszDnsDomainName,
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_DC_INFO,
+    dwError = LsaDmWrappConnectDomain(pszDnsDomainName,
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_DC_INFO,
                                       NULL,
                                       LsaDmWrappLdapPingTcpCallback,
                                       NULL);
     return dwError;
 }
 
+DWORD
+LsaDmWrapLdapOpenDirectoryDomain(
+    IN PCSTR pszDnsDomainName,
+    OUT PHANDLE phDirectory
+    )
+{
+    DWORD dwError = 0;
+    LSA_DM_WRAP_LDAP_OPEN_DIRECORY_CALLBACK_CONTEXT context = { 0 };
+
+    if (AD_GetLDAPSignAndSeal())
+    {
+        context.dwFlags |= LSA_LDAP_OPT_SIGN_AND_SEAL;
+    }
+
+    dwError = LsaDmWrappConnectDomain(pszDnsDomainName,
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_AUTH,
+                                      NULL,
+                                      LsaDmWrappLdapOpenDirectoryDomainCallback,
+                                      &context);
+
+    *phDirectory = context.hDirectory;
+
+    return dwError;
+}
+
+DWORD
+LsaDmWrapLdapOpenDirectoryGc(
+    IN PCSTR pszDnsDomainName,
+    OUT PHANDLE phDirectory
+    )
+{
+    DWORD dwError = 0;
+    LSA_DM_WRAP_LDAP_OPEN_DIRECORY_CALLBACK_CONTEXT context = { 0 };
+
+    if (AD_GetLDAPSignAndSeal())
+    {
+        context.dwFlags |= LSA_LDAP_OPT_SIGN_AND_SEAL;
+    }
+
+    dwError = LsaDmWrappConnectDomain(pszDnsDomainName,
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_AUTH |
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_GC,
+                                      NULL,
+                                      LsaDmWrappLdapOpenDirectoryGcCallback,
+                                      &context);
+
+    *phDirectory = context.hDirectory;
+
+    return dwError;
+}
+
 DWORD
 LsaDmWrapNetLookupObjectSidByName(
     IN PCSTR pszDnsDomainName,
     IN PCSTR pszName,
-    OUT PSTR* ppszSid,
-    OUT OPTIONAL LSA_OBJECT_TYPE* pAccountType
+    OUT PSTR* ppszSid
     )
 {
     DWORD dwError = 0;
@@ -537,20 +759,15 @@ LsaDmWrapNetLookupObjectSidByName(
 
     context.pszName = pszName;
 
-    dwError = LsaDmConnectDomain(pszDnsDomainName,
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_AUTH |
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_DC_INFO,
+    dwError = LsaDmWrappConnectDomain(pszDnsDomainName,
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_AUTH |
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_DC_INFO,
                                       NULL,
                                       LsaDmWrappLookupSidByNameCallback,
                                       &context);
 
     *ppszSid = context.pszSid;
 
-    if (pAccountType)
-    {
-        *pAccountType = context.ObjectType;
-    }
-
     return dwError;
 }
 
@@ -558,8 +775,7 @@ DWORD
 LsaDmWrapNetLookupNameByObjectSid(
     IN  PCSTR pszDnsDomainName,
     IN  PCSTR pszSid,
-    OUT PSTR* ppszName,
-    OUT OPTIONAL LSA_OBJECT_TYPE* pAccountType
+    OUT PSTR* ppszName
     )
 {
     DWORD dwError = 0;
@@ -567,20 +783,15 @@ LsaDmWrapNetLookupNameByObjectSid(
 
     context.pszSid = pszSid;
 
-    dwError = LsaDmConnectDomain(pszDnsDomainName,
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_AUTH |
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_DC_INFO,
+    dwError = LsaDmWrappConnectDomain(pszDnsDomainName,
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_AUTH |
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_DC_INFO,
                                       NULL,
                                       LsaDmWrappLookupNameBySidCallback,
                                       &context);
 
     *ppszName = context.pszNT4Name;
 
-    if (pAccountType)
-    {
-        *pAccountType = context.ObjectType;
-    }
-
     return dwError;
 }
 
@@ -599,9 +810,9 @@ LsaDmWrapNetLookupNamesByObjectSids(
     context.ppszSids = ppszSids;
     context.dwSidCounts = dwSidCounts;
 
-    dwError = LsaDmConnectDomain(pszDnsDomainName,
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_AUTH |
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_DC_INFO,
+    dwError = LsaDmWrappConnectDomain(pszDnsDomainName,
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_AUTH |
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_DC_INFO,
                                       NULL,
                                       LsaDmWrappLookupNamesBySidsCallback,
                                       &context);
@@ -627,9 +838,9 @@ LsaDmWrapNetLookupObjectSidsByNames(
     context.ppszNames = ppszNames;
     context.dwNameCounts = dwNameCounts;
 
-    dwError = LsaDmConnectDomain(pszDnsDomainName,
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_AUTH |
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_DC_INFO,
+    dwError = LsaDmWrappConnectDomain(pszDnsDomainName,
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_AUTH |
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_DC_INFO,
                                       NULL,
                                       LsaDmWrappLookupSidsByNamesCallback,
                                       &context);
@@ -653,9 +864,9 @@ LsaDmWrapDsEnumerateDomainTrusts(
 
     context.dwFlags = dwFlags;
 
-    dwError = LsaDmConnectDomain(pszDnsDomainName,
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_AUTH |
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_DC_INFO,
+    dwError = LsaDmWrappConnectDomain(pszDnsDomainName,
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_AUTH |
+                                      LSA_DM_WRAP_CONNECT_DOMAIN_FLAG_DC_INFO,
                                       NULL,
                                       LsaDmWrappDsEnumerateDomainTrustsCallback,
                                       &context);
@@ -666,80 +877,3 @@ LsaDmWrapDsEnumerateDomainTrusts(
     return dwError;
 }
 
-DWORD
-LsaDmWrapDsGetDcName(
-    IN PCSTR pszDnsDomainName,
-    IN PCSTR pszFindDomainName,
-    IN BOOLEAN bReturnDnsName,
-    OUT PSTR* ppszDomainDnsOrFlatName,
-    OUT OPTIONAL PSTR* ppszDomainForestDnsName
-    )
-{
-    DWORD dwError = 0;
-    LSA_DM_WRAP_GET_DC_NAME_CALLBACK_CONTEXT context = { 0 };
-
-    context.pszDomainName = pszFindDomainName;
-    context.bReturnDnsName = bReturnDnsName;
-
-    dwError = LsaDmConnectDomain(pszDnsDomainName,
-                                 LSA_DM_CONNECT_DOMAIN_FLAG_AUTH |
-                                 LSA_DM_CONNECT_DOMAIN_FLAG_DC_INFO,
-                                 NULL,
-                                 LsaDmWrappDsGetDcNameCallback,
-                                 &context);
-
-    *ppszDomainDnsOrFlatName = context.pszDomainDnsOrFlatName;
-    if (ppszDomainForestDnsName)
-    {
-        *ppszDomainForestDnsName = context.pszDomainForestDnsName;
-    }
-    else
-    {
-        LW_SAFE_FREE_STRING(context.pszDomainForestDnsName);
-    }
-
-    return dwError;
-}
-
-static
-DWORD
-LsaDmWrappAuthenticateUserExCallback(
-    IN PCSTR pszDnsDomainOrForestName,
-    IN OPTIONAL PLWNET_DC_INFO pDcInfo,
-    IN OPTIONAL PVOID pContext,
-    OUT PBOOLEAN pbIsNetworkError
-    )
-{
-    PLSA_DM_WRAP_AUTH_USER_EX_CALLBACK_CONTEXT pCtx = (PLSA_DM_WRAP_AUTH_USER_EX_CALLBACK_CONTEXT) pContext;
-
-    return AD_NetlogonAuthenticationUserEx(
-                    pDcInfo->pszDomainControllerName,
-                    pCtx->pUserParams,
-                    pCtx->ppUserInfo,
-                    pbIsNetworkError);
-}
-
-DWORD
-LsaDmWrapAuthenticateUserEx(
-    IN PCSTR pszDnsDomainName,
-    IN PLSA_AUTH_USER_PARAMS pUserParams,
-    OUT PLSA_AUTH_USER_INFO *ppUserInfo
-    )
-{
-    DWORD dwError = 0;
-    LSA_DM_WRAP_AUTH_USER_EX_CALLBACK_CONTEXT context = { 0 };
-
-    context.pUserParams = pUserParams;
-    context.ppUserInfo = ppUserInfo;
-
-    dwError = LsaDmConnectDomain(pszDnsDomainName,
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_AUTH |
-                                      LSA_DM_CONNECT_DOMAIN_FLAG_DC_INFO,
-                                      NULL,
-                                      LsaDmWrappAuthenticateUserExCallback,
-                                      &context);
-
-    *ppUserInfo = *(context.ppUserInfo);
-
-    return dwError;
-}
