@@ -57,7 +57,7 @@ AD_OfflineGetGroupMembers(
     OUT PLSA_SECURITY_OBJECT** pppMemberObjects
     )
 {
-    DWORD dwError = LW_ERROR_SUCCESS;
+    DWORD dwError = LSA_ERROR_SUCCESS;
     size_t sGroupMembershipsCount = 0;
     PLSA_GROUP_MEMBERSHIP* ppGroupMemberships = NULL;
     size_t sMemberSidsCount = 0;
@@ -68,7 +68,7 @@ AD_OfflineGetGroupMembers(
     PLSA_SECURITY_OBJECT* ppObjects = NULL;
     size_t sIndex = 0;
 
-    dwError = ADCacheGetGroupMembers(
+    dwError = LsaDbGetGroupMembers(
         gpLsaAdProviderState->hCacheConnection,
         pszGroupSid,
         AD_GetTrimUserMembershipEnabled(),
@@ -76,7 +76,7 @@ AD_OfflineGetGroupMembers(
         &ppGroupMemberships);
     BAIL_ON_LSA_ERROR(dwError);
 
-    dwError = LwAllocateMemory(
+    dwError = LsaAllocateMemory(
         sizeof(*ppszMemberSids) * sGroupMembershipsCount,
         (PVOID*)&ppszMemberSids);
     BAIL_ON_LSA_ERROR(dwError);
@@ -106,9 +106,9 @@ AD_OfflineGetGroupMembers(
     sObjectsCount = 0;
 
 cleanup:
-    ADCacheSafeFreeObjectList(sObjectsCount, &ppObjects);
-    LW_SAFE_FREE_MEMORY(ppszMemberSids);
-    ADCacheSafeFreeGroupMembershipList(sGroupMembershipsCount,
+    LsaDbSafeFreeObjectList(sObjectsCount, &ppObjects);
+    LSA_SAFE_FREE_MEMORY(ppszMemberSids);
+    LsaDbSafeFreeGroupMembershipList(sGroupMembershipsCount,
                                           &ppGroupMemberships);
 
     return dwError;
@@ -127,14 +127,14 @@ AD_OfflineFindObjectsBySidList(
     OUT PLSA_SECURITY_OBJECT** pppObjects
     )
 {
-    DWORD dwError = LW_ERROR_SUCCESS;
+    DWORD dwError = LSA_ERROR_SUCCESS;
     PLSA_SECURITY_OBJECT *ppObjects = NULL;
 
     /* 
      * Lookup users and groups from the cache.
      */
 
-    dwError = ADCacheFindObjectsBySidList(
+    dwError = LsaDbFindObjectsBySidList(
                     gpLsaAdProviderState->hCacheConnection,
                     sCount,
                     ppszSidList,
@@ -145,7 +145,7 @@ AD_OfflineFindObjectsBySidList(
     ppObjects = NULL;
 
 cleanup:
-    ADCacheSafeFreeObjectList(sCount, &ppObjects);
+    LsaDbSafeFreeObjectList(sCount, &ppObjects);
     return dwError;
 
 error:
@@ -165,9 +165,9 @@ AD_GatherSidsFromGroupMemberships(
 {
     // NOTE: The result points to the sids inside the memberships.
     // Do not deallocate the memberhips while using the result.
-    // Call LW_SAFE_FREE_MEMORY() on result when done so as to
+    // Call LSA_SAFE_FREE_MEMORY() on result when done so as to
     // not free up the sids (which reside in the memberships).
-    DWORD dwError = LW_ERROR_SUCCESS;
+    DWORD dwError = LSA_ERROR_SUCCESS;
     // Do not free actual strings, just the array.
     PSTR* ppszSids = NULL;
     size_t sSidsCount = 0;
@@ -228,7 +228,7 @@ AD_GatherSidsFromGroupMemberships(
         }
 
         // Allocate memory so we can gather up stuff.
-        dwError = LwAllocateMemory(sizeof(*ppszSids) * sMemberhipsCount,
+        dwError = LsaAllocateMemory(sizeof(*ppszSids) * sMemberhipsCount,
                                     (PVOID*)&ppszSids);
         BAIL_ON_LSA_ERROR(dwError);
 
@@ -243,7 +243,7 @@ cleanup:
     return dwError;
 
 error:
-    LW_SAFE_FREE_MEMORY(ppszSids);
+    LSA_SAFE_FREE_MEMORY(ppszSids);
     sSidsCount = 0;
     goto cleanup;
 }
@@ -269,7 +269,7 @@ AD_GroupExpansionDataCreate(
     PLSA_AD_GROUP_EXPANSION_DATA pExpansionData = NULL;
     const size_t sNumberOfBuckets = 20;
 
-    dwError = LwAllocateMemory(
+    dwError = LsaAllocateMemory(
                 sizeof(*pExpansionData),
                 (PVOID*) &pExpansionData);
     BAIL_ON_LSA_ERROR(dwError);
@@ -332,27 +332,7 @@ AD_GroupExpansionDataAddExpansionResults(
     if (dwExpandedGroupDepth > pExpansionData->dwMaxDepth)
     {
         // This should never happen
-        dwError = LW_ERROR_INTERNAL;
-        BAIL_ON_LSA_ERROR(dwError);
-    }
-
-    if ((sMembersCount + pExpansionData->pUsers->sCount) * 2 >
-            pExpansionData->pUsers->sTableSize)
-    {
-        dwError = LsaHashResize(
-                        pExpansionData->pUsers,
-                        (sMembersCount +
-                             pExpansionData->pUsers->sCount + 10) * 3);
-        BAIL_ON_LSA_ERROR(dwError);
-    }
-
-    if ((sMembersCount + pExpansionData->pGroupsToExpand->sCount) * 2 >
-            pExpansionData->pGroupsToExpand->sTableSize)
-    {
-        dwError = LsaHashResize(
-                        pExpansionData->pGroupsToExpand,
-                        (sMembersCount +
-                             pExpansionData->pGroupsToExpand->sCount + 10) * 3);
+        dwError = LSA_ERROR_INTERNAL;
         BAIL_ON_LSA_ERROR(dwError);
     }
 
@@ -365,36 +345,28 @@ AD_GroupExpansionDataAddExpansionResults(
             continue;
         }
 
-        if (pCurrentMember->type == LSA_OBJECT_TYPE_USER)
+        if (pCurrentMember->type == AccountType_User)
         {
-            if (!LsaHashExists(pExpansionData->pUsers,
-                               ppMembers[sMembersCount-1]))
-            {
-                dwError = LsaHashSetValue(
-                    pExpansionData->pUsers,
-                    ppMembers[sMembersCount-1],
-                    (PVOID)(size_t)dwExpandedGroupDepth);
-                BAIL_ON_LSA_ERROR(dwError);
-                ppMembers[sMembersCount-1] = NULL;
-            }
-            else
-            {
-                ADCacheSafeFreeObject(&ppMembers[sMembersCount-1]);
-            }
+            dwError = LsaHashSetValue(
+                        pExpansionData->pUsers,
+                        ppMembers[sMembersCount-1],
+                        (PVOID)(size_t)dwExpandedGroupDepth);
+            BAIL_ON_LSA_ERROR(dwError);
+            ppMembers[sMembersCount-1] = NULL;
         }
-        else if (pCurrentMember->type == LSA_OBJECT_TYPE_GROUP)
+        else if (pCurrentMember->type == AccountType_Group)
         {
             if (dwExpandedGroupDepth >= pExpansionData->dwMaxDepth)
             {
                 pExpansionData->bDiscardedDueToDepth = TRUE;
-                ADCacheSafeFreeObject(&ppMembers[sMembersCount-1]);
+                LsaDbSafeFreeObject(&ppMembers[sMembersCount-1]);
             }
             else if (LsaHashExists(pExpansionData->pExpandedGroups,
                                    pCurrentMember) ||
                      LsaHashExists(pExpansionData->pGroupsToExpand,
                                    pCurrentMember))
             {
-                ADCacheSafeFreeObject(&ppMembers[sMembersCount-1]);
+                LsaDbSafeFreeObject(&ppMembers[sMembersCount-1]);
             }
             else
             {
@@ -409,21 +381,21 @@ AD_GroupExpansionDataAddExpansionResults(
         else
         {
             // some other kind of object -- should not happen
-            ADCacheSafeFreeObject(&ppMembers[sMembersCount-1]);
+            LsaDbSafeFreeObject(&ppMembers[sMembersCount-1]);
         }
     }
 
 cleanup:
     if (ppMembers && (sMembersCount == 0))
     {
-        ADCacheSafeFreeObjectList(sMembersCount, &ppMembers);
+        LsaDbSafeFreeObjectList(sMembersCount, &ppMembers);
     }
     *psMembersCount = sMembersCount;
     *pppMembers = ppMembers;
     return dwError;
 
 error:
-    ADCacheSafeFreeObjectList(sMembersCount, &ppMembers);
+    LsaDbSafeFreeObjectList(sMembersCount, &ppMembers);
     if (dwError && !pExpansionData->dwLastError)
     {
         pExpansionData->dwLastError = dwError;
@@ -471,7 +443,7 @@ AD_GroupExpansionDataGetNextGroupToExpand(
         pHashEntry = LsaHashNext(&pExpansionData->GroupsToExpandIterator);
         if (!pHashEntry)
         {
-            dwError = LW_ERROR_INTERNAL;
+            dwError = LSA_ERROR_INTERNAL;
             BAIL_ON_LSA_ERROR(dwError);
         }
     }
@@ -504,7 +476,7 @@ cleanup:
     return dwError;
 
 error:
-    ADCacheSafeFreeObject(&pGroupToExpand);
+    LsaDbSafeFreeObject(&pGroupToExpand);
     dwGroupToExpandDepth = 0;
 
     if (dwError && !pExpansionData->dwLastError)
@@ -535,7 +507,7 @@ AD_GroupExpansionDataGetResults(
 
     // Fill in the final list of users and return it.
     sHashCount = pExpansionData->pUsers->sCount;
-    dwError = LwAllocateMemory(
+    dwError = LsaAllocateMemory(
                 sizeof(*ppUserMembers) * sHashCount,
                 (PVOID*)&ppUserMembers);
     BAIL_ON_LSA_ERROR(dwError);
@@ -557,7 +529,7 @@ AD_GroupExpansionDataGetResults(
 
     if (sUserMembersCount != sHashCount)
     {
-        dwError = LW_ERROR_INTERNAL;
+        dwError = LSA_ERROR_INTERNAL;
         BAIL_ON_LSA_ERROR(dwError);
     }
 
@@ -579,7 +551,7 @@ cleanup:
     return dwError;
 
 error:
-    ADCacheSafeFreeObjectList(sUserMembersCount, &ppUserMembers);
+    LsaDbSafeFreeObjectList(sUserMembersCount, &ppUserMembers);
     sUserMembersCount = 0;
 
     if (dwError && !pExpansionData->dwLastError)
@@ -611,7 +583,7 @@ AD_GroupExpansionDataDestroy(
         LsaHashSafeFree(&pExpansionData->pGroupsToExpand);
         LsaHashSafeFree(&pExpansionData->pExpandedGroups);
         LsaHashSafeFree(&pExpansionData->pUsers);
-        LwFreeMemory(pExpansionData);
+        LsaFreeMemory(pExpansionData);
     }
 }
 
