@@ -94,14 +94,14 @@ main(
                     pszConfigFilePath);
     BAIL_ON_LSA_ERROR(dwError);
     
-    if (LW_IS_NULL_OR_EMPTY_STR(gpszProviderLibPath))
+    if (IsNullOrEmptyString(gpszProviderLibPath))
     {
         fprintf(stderr, "Error: The stress config file does not have a valid provider library path\n");
         dwError = EINVAL;
         BAIL_ON_LSA_ERROR(dwError);
     }
     
-    if (LW_IS_NULL_OR_EMPTY_STR(gpszProviderConfigFilePath))
+    if (IsNullOrEmptyString(gpszProviderConfigFilePath))
     {
         fprintf(stderr, "Error: The stress config file does not have a valid provider config file path\n");
         dwError = EINVAL;
@@ -110,7 +110,7 @@ main(
     
     gpAuthProvider->pszProviderLibpath = gpszProviderLibPath;
     
-    dwError = LWNetExtendEnvironmentForKrb5Affinity(TRUE);
+    dwError = LWNetExtendEnvironmentForKrb5Affinity(FALSE);
     BAIL_ON_LSA_ERROR(dwError);
     
     dwError = LADSBlockSelectedSignals();
@@ -138,7 +138,7 @@ cleanup:
 
     LADSShutdownGlobals();
 
-    LW_SAFE_FREE_STRING(pszConfigFilePath);
+    LSA_SAFE_FREE_STRING(pszConfigFilePath);
 
     return (dwError);
 
@@ -205,27 +205,27 @@ LADSShutdownGlobals(
                     DWORD i = 0;
                     for (i = 0; i < gLADSStressData[iType].dwNumItems; i++)
                     {
-                        LW_SAFE_FREE_STRING(gLADSStressData[iType].data.ppszNames[i]);
+                        LSA_SAFE_FREE_STRING(gLADSStressData[iType].data.ppszNames[i]);
                     }
-                    LwFreeMemory(gLADSStressData[iType].data.ppszNames);
+                    LsaFreeMemory(gLADSStressData[iType].data.ppszNames);
                 }
                 break;
                 
             case LADS_FIND_USER_BY_ID:
                 
-                LW_SAFE_FREE_MEMORY(gLADSStressData[iType].data.pUidArray);
+                LSA_SAFE_FREE_MEMORY(gLADSStressData[iType].data.pUidArray);
 
             case LADS_FIND_GROUP_BY_ID:
                 
-                LW_SAFE_FREE_MEMORY(gLADSStressData[iType].data.pGidArray);
+                LSA_SAFE_FREE_MEMORY(gLADSStressData[iType].data.pGidArray);
 
             default:
                 break;
         }
     }
     
-    LW_SAFE_FREE_STRING(gpszProviderLibPath);
-    LW_SAFE_FREE_STRING(gpszProviderConfigFilePath);
+    LSA_SAFE_FREE_STRING(gpszProviderLibPath);
+    LSA_SAFE_FREE_STRING(gpszProviderConfigFilePath);
     
     return dwError;
 }
@@ -286,7 +286,7 @@ LADSParseArgs(
            }
            case ConfigFile:
                
-               dwError = LwAllocateString(
+               dwError = LsaAllocateString(
                                pszArg,
                                &pszConfigFilePath);
                BAIL_ON_LSA_ERROR(dwError);
@@ -331,7 +331,7 @@ LADSParseArgs(
         }
     } while ((parse_mode != Done) && (iArg < argc));
     
-    if (LW_IS_NULL_OR_EMPTY_STR(pszConfigFilePath))
+    if (IsNullOrEmptyString(pszConfigFilePath))
     {
         ShowUsage();
         exit(1);
@@ -348,7 +348,7 @@ error:
 
     *ppszConfigFilePath = NULL;
 
-    LW_SAFE_FREE_STRING(pszConfigFilePath);
+    LSA_SAFE_FREE_STRING(pszConfigFilePath);
     
     goto cleanup;
 }
@@ -470,61 +470,74 @@ error:
 DWORD
 LADSInitAuthProvider(
     PCSTR pszConfigFilePath,
-    PTEST_AUTH_PROVIDER pProvider
+    PLSA_AUTH_PROVIDER pProvider
     )
 {
     DWORD dwError = 0;
     PFNINITIALIZEPROVIDER pfnInitProvider = NULL;
-    PCSTR pszError = NULL;
+    PCSTR  pszError = NULL;
     PSTR pszProviderLibpath = NULL;
-
-    if (LW_IS_NULL_OR_EMPTY_STR(pProvider->pszProviderLibpath))
-    {
-        dwError = LW_ERROR_INVALID_AUTH_PROVIDER;
+    
+    if (IsNullOrEmptyString(pProvider->pszProviderLibpath)) {
+        dwError = ENOENT;
         BAIL_ON_LSA_ERROR(dwError);
     }
     
     pszProviderLibpath = pProvider->pszProviderLibpath;
     
     dlerror();
+        
     pProvider->pLibHandle = dlopen(pszProviderLibpath, RTLD_NOW | RTLD_GLOBAL);
-    if (!pProvider->pLibHandle)
-    {
-        LSA_LOG_ERROR("Failed to open auth provider at path '%s'", pszProviderLibpath);
+    if (pProvider->pLibHandle == NULL) {
+       LSA_LOG_ERROR("Failed to open auth provider at path [%s]", pszProviderLibpath);
 
-        pszError = dlerror();
-        if (!LW_IS_NULL_OR_EMPTY_STR(pszError))
-        {
-            LSA_LOG_ERROR("%s", pszError);
-        }
-
-        dwError = LW_ERROR_INVALID_AUTH_PROVIDER;
-        BAIL_ON_LSA_ERROR(dwError);
+       pszError = dlerror();
+       if (!IsNullOrEmptyString(pszError)) {
+          LSA_LOG_ERROR("%s", pszError);
+       }
+            
+       dwError = LSA_ERROR_INVALID_AUTH_PROVIDER;
+       BAIL_ON_LSA_ERROR(dwError);
     }
-
+        
     dlerror();
     pfnInitProvider = (PFNINITIALIZEPROVIDER)dlsym(
-        pProvider->pLibHandle,
-        LSA_SYMBOL_NAME_INITIALIZE_PROVIDER);
-    if (!pfnInitProvider)
-    {
-        LSA_LOG_ERROR("Ignoring invalid auth provider at path '%s'", pszProviderLibpath);
-
-        pszError = dlerror();
-        if (!LW_IS_NULL_OR_EMPTY_STR(pszError))
-        {
-            LSA_LOG_ERROR("%s", pszError);
-        }
-
-        dwError = LW_ERROR_INVALID_AUTH_PROVIDER;
-        BAIL_ON_LSA_ERROR(dwError);
+                                        pProvider->pLibHandle,
+                                        LSA_SYMBOL_NAME_INITIALIZE_PROVIDER);
+    if (pfnInitProvider == NULL) {
+       LSA_LOG_ERROR("Ignoring invalid auth provider at path [%s]", pszProviderLibpath);
+            
+       pszError = dlerror();
+       if (!IsNullOrEmptyString(pszError)) {
+          LSA_LOG_ERROR("%s", pszError);
+       }
+            
+       dwError = LSA_ERROR_INVALID_AUTH_PROVIDER;
+       BAIL_ON_LSA_ERROR(dwError);
+    }
+        
+    dlerror();
+    pProvider->pFnShutdown = (PFNSHUTDOWNPROVIDER)dlsym(
+                                        pProvider->pLibHandle,
+                                        LSA_SYMBOL_NAME_SHUTDOWN_PROVIDER);
+    if (pProvider->pFnShutdown == NULL) {
+       LSA_LOG_ERROR("Ignoring invalid auth provider at path [%s]", pszProviderLibpath);
+            
+       pszError = dlerror();
+       if (!IsNullOrEmptyString(pszError)) {
+          LSA_LOG_ERROR("%s", pszError);
+       }
+            
+       dwError = LSA_ERROR_INVALID_AUTH_PROVIDER;
+       BAIL_ON_LSA_ERROR(dwError);
     }
         
     dwError = pfnInitProvider(
+                    pszConfigFilePath,
                     &pProvider->pszName,
                     &pProvider->pFnTable);
     BAIL_ON_LSA_ERROR(dwError);
-
+        
     dwError = LADSValidateProvider(pProvider);
     BAIL_ON_LSA_ERROR(dwError);
     
@@ -539,12 +552,11 @@ error:
 
 DWORD
 LADSValidateProvider(
-    PTEST_AUTH_PROVIDER pProvider
+    PLSA_AUTH_PROVIDER pProvider
     )
 {
     if (!pProvider ||
         !pProvider->pFnTable ||
-        !pProvider->pFnTable->pfnShutdownProvider ||
         !pProvider->pFnTable->pfnOpenHandle ||
         !pProvider->pFnTable->pfnCloseHandle ||
         !pProvider->pFnTable->pfnServicesDomain ||
@@ -577,7 +589,7 @@ LADSValidateProvider(
         !pProvider->pFnTable->pfnFreeStatus
         )
     {
-        return LW_ERROR_INVALID_AUTH_PROVIDER;
+        return LSA_ERROR_INVALID_AUTH_PROVIDER;
     }
     
     return 0;
@@ -603,7 +615,7 @@ LADSStartWorkers(
            continue;
         }
 
-        dwError = LwAllocateMemory(
+        dwError = LsaAllocateMemory(
                       sizeof(pthread_t) * gLADSStressData[iType].dwNumThreads,
                       (PVOID*)&gLADSStressData[iType].pThreadArray);
         BAIL_ON_LSA_ERROR(dwError);
@@ -696,7 +708,7 @@ LADSStopWorkers(
             }
         }
 
-        LwFreeMemory(gLADSStressData[iType].pThreadArray);
+        LsaFreeMemory(gLADSStressData[iType].pThreadArray);
     }
 
     return dwError;
@@ -704,22 +716,22 @@ LADSStopWorkers(
 
 DWORD
 LADSShutdownAuthProvider(
-    PTEST_AUTH_PROVIDER pProvider
+    PLSA_AUTH_PROVIDER pProvider
     )
 {
-    if (pProvider)
-    {
-        if (pProvider->pFnTable && pProvider->pFnTable->pfnShutdownProvider)
-        {
-            pProvider->pFnTable->pfnShutdownProvider();
-        }
-
-        if (pProvider->pLibHandle)
-        {
-            dlclose(pProvider->pLibHandle);
-        }
+    if (pProvider->pFnShutdown) {
+    
+        pProvider->pFnShutdown(
+               pProvider->pszName,
+               pProvider->pFnTable
+               );
+   
     }
 
+    if (pProvider->pLibHandle) {
+        dlclose(pProvider->pLibHandle);
+    }
+    
     return 0;
 }
 
