@@ -70,63 +70,6 @@ error:
     goto cleanup;
 }
 
-DWORD
-DNSCreatePtrRecord(
-    PCSTR pszName,
-    WORD  wClass,
-    PCSTR pszDest,
-    PDNS_RR_RECORD * ppDNSRecord
-    )
-{
-    DWORD dwError = 0;
-    PDNS_RR_RECORD pDNSRRRecord = NULL;
-    PDNS_DOMAIN_NAME pDomainName = NULL;
-
-    dwError = DNSDomainNameFromString(
-                    pszName,
-                    &pDomainName);
-    BAIL_ON_LWDNS_ERROR(dwError);
-
-    dwError = DNSAllocateMemory(
-                    sizeof(DNS_RR_RECORD),
-                    (PVOID *)&pDNSRRRecord);
-    BAIL_ON_LWDNS_ERROR(dwError);
-
-    pDNSRRRecord->RRHeader.dwTTL = DNS_ONE_HOUR_IN_SECS;
-    pDNSRRRecord->RRHeader.wClass = wClass;
-    pDNSRRRecord->RRHeader.wType = QTYPE_PTR;
-    pDNSRRRecord->RRHeader.pDomainName = pDomainName;
-    pDomainName = NULL;
-    pDNSRRRecord->RRHeader.wRDataSize = 0;
-
-    dwError = DNSDomainNameFromString(
-                    pszDest,
-                    &pDomainName);
-    BAIL_ON_LWDNS_ERROR(dwError);
-    pDNSRRRecord->pRDataDomain = pDomainName;
-    pDomainName = NULL;
-
-    *ppDNSRecord = pDNSRRRecord;
-
-cleanup:
-    if (pDomainName)
-    {
-        DNSFreeDomainName(pDomainName);
-    }
-
-    return dwError;
-
-error:
-    if (pDNSRRRecord)
-    {
-        DNSFreeRecord(pDNSRRRecord);
-    }
-
-    *ppDNSRecord = NULL;
-
-    goto cleanup;
-}
-
 DWORD
 DNSCreateARecord(
     PCSTR pszHost,
@@ -890,11 +833,6 @@ DNSFreeRecord(
     {
         DNSFreeMemory(pRecord->pRData);
     }
-
-    if (pRecord->pRDataDomain)
-    {
-        DNSFreeDomainName(pRecord->pRDataDomain);
-    }
     
     if (pRecord->RRHeader.pDomainName)
     {
