@@ -19,16 +19,6 @@
 ++*/
 
 #include "config.h"
-
-#if defined(__LWI_NETBSD__)
-#ifdef HAVE_NETINET_IN_H
-#include <netinet/in.h>
-#endif
-#ifdef HAVE_RESOLV_H
-#include <resolv.h>
-#endif
-#endif  // __LWI_NETBSD__
-
 #include "dnssystem.h"
 #include "lwdns.h"
 #include "dnsdefines.h"
@@ -47,7 +37,6 @@
 #include "dnsupdate.h"
 #include "dnsupresp.h"
 #include "dnsparser.h"
-#include "lw/rtlstring.h"
 
 #include "externs.h"
 
