@@ -48,23 +48,6 @@
  */
 #include "includes.h"
 
-static
-DWORD
-LWNetFindServersInDomain(
-    IN PDNS_SERVER_INFO pServerArray,
-    IN DWORD dwServerCount,
-    IN PCSTR pszDomainName,
-    OUT PDNS_SERVER_INFO* ppServersInDomain,
-    OUT PDWORD pdwServersInDomainCount
-    );
-
-static
-BOOL
-LWNetServerIsInDomain(
-    IN PDNS_SERVER_INFO pServerInfo,
-    IN PCSTR pszDomainName
-    );
-
 static
 DWORD
 LWNetSrvPingCLdap(
@@ -85,41 +68,33 @@ LWNetSrvPingCLdap(
     LWNET_UNIX_MS_TIME_T startTime = 0;
     LWNET_UNIX_MS_TIME_T stopTime = 0;
 
-    dwError = LwAllocateStringPrintf(&pszQuery,
-                                        "(&(DnsDomain=%s)(NtVer=\\06\\00\\00\\80))",
+    dwError = LWNetAllocateStringPrintf(&pszQuery,
+                                        "(&(DnsDomain=%s)(NtVer=\\06\\00\\00\\20))",
                                         pszDnsDomainName);
     BAIL_ON_LWNET_ERROR(dwError);
 
-    dwError = LwCLdapOpenDirectory(pszAddress, &hDirectory);
+    dwError = LWNetCLdapOpenDirectory(pszAddress, &hDirectory);
     BAIL_ON_LWNET_ERROR(dwError);
 
-    dwError = LwLdapBindDirectoryAnonymous(hDirectory);
+    dwError = LWNetLdapBindDirectoryAnonymous(hDirectory);
     BAIL_ON_LWNET_ERROR(dwError);
 
     dwError = LWNetGetSystemTimeInMs(&startTime);
     BAIL_ON_LWNET_ERROR(dwError);
 
     /* TODO: May need to do retries with shorter timeout if UDP does not retry */
-    dwError = LwLdapDirectorySearchEx(
-                    hDirectory,
-                    "",
-                    LDAP_SCOPE_BASE,
-                    pszQuery,
-                    szAttributeList,
-                    NULL,
-                    0,
-                    &pMessage);
+    dwError = LWNetLdapDirectorySearchEx(hDirectory, "", LDAP_SCOPE_BASE,
+                                         pszQuery, szAttributeList, 0,
+                                         &pMessage);
     BAIL_ON_LWNET_ERROR(dwError);
 
     dwError = LWNetGetSystemTimeInMs(&stopTime);
     BAIL_ON_LWNET_ERROR(dwError);
 
-    dwError = LwLdapGetBytes(
-                    hDirectory,
-                    pMessage,
-                    NETLOGON_LDAP_ATTRIBUTE_NAME,
-                    &pNetlogonAttributeValue,
-                    &dwNetlogonAttributeSize);
+    dwError = LWNetGetLDAPOctetString(hDirectory, pMessage,
+                                      NETLOGON_LDAP_ATTRIBUTE_NAME,
+                                      &pNetlogonAttributeValue,
+                                      &dwNetlogonAttributeSize);
     BAIL_ON_LWNET_ERROR(dwError);
 
     dwError = LWNetBuildDCInfo(pNetlogonAttributeValue,
@@ -144,7 +119,7 @@ error:
 
     if (hDirectory)
     {
-        LwLdapCloseDirectory(hDirectory);
+        LWNetLdapCloseDirectory(hDirectory);
     }
 
     LWNET_SAFE_FREE_MEMORY(pNetlogonAttributeValue);
@@ -196,6 +171,7 @@ LWNetSrvPingCLdapDerefenceThreadContext(
     }
 }
 
+static
 BOOLEAN
 LWNetSrvIsMatchingDcInfo(
     IN PLWNET_DC_INFO pDcInfo,
@@ -224,7 +200,13 @@ LWNetSrvIsMatchingDcInfo(
          !(pDcInfo->dwFlags & DS_TIMESERV_FLAG))
         ||
         ((dwDsFlags & DS_WRITABLE_REQUIRED) &&
-         !(pDcInfo->dwFlags & DS_WRITABLE_FLAG))
+         !(pDcInfo->dwFlags & DS_WRITEABLE_FLAG))
+        ||
+        ((dwDsFlags & DS_TIMESERV_REQUIRED) &&
+         !(pDcInfo->dwFlags & DS_TIMESERV_FLAG))
+        ||
+        ((dwDsFlags & DS_WRITABLE_REQUIRED) &&
+         !(pDcInfo->dwFlags & DS_WRITEABLE_FLAG))
         ||
         ((dwDsFlags & DS_GOOD_TIMESERV_REQUIRED) &&
          !(pDcInfo->dwFlags & DS_GOOD_TIMESERV_FLAG))
@@ -237,40 +219,6 @@ LWNetSrvIsMatchingDcInfo(
     return isMatching;
 }
 
-BOOLEAN
-LWNetSrvIsAffinitizableRequestFlags(
-    IN DWORD dwDsFlags
-    )
-{
-    BOOLEAN isCacheable = TRUE;
-
-    // If any of these conditions are satisfied,
-    // then caching should not be done.
-    if (dwDsFlags & (DS_TIMESERV_REQUIRED | DS_GOOD_TIMESERV_REQUIRED))
-    {
-        isCacheable = FALSE;
-    }
-
-    return isCacheable;
-}
-
-static
-BOOLEAN
-LWNetSrvIsInSameSite(
-    IN PLWNET_DC_INFO pDcInfo
-    )
-{
-    BOOLEAN isInSameSite = FALSE;
-
-    if (pDcInfo->pszDCSiteName && pDcInfo->pszClientSiteName &&
-        !strcasecmp(pDcInfo->pszClientSiteName, pDcInfo->pszDCSiteName))
-    {
-        isInSameSite = TRUE;
-    }
-
-    return isInSameSite;
-}
-
 static
 PVOID
 LWNetSrvPingCLdapThread(
@@ -331,25 +279,11 @@ LWNetSrvPingCLdapThread(
         dwError = LWNetSrvPingCLdap(pContext->pszDnsDomainName, pszAddress, &pDcInfo);
         if (dwError)
         {
-            LWNET_LOG_INFO("Failed CLDAP ping %s (%s) in %s() at %s:%d (error %d/0x%08x)", pContext->pszDnsDomainName, pszAddress, __FUNCTION__, __FILE__, __LINE__, dwError, dwError);
+            LWNET_LOG_ERROR("Failed CLDAP ping %s (%s) in %s() at %s:%d (error %d/0x%08x)", pContext->pszDnsDomainName, pszAddress, __FUNCTION__, __FILE__, __LINE__, dwError, dwError);
             continue;
         }
         if (!LWNetSrvIsMatchingDcInfo(pDcInfo, pContext->dwDsFlags))
         {
-            if (LWNetSrvIsMatchingDcInfo(pDcInfo, pContext->dwDsFlags & ~DS_WRITABLE_REQUIRED))
-            {
-                // We found something, but it failed only because it did
-                // not satisfy writability.  We mark this in the context.
-                if (!isAcquired)
-                {
-                    LWNET_CLDAP_THREAD_CONTEXT_ACQUIRE(pContext);
-                    isAcquired = TRUE;
-                }
-                pContext->bFailedFindWritable = TRUE;
-                LWNET_CLDAP_THREAD_CONTEXT_RELEASE(pContext);
-                isAcquired = FALSE;
-            }
-            LWNET_SAFE_FREE_DC_INFO(pDcInfo);
             continue;
         }
         break;
@@ -360,11 +294,8 @@ LWNetSrvPingCLdapThread(
         //
         // Save the result, if appropriate.
         //
-        if (!isAcquired)
-        {
-            LWNET_CLDAP_THREAD_CONTEXT_ACQUIRE(pContext);
-            isAcquired = TRUE;
-        }
+        LWNET_CLDAP_THREAD_CONTEXT_ACQUIRE(pContext);
+        isAcquired = TRUE;
 
         if (!pContext->bIsDone && !pContext->pDcInfo)
         {
@@ -421,8 +352,7 @@ LWNetSrvPingCLdapArray(
     IN DWORD dwServerCount,
     IN OPTIONAL DWORD dwThreadCount,
     IN OPTIONAL DWORD dwTimeoutSeconds,
-    OUT PLWNET_DC_INFO* ppDcInfo,
-    OUT PBOOLEAN pbFailedFindWritable
+    OUT PLWNET_DC_INFO* ppDcInfo
     )
 // TODO: Potentially have a minimum amount of time so we can evaluate multiple
 // ping results (i.e., in a case where the ping starts later due to thread
@@ -441,7 +371,6 @@ LWNetSrvPingCLdapArray(
     LWNET_UNIX_MS_TIME_T now = 0;
     PLWNET_DC_INFO pDcInfo = NULL;
     DWORD i;
-    BOOLEAN bFailedFindWritable = FALSE;
 
     if (dwThreadCount > 0)
     {
@@ -520,13 +449,13 @@ LWNetSrvPingCLdapArray(
     isAcquired = TRUE;
     if (ETIMEDOUT == dwError)
     {
-        dwError = NERR_DCNotFound;
+        dwError = LWNET_ERROR_FAILED_FIND_DC;
     }
     BAIL_ON_LWNET_ERROR(dwError);
 
     if (!pContext->pDcInfo)
     {
-        dwError = NERR_DCNotFound;
+        dwError = LWNET_ERROR_FAILED_FIND_DC;
         BAIL_ON_LWNET_ERROR(dwError);
     }
 
@@ -547,7 +476,6 @@ error:
             // Stop processing any more
             pContext->bIsDone = TRUE;
             pContext->dwServerIndex = pContext->dwServerCount;
-            bFailedFindWritable = pContext->bFailedFindWritable;
         }
         if (isAcquired)
         {
@@ -565,156 +493,17 @@ error:
         LWNET_SAFE_FREE_DC_INFO(pDcInfo);
     }
     *ppDcInfo = pDcInfo;
-    *pbFailedFindWritable = pDcInfo ? FALSE : bFailedFindWritable;
     return dwError;
 }
 
-VOID
-LWNetFilterFromBlackList(
-    IN DWORD dwBlackListCount,
-    IN OPTIONAL PSTR* ppszAddressBlackList,
-    IN OUT PDWORD pdwServerCount,
-    IN OUT PDNS_SERVER_INFO pServerArray
-    )
-{
-    DWORD dwServerRead = 0;
-    DWORD dwServerWrote = 0;
-    DWORD dwBlackIndex = 0;
-    BOOLEAN bBlackListed = FALSE;
-
-    LWNET_LOG_INFO("Filtering list of %d servers with list of %d black listed servers", *pdwServerCount, dwBlackListCount);
-
-    if (!dwBlackListCount)
-    {
-        return;
-    }
-
-    for (dwServerRead = 0; dwServerRead < *pdwServerCount; dwServerRead++)
-    {
-        bBlackListed = FALSE;
-        for (dwBlackIndex = 0;
-             !bBlackListed && dwBlackIndex < dwBlackListCount;
-             dwBlackIndex++)
-        {
-            if (!strcmp(pServerArray[dwServerRead].pszAddress,
-                        ppszAddressBlackList[dwBlackIndex]))
-            {
-                bBlackListed = TRUE;
-                LWNET_LOG_INFO("Filtering server %s since it is black listed",
-                        pServerArray->pszAddress);
-            }
-        }
-        /* If bBlackListed is true, this server array entry will get
-         * overwritten with the next non-blacklisted entry. The address and
-         * name strings inside of the entry do not need to be freed because
-         * they are allocated in the same memory block as the array.
-         */
-        if (!bBlackListed)
-        {
-            pServerArray[dwServerWrote++] = pServerArray[dwServerRead];
-        }
-    }
-    *pdwServerCount = dwServerWrote;
-}
-
-typedef DWORD (*PLWNET_DC_LIST_QUERY_METHOD)(
-    IN PCSTR pszDnsDomainName,
-    IN OPTIONAL PCSTR pszSiteName,
-    IN DWORD dwDsFlags,
-    OUT PDNS_SERVER_INFO* ppServerArray,
-    OUT PDWORD pdwServerCount
-    );
-
-static
-DWORD
-LWNetSrvGetDCNameDiscoverInternal(
-    IN PCSTR pszDnsDomainName,
-    IN OPTIONAL PCSTR pszSiteName,
-    IN OPTIONAL PCSTR pszPrimaryDomain,
-    IN DWORD dwDsFlags,
-    IN DWORD dwBlackListCount,
-    IN OPTIONAL PSTR* ppszAddressBlackList,
-    IN PLWNET_DC_LIST_QUERY_METHOD pfnDCListQuery,
-    OUT PLWNET_DC_INFO* ppDcInfo,
-    OUT OPTIONAL PDNS_SERVER_INFO* ppServerArray,
-    OUT OPTIONAL PDWORD pdwServerCount,
-    OUT PBOOLEAN bFailedFindWritable
-    );
-
 DWORD
 LWNetSrvGetDCNameDiscover(
     IN PCSTR pszDnsDomainName,
     IN OPTIONAL PCSTR pszSiteName,
-    IN OPTIONAL PCSTR pszPrimaryDomain,
     IN DWORD dwDsFlags,
-    IN DWORD dwBlackListCount,
-    IN OPTIONAL PSTR* ppszAddressBlackList,
     OUT PLWNET_DC_INFO* ppDcInfo,
     OUT OPTIONAL PDNS_SERVER_INFO* ppServerArray,
-    OUT OPTIONAL PDWORD pdwServerCount,
-    OUT PBOOLEAN pbFailedFindWritable
-    )
-{
-    DWORD dwError = 0;
-
-    /* First try with the "Preferred DC list" */
-
-    dwError = LWNetSrvGetDCNameDiscoverInternal(
-                  pszDnsDomainName,
-                  pszSiteName,
-                  pszPrimaryDomain,
-                  dwDsFlags,
-                  dwBlackListCount,
-                  ppszAddressBlackList,
-                  LWNetGetPreferredDcList,
-                  ppDcInfo,
-                  ppServerArray,
-                  pdwServerCount,
-                  pbFailedFindWritable);
-    if (dwError == ERROR_SUCCESS)
-    {
-        goto cleanup;
-    }
-
-    /* Try again using the standard DNS SRV queries */
-
-    dwError = LWNetSrvGetDCNameDiscoverInternal(
-                  pszDnsDomainName,
-                  pszSiteName,
-                  pszPrimaryDomain,
-                  dwDsFlags,
-                  dwBlackListCount,
-                  ppszAddressBlackList,
-                  LWNetDnsSrvQuery,
-                  ppDcInfo,
-                  ppServerArray,
-                  pdwServerCount,
-                  pbFailedFindWritable);
-    BAIL_ON_LWNET_ERROR(dwError);
-
-cleanup:
-
-    return dwError;
-
-error:
-
-    goto cleanup;
-}
-
-static
-DWORD
-LWNetSrvGetDCNameDiscoverInternal(
-    IN PCSTR pszDnsDomainName,
-    IN OPTIONAL PCSTR pszSiteName,
-    IN OPTIONAL PCSTR pszPrimaryDomain,
-    IN DWORD dwDsFlags,
-    IN DWORD dwBlackListCount,
-    IN OPTIONAL PSTR* ppszAddressBlackList,
-    IN PLWNET_DC_LIST_QUERY_METHOD pfnDCListQuery,
-    OUT PLWNET_DC_INFO* ppDcInfo,
-    OUT OPTIONAL PDNS_SERVER_INFO* ppServerArray,
-    OUT OPTIONAL PDWORD pdwServerCount,
-    OUT PBOOLEAN pbFailedFindWritable
+    OUT OPTIONAL PDWORD pdwServerCount
     )
 //
 // Algorithm:
@@ -729,152 +518,85 @@ LWNetSrvGetDCNameDiscoverInternal(
 //
 {
     DWORD dwError = 0;
-    PLWNET_DC_INFO pDcInfo = NULL;
     PDNS_SERVER_INFO pServerArray = NULL;
-    PDNS_SERVER_INFO pServersInPrimaryDomain = NULL;
-    DWORD dwServersInPrimaryDomainCount = 0;
     DWORD dwServerCount = 0;
-    PLWNET_DC_INFO pSiteDcInfo = NULL;
-    PDNS_SERVER_INFO pSiteServerArray = NULL;
-    DWORD dwSiteServerCount = 0;
-    BOOLEAN bFailedFindWritable = FALSE;
+    PLWNET_DC_INFO pDcInfo = NULL;
+    PSTR pszClientSiteName = NULL;
 
-    // Get server list
-    dwError = pfnDCListQuery(pszDnsDomainName,
-                             pszSiteName,
-                             dwDsFlags,
-                             &pServerArray,
-                             &dwServerCount);
+    dwError = LWNetDnsSrvQuery(pszDnsDomainName, pszSiteName, dwDsFlags,
+                               &pServerArray, &dwServerCount);
     BAIL_ON_LWNET_ERROR(dwError);
 
-    LWNetFilterFromBlackList(
-        dwBlackListCount,
-        ppszAddressBlackList,
-        &dwServerCount,
-        pServerArray);
-    if (!dwServerCount)
+    // If we do not have a site, use CLDAP to one DC to get the desired site.
+    if (IsNullOrEmptyString(pszSiteName))
     {
-        dwError = DNS_ERROR_BAD_PACKET;
-        BAIL_ON_LWNET_ERROR(dwError);
-    }
-
-    if (pszPrimaryDomain)
-    {
-        dwError = LWNetFindServersInDomain(
-            pServerArray,
-            dwServerCount,
-            pszPrimaryDomain,
-            &pServersInPrimaryDomain,
-            &dwServersInPrimaryDomainCount);
-        BAIL_ON_LWNET_ERROR(dwError);
-
-        if (dwServersInPrimaryDomainCount > 0)
-        {
-            dwError = LWNetSrvPingCLdapArray(pszDnsDomainName,
-                                             dwDsFlags,
-                                             pServersInPrimaryDomain,
-                                             dwServersInPrimaryDomainCount,
-                                             0, 0, &pDcInfo, &bFailedFindWritable);
-        }
-
-        if (dwServersInPrimaryDomainCount == 0 ||
-            dwError == NERR_DCNotFound)
-        {
-            dwError = LWNetSrvPingCLdapArray(pszDnsDomainName,
-                                             dwDsFlags,
-                                             pServerArray, dwServerCount,
-                                             0, 0, &pDcInfo, &bFailedFindWritable);
-            BAIL_ON_LWNET_ERROR(dwError);
-        }
-    }
-    else
-    {
-        // Do CLDAP
         dwError = LWNetSrvPingCLdapArray(pszDnsDomainName,
                                          dwDsFlags,
                                          pServerArray, dwServerCount,
-                                         0, 0, &pDcInfo, &bFailedFindWritable);
+                                         0, 0, &pDcInfo);
+        BAIL_ON_LWNET_ERROR(dwError);
+
+        // If there is no site, then we are done (though we do not
+        // expect this to ever happen).
+        if (IsNullOrEmptyString(pDcInfo->pszClientSiteName))
+        {
+            LWNET_LOG_ALWAYS("Missing client site name");
+            dwError = 0;
+            goto cleanup;
+        }
+
+        // ISSUE-2008/07/03-dalmeida -- re-enable this after testing
+#if 0
+        // If we got the correct site already, we are done
+        if (!strcasecmp(pDcInfo->pszClientSiteName, pDcInfo->pszDCSiteName))
+        {
+            dwError = 0;
+            goto cleanup;
+        }
+#endif
+
+        dwError = LWNetAllocateString(pDcInfo->pszClientSiteName,
+                                      &pszClientSiteName);
+        BAIL_ON_LWNET_ERROR(dwError);
+
+        LWNET_SAFE_FREE_DC_INFO(pDcInfo);
+        LWNET_SAFE_FREE_MEMORY(pServerArray);
+        dwServerCount = 0;
+
+        dwError = LWNetSrvGetDCNameDiscover(pszDnsDomainName,
+                                            pszClientSiteName,
+                                            dwDsFlags,
+                                            &pDcInfo,
+                                            &pServerArray, &dwServerCount);
         BAIL_ON_LWNET_ERROR(dwError);
     }
-
-    // If there is no client site, then we are done (though we do not
-    // expect this to ever happen).
-    if (IsNullOrEmptyString(pDcInfo->pszClientSiteName))
+    else
     {
-        LWNET_LOG_ALWAYS("Missing client site name from "
-                "DC response from %s (%s)",
-                LWNET_SAFE_LOG_STRING(pDcInfo->pszDomainControllerName),
-                LWNET_SAFE_LOG_STRING(pDcInfo->pszDomainControllerAddress));
-        goto cleanup;
-    }
+        dwError = LWNetSrvPingCLdapArray(pszDnsDomainName,
+                                         dwDsFlags,
+                                         pServerArray, dwServerCount,
+                                         0, 0, &pDcInfo);
+        BAIL_ON_LWNET_ERROR(dwError);
 
-    // If a site was passed in, there is nothing more to do.
-    if (!IsNullOrEmptyString(pszSiteName))
-    {
-        goto cleanup;
-    }
-
-    // There was no site passed in, so we need to look at the
-    // CLDAP response to get the client site.
-
-    // If we got the correct site already, we are done.
-    if (LWNetSrvIsInSameSite(pDcInfo))
-    {
-        dwError = 0;
-        goto cleanup;
-    }
-
-    // Now we need to use the client site to find a site-specific DC.
-    dwError = LWNetSrvGetDCNameDiscover(pszDnsDomainName,
-                                        pDcInfo->pszClientSiteName,
-                                        pszPrimaryDomain,
-                                        dwDsFlags,
-                                        dwBlackListCount,
-                                        ppszAddressBlackList,
-                                        &pSiteDcInfo,
-                                        &pSiteServerArray, &dwSiteServerCount,
-                                        &bFailedFindWritable);
-    if (NERR_DCNotFound == dwError)
-    {
-        if (bFailedFindWritable)
+        // ISSUE-2008/07/02-dalmeida -- clean this up.
+        if (IsNullOrEmptyString(pDcInfo->pszClientSiteName))
         {
-            LWNET_LOG_WARNING("No writable DC in client site '%s' for domain '%s'",
-                              pDcInfo->pszClientSiteName,
-                              pszDnsDomainName);
+            LWNET_LOG_ALWAYS("Missing client site name");
+            dwError = 0;
+            goto cleanup;
         }
-        // Count not find site-specific DC, so use the original DC.
-        dwError = 0;
-        goto cleanup;
+
     }
-    BAIL_ON_LWNET_ERROR(dwError);
-
-    // Use the site-specific DC.
-    LWNET_SAFE_FREE_DC_INFO(pDcInfo);
-    LWNET_SAFE_FREE_MEMORY(pServerArray);
-    dwServerCount = 0;
-
-    pDcInfo = pSiteDcInfo;
-    pServerArray = pSiteServerArray;
-    dwServerCount = dwSiteServerCount;
-
-    pSiteDcInfo = NULL;
-    pSiteServerArray = NULL;
-    dwSiteServerCount = 0;
 
 error:
 cleanup:
-    LWNET_SAFE_FREE_DC_INFO(pSiteDcInfo);
-    LWNET_SAFE_FREE_MEMORY(pSiteServerArray);
-    LWNET_SAFE_FREE_MEMORY(pServersInPrimaryDomain);
-    dwSiteServerCount = 0;
-
+    LWNET_SAFE_FREE_STRING(pszClientSiteName);
     if (dwError)
     {
         LWNET_SAFE_FREE_DC_INFO(pDcInfo);
         LWNET_SAFE_FREE_MEMORY(pServerArray);
         dwServerCount = 0;
     }
-
     *ppDcInfo = pDcInfo;
     if (ppServerArray)
     {
@@ -885,85 +607,9 @@ cleanup:
     {
         LWNET_SAFE_FREE_MEMORY(pServerArray);
     }
-    *pbFailedFindWritable = bFailedFindWritable;
-
     return dwError;
 }
 
-static
-DWORD
-LWNetFindServersInDomain(
-    IN PDNS_SERVER_INFO pServerArray,
-    IN DWORD dwServerCount,
-    IN PCSTR pszDomainName,
-    OUT PDNS_SERVER_INFO* ppServersInDomain,
-    OUT PDWORD pdwServersInDomainCount
-    )
-{
-    DWORD dwError = 0;
-    DWORD i = 0;
-    DWORD dwServersInDomainCount = 0;
-    DWORD dwServerIndex = 0;
-    PDNS_SERVER_INFO pServersInDomain = NULL;
-
-    for (i = 0; i < dwServerCount; i++)
-    {
-        if (LWNetServerIsInDomain(&pServerArray[i], pszDomainName))
-        {
-            dwServersInDomainCount++;
-        }
-    }
-
-    if (dwServersInDomainCount)
-    {
-        dwError = LWNetAllocateMemory(dwServersInDomainCount * sizeof(*pServerArray), OUT_PPVOID(&pServersInDomain));
-        BAIL_ON_LWNET_ERROR(dwError);
-
-        for (i = 0; i < dwServerCount; i++)
-        {
-            if (LWNetServerIsInDomain(&pServerArray[i], pszDomainName))
-            {
-                pServersInDomain[dwServerIndex++] = pServerArray[i];
-            }
-        }
-    }
-
-    *ppServersInDomain = pServersInDomain;
-    *pdwServersInDomainCount = dwServersInDomainCount;
-
-cleanup:
-
-    return dwError;
-
-error:
-
-    *ppServersInDomain = NULL;
-    *pdwServersInDomainCount = 0;
-
-    LWNET_SAFE_FREE_MEMORY(pServersInDomain);
-
-    goto cleanup;
-}
-
-static
-BOOL
-LWNetServerIsInDomain(
-    IN PDNS_SERVER_INFO pServerInfo,
-    IN PCSTR pszDomainName
-    )
-{
-    PSTR pszDot = strchr(pServerInfo->pszName, '.');
-
-    if (!pszDot)
-    {
-        return FALSE;
-    }
-    else
-    {
-        return !strcasecmp(pszDot + 1, pszDomainName);
-    }
-}
-
 DWORD
 LWNetBuildDCInfo(
     IN PBYTE pBuffer,
@@ -1035,6 +681,55 @@ error:
     return dwError;
 }
 
+DWORD
+LWNetGetLDAPOctetString(
+    IN HANDLE hDirectory,
+    IN LDAPMessage* pMessage,
+    IN PCSTR pszFieldName,
+    OUT PBYTE* ppValue,
+    OUT PDWORD pdwValueSize
+    )
+{
+    DWORD dwError = LWNET_ERROR_SUCCESS;
+    PAD_DIRECTORY_CONTEXT pDirectory = (PAD_DIRECTORY_CONTEXT)hDirectory;
+    struct berval** pBerArray = NULL;
+    PBYTE pValue = NULL;
+    DWORD dwValueSize = 0;
+
+    /* TODO: Either we abstract the LDAP handle, or we don't. */
+    pBerArray = (struct berval **) ldap_get_values_len(pDirectory->ld,
+                                                       pMessage,
+                                                       pszFieldName);
+    if (!pBerArray || !pBerArray[0])
+    {
+        dwError = LWNET_ERROR_INVALID_PARAMETER;
+        BAIL_ON_LWNET_ERROR(dwError);
+    }
+
+    dwValueSize = pBerArray[0]->bv_len;
+
+    dwError = LWNetAllocateMemory(dwValueSize, (PVOID*)&pValue);
+    BAIL_ON_LWNET_ERROR(dwError);
+    
+    memcpy(pValue, pBerArray[0]->bv_val, dwValueSize);
+
+error:
+    if (pBerArray)
+    {
+        ldap_value_free_len(pBerArray);
+    }
+    if (dwError)
+    {
+        LWNET_SAFE_FREE_MEMORY(pValue);
+        dwValueSize = 0;
+    }
+
+    *ppValue = pValue;
+    *pdwValueSize = dwValueSize;
+
+    return dwError;
+}
+
 static
 DWORD
 LWNetReadUnalignedDword(
@@ -1056,7 +751,7 @@ LWNetReadLEDword(
 {
     if (pArray->totalSize + pArray->pStart - pArray->pCur < sizeof(DWORD))
     {
-        return DNS_ERROR_BAD_PACKET;
+        return LWNET_ERROR_DATA_ERROR;
     }
 #if defined(WORDS_BIGENDIAN)
     *pdwDest = LW_ENDIAN_SWAP32(LWNetReadUnalignedDword(pArray->pCur));
@@ -1064,7 +759,7 @@ LWNetReadLEDword(
     *pdwDest = LWNetReadUnalignedDword(pArray->pCur);
 #endif
     pArray->pCur += sizeof(DWORD);
-    return ERROR_SUCCESS;
+    return LWNET_ERROR_SUCCESS;
 }
 
 static
@@ -1088,7 +783,7 @@ LWNetReadLEWord(
 {
     if (pArray->totalSize + pArray->pStart - pArray->pCur < sizeof(WORD))
     {
-        return DNS_ERROR_BAD_PACKET;
+        return LWNET_ERROR_DATA_ERROR;
     }
 #if defined(WORDS_BIGENDIAN)
     *pwDest = LW_ENDIAN_SWAP16(LWNetReadUnalignedWord(pArray->pCur));
@@ -1096,7 +791,7 @@ LWNetReadLEWord(
     *pwDest = LWNetReadUnalignedWord(pArray->pCur);
 #endif
     pArray->pCur += sizeof(WORD);
-    return ERROR_SUCCESS;
+    return LWNET_ERROR_SUCCESS;
 }
 
 DWORD
@@ -1109,7 +804,7 @@ LWNetReadGUID(
     
     if (BYTES_REMAINING((*pArray)) < LWNET_GUID_SIZE)
     {
-        dwError = DNS_ERROR_BAD_PACKET;
+        dwError = LWNET_ERROR_DATA_ERROR;
         BAIL_ON_LWNET_ERROR(dwError);
     }
     memcpy(pbtDest, pArray->pCur, LWNET_GUID_SIZE);
@@ -1148,7 +843,7 @@ LWNetReadString(
                 if (followOffset >= pArray->totalSize)
                 {
                     //Offset out of bounds
-                    dwError = DNS_ERROR_BAD_PACKET;
+                    dwError = LWNET_ERROR_DATA_ERROR;
                     goto error;
                 }
                 *pCur += 2;
@@ -1158,7 +853,7 @@ LWNetReadString(
                 {
                     // This is definitely redundant, and it could be an infinite
                     // loop.
-                    dwError = DNS_ERROR_BAD_PACKET;
+                    dwError = LWNET_ERROR_DATA_ERROR;
                     goto error;
                 }
                 break;
@@ -1170,13 +865,13 @@ LWNetReadString(
                 {
                     // This goes out of bounds of the output buffer. There must be
                     // an infinite loop in the encoding.
-                    dwError = DNS_ERROR_BAD_PACKET;
+                    dwError = LWNET_ERROR_DATA_ERROR;
                     goto error;
                 }
                 if (copyLen + 1 + *pCur - pArray->pStart > pArray->totalSize)
                 {
                     // The label goes out of bounds of the message
-                    dwError = DNS_ERROR_BAD_PACKET;
+                    dwError = LWNET_ERROR_DATA_ERROR;
                     goto error;
                 }
                 if (outOffset > 0)
@@ -1190,7 +885,7 @@ LWNetReadString(
                 break;
             default:
                 // Illegal reserved value
-                dwError = DNS_ERROR_BAD_PACKET;
+                dwError = LWNET_ERROR_DATA_ERROR;
                 goto error;
         }
     }
@@ -1205,13 +900,3 @@ error:
     *ppszDest = pszOut;
     return dwError;
 }
-
-
-/*
-local variables:
-mode: c
-c-basic-offset: 4
-indent-tabs-mode: nil
-tab-width: 4
-end:
-*/
