@@ -53,7 +53,6 @@
 #define MACHINEPWD_DB     MACHINEPWD_DB_DIR "/pstore.db"
 
 static pthread_rwlock_t g_MachinePwdDBLock;
-static BOOLEAN g_MachinePwdDBLockInit = FALSE;
 
 #define ENTER_MACHINEPWD_DB_RW_READER_LOCK(bInLock) \
     if (!bInLock) {                                 \
@@ -86,7 +85,6 @@ SqlDBFreeMachineAcctInfo(
     LWPS_SAFE_FREE_STRING(pAcct->pszDomainName);
     LWPS_SAFE_FREE_STRING(pAcct->pszDomainDnsName);
     LWPS_SAFE_FREE_STRING(pAcct->pszHostName);
-    LWPS_SAFE_FREE_STRING(pAcct->pszHostDnsDomain);
     LWPS_SAFE_FREE_STRING(pAcct->pszMachineAccountName);
     LWPS_SAFE_FREE_STRING(pAcct->pszMachineAccountPassword);
     
@@ -98,12 +96,8 @@ DWORD
 SqlDBDbInitGlobals()
 {
     DWORD dwError = 0;
-
-    if (!g_MachinePwdDBLockInit)
-    {
-        pthread_rwlock_init(&g_MachinePwdDBLock, NULL);
-        g_MachinePwdDBLockInit = TRUE;
-    }
+    
+    pthread_rwlock_init(&g_MachinePwdDBLock, NULL);
     
     dwError = SqlDBCreateDb();
     BAIL_ON_LWPS_ERROR(dwError);
@@ -148,64 +142,6 @@ error:
     goto cleanup;
 }
 
-/*
- * This function assumes queries are a single atomic statement
- */
-static
-DWORD
-SqlDBExec(
-    sqlite3 * pDbHandle,
-    PCSTR pszQuery,
-    int (*callback)(void*, int, char**, char**),
-    void * arg,
-    PSTR *ppszError)
-{
-    DWORD dwError = 0;
-    DWORD dwCount = 0;
-
-    do {
-        dwError = sqlite3_exec(pDbHandle, pszQuery, callback, arg,
-                ppszError);
-        if (dwError == SQLITE_BUSY)
-        {
-            usleep(dwCount * 1000);
-            if (dwCount < 50)
-                dwCount++;
-        }
-    } while (dwError == SQLITE_BUSY);
-
-    return dwError;
-}
-
-static
-DWORD
-SqlDBGetTable(
-    sqlite3 *pDbHandle,
-    PCSTR pszQuery,
-    PSTR **pppszDbResult,
-    int * pNumRows,
-    int * pNumCols,
-    PSTR * ppszError)
-{
-    DWORD dwError = 0;
-    DWORD dwCount = 0;
-
-    do {
-        dwError = sqlite3_get_table(pDbHandle, pszQuery, pppszDbResult,
-                pNumRows, pNumCols, ppszError);
-
-        if (dwError == SQLITE_BUSY)
-        {
-            usleep(dwCount * 1000);
-            if (dwCount < 50)
-                dwCount++;
-        }
-    } while (dwError == SQLITE_BUSY);
-
-    return dwError;
-}
-
-
 void
 SqlDBClose(
     HANDLE hDb
@@ -254,7 +190,7 @@ SqlDBCreateDb()
     
     pDbHandle = (sqlite3*)hDb;
         
-    dwError = SqlDBExec(pDbHandle,
+    dwError = sqlite3_exec(pDbHandle,
                            DB_QUERY_CREATE_MACHINEPWD_TABLE,
                            NULL,
                            NULL,
@@ -301,30 +237,20 @@ SqlDBSetPwdEntry(
     BAIL_ON_LWPS_ERROR(dwError);
     
     ENTER_MACHINEPWD_DB_RW_WRITER_LOCK(bInLock);
-     
-    pszQuery = sqlite3_mprintf(
-                    DB_QUERY_DELETE_MACHINEPWD_ENTRY_BY_HOST_NAME,
-                    pAcct->pszHostName);
-    if (!pszQuery) {
-        dwError = LWPS_ERROR_QUERY_CREATION_FAILED;
-        BAIL_ON_LWPS_ERROR(dwError);
-    }
     
-    dwError = SqlDBExec(pDbHandle,
-                           pszQuery,
+    dwError = sqlite3_exec(pDbHandle,
+                           DB_QUERY_DELETE_ALL_MACHINEPWD_ENTRIES,
                            NULL,
                            NULL,
                            &pszError);
     BAIL_ON_LWPS_ERROR(dwError);
-
-    sqlite3_free(pszQuery);    
+    
     pszQuery = sqlite3_mprintf(
                     DB_QUERY_INSERT_MACHINEPWD_ENTRY,
                     pAcct->pszDomainSID,
                     pAcct->pszDomainName,
                     pAcct->pszDomainDnsName,
                     pAcct->pszHostName,
-                    pAcct->pszHostDnsDomain,
                     pAcct->pszMachineAccountName,
                     pAcct->pszMachineAccountPassword,
                     (DWORD) time(NULL),
@@ -335,7 +261,7 @@ SqlDBSetPwdEntry(
         BAIL_ON_LWPS_ERROR(dwError);
     }
     
-    dwError = SqlDBExec(pDbHandle,
+    dwError = sqlite3_exec(pDbHandle,
                            pszQuery,
                            NULL,
                            NULL,
@@ -383,12 +309,12 @@ SqlDBGetPwdEntry(
     PSTR     pszValue = NULL;
     PMACHINE_ACCT_INFO pAcct = NULL;
     BOOLEAN bInLock = FALSE;
-    DWORD   dwExpectedNumCols = 10;
+    DWORD   dwExpectedNumCols = 9;
     PSTR    pszEndPtr = NULL;
     
     ENTER_MACHINEPWD_DB_RW_READER_LOCK(bInLock);
     
-    dwError = SqlDBGetTable(pDbHandle,
+    dwError = sqlite3_get_table(pDbHandle,
                            pszQuery,
                            &ppszDbResult,
                            &numRows,
@@ -455,22 +381,6 @@ SqlDBGetPwdEntry(
         BAIL_ON_LWPS_ERROR(dwError);
     }
     
-    pszValue = ppszDbResult[i++];
-    if (!IsNullOrEmptyString(pszValue))
-    {
-        dwError = LwpsAllocateString(
-                    pszValue,
-                    &pAcct->pszHostDnsDomain);
-        BAIL_ON_LWPS_ERROR(dwError);
-    }
-    else if (!IsNullOrEmptyString(pAcct->pszDomainDnsName))
-    {
-        dwError = LwpsAllocateString(
-                    pAcct->pszDomainDnsName,
-                    &pAcct->pszHostDnsDomain);
-        BAIL_ON_LWPS_ERROR(dwError);
-    }
-
     pszValue = ppszDbResult[i++];
     if (!IsNullOrEmptyString(pszValue))
     {
@@ -657,7 +567,7 @@ SqlDBDeletePwdEntryByHostName(
         BAIL_ON_LWPS_ERROR(dwError);
     }
     
-    dwError = SqlDBExec(pDbHandle,
+    dwError = sqlite3_exec(pDbHandle,
                            pszQuery,
                            NULL,
                            NULL,
@@ -695,7 +605,7 @@ SqlDBDeleteAllEntries(
     
     ENTER_MACHINEPWD_DB_RW_WRITER_LOCK(bInLock);
     
-    dwError = SqlDBExec(pDbHandle,
+    dwError = sqlite3_exec(pDbHandle,
                            DB_QUERY_DELETE_ALL_MACHINEPWD_ENTRIES,
                            NULL,
                            NULL,
@@ -732,7 +642,7 @@ SqlDBGetPwdEntries(
     int     iRow = 0, numRows = 0;
     int     iCol = 0, numCols = 0;
     int     iVal = 0;
-    DWORD   dwExpectedNumCols = 10;
+    DWORD   dwExpectedNumCols = 9;
     PSTR    pszError = NULL;
     PSTR*   ppszDbResult = NULL;
     PSTR    pszEndPtr = NULL;
@@ -741,7 +651,7 @@ SqlDBGetPwdEntries(
     
     ENTER_MACHINEPWD_DB_RW_READER_LOCK(bInLock);
     
-    dwError = SqlDBGetTable(
+    dwError = sqlite3_get_table(
                            pDbHandle,
                            DB_QUERY_GET_MACHINEPWD_ENTRIES,
                            &ppszDbResult,
@@ -828,7 +738,7 @@ SqlDBGetPwdEntries(
                     {
                         dwError = LwpsAllocateString(
                                     ppszDbResult[iVal],
-                                    &pAcct->pszHostDnsDomain);
+                                    &pAcct->pszMachineAccountName);
                         BAIL_ON_LWPS_ERROR(dwError);
                     }
                     break;
@@ -839,24 +749,13 @@ SqlDBGetPwdEntries(
                     {
                         dwError = LwpsAllocateString(
                                     ppszDbResult[iVal],
-                                    &pAcct->pszMachineAccountName);
+                                    &pAcct->pszMachineAccountPassword);
                         BAIL_ON_LWPS_ERROR(dwError);
                     }
                     break;
                     
                 case 6:
                     
-                    if (!IsNullOrEmptyString(ppszDbResult[iVal]))
-                    {
-                        dwError = LwpsAllocateString(
-                                    ppszDbResult[iVal],
-                                    &pAcct->pszMachineAccountPassword);
-                        BAIL_ON_LWPS_ERROR(dwError);
-                    }
-                    break;
-
-                case 7:
-
                     pAcct->tPwdCreationTimestamp = 
                                 (time_t) strtoll(ppszDbResult[iVal],
                                                  &pszEndPtr,
@@ -871,7 +770,7 @@ SqlDBGetPwdEntries(
 
                     break;
                 
-                case 8:
+                case 7:
                     
                     pAcct->tPwdClientModifyTimestamp = 
                                 (time_t) strtoll(ppszDbResult[iVal],
@@ -886,7 +785,7 @@ SqlDBGetPwdEntries(
                     }
                     break;
                     
-                case 9:
+                case 8:
                     
                     pAcct->dwSchannelType = (UINT32)atol(ppszDbResult[iVal]);
                     break;
@@ -915,7 +814,7 @@ cleanup:
     
 error:
 
-    *pppAcct = NULL;
+    *ppAcct = NULL;
     *pdwNumEntries = 0;
     
     if (ppAcct) {
